@@ -1,6 +1,6 @@
 /*
  This file is part of GNU Taler
- (C) 2022-2024 Taler Systems S.A.
+ (C) 2022-2025 Taler Systems S.A.
 
  GNU Taler is free software; you can redistribute it and/or modify it under the
  terms of the GNU General Public License as published by the Free Software
@@ -68,13 +68,19 @@ function DefaultTestingContext({
     supported_kyc_requirements: [],
     version: "asd",
   };
+  // @ts-expect-error don't care about the content of keys
+  const keys: TalerExchangeApi.ExchangeKeysResponse = {};
+
   const value: ExchangeContextType = {
     cancelRequest: () => null,
-    config,
+    config: { config, keys },
     url: new URL("/", "http://localhost"),
     hints: [],
     lib: {
-      exchange: undefined!, //FIXME: mock
+      exchange: undefined!, // FIXME: mock
+    },
+    unthrottledApi: {
+      exchange: undefined!, // FIXME: mock
     },
     onActivity: () => null!,
   };
