@@ -28,10 +28,11 @@ import {
   Loading,
   RouteDefinition,
   ToastBanner,
+  logBugForDevelopers,
   notifyError,
   notifyException,
   useBankCoreApiContext,
-  useCommonPreference,
+  useCommonPreferences,
   useTranslationContext,
 } from "@gnu-taler/web-util/browser";
 import { ComponentChildren, Fragment, VNode, h } from "preact";
@@ -67,7 +68,7 @@ export function BankFrame({
   const { i18n } = useTranslationContext();
   const session = useSessionState();
   const settings = useSettingsContext();
-  const {showDebugInfo} = useCommonPreference();
+  const [{ showDebugInfo }] = useCommonPreferences();
   const [preferences, updatePreferences] = usePreferences();
   const [, , resetBankState] = useBankState();
   const d = useBankCoreApiContext();
@@ -77,11 +78,13 @@ export function BankFrame({
 
   useEffect(() => {
     if (error) {
+      logBugForDevelopers(error);
       if (error instanceof Error) {
-        console.log("Internal error, please report", error);
-        notifyException(i18n.str`Internal error, please report.`, error);
+        notifyException(
+          i18n.str`Internal error, please report. There should be more information in the console.`,
+          error,
+        );
       } else {
-        console.log("Internal error, please report", error);
         notifyError(
           i18n.str`Internal error, please report.`,
           String(error) as TranslatedString,
@@ -251,7 +254,7 @@ function AppActivity(): VNode {
   const d = useBankCoreApiContext();
   const onBackendActivity = !d ? undefined : d.onActivity;
   const cancelRequest = !d ? undefined : d.cancelRequest;
-  const {showDebugInfo} = useCommonPreference();
+  const [{ showDebugInfo }] = useCommonPreferences();
   useEffect(() => {
     // console.log("ASDASDS", onBackendActivity)
     if (!showDebugInfo) return;
