@@ -25,7 +25,6 @@ import {
   IbanString,
   PaytoType,
   Paytos,
-  TalerCorebankApi,
   TalerErrorCode,
   TranslatedString,
   assertUnreachable
@@ -36,12 +35,11 @@ import {
   LocalNotificationBanner,
   RouteDefinition,
   ShowInputErrorLabel,
-  makeSafeCall,
   notifyInfo,
   useBankCoreApiContext,
   useChallengeHandler,
   useLocalNotificationBetter,
-  useTranslationContext,
+  useTranslationContext
 } from "@gnu-taler/web-util/browser";
 import { ComponentChildren, Fragment, Ref, VNode, h } from "preact";
 import { useState } from "preact/hooks";
@@ -107,7 +105,8 @@ export function PaytoWireTransferForm({
   const parsedAmount = Amounts.parse(
     `${limitWithFee.currency}:${trimmedAmountStr}`,
   );
-  const [notification, notifyOnError] = useLocalNotificationBetter();
+  const [notification, safeFunctionHandler] = useLocalNotificationBetter();
+
   const mfa = useChallengeHandler();
 
   const paytoType =
@@ -148,130 +147,97 @@ export function PaytoWireTransferForm({
           ),
   });
 
-  let payto_uri: Paytos.FullPaytoString | undefined;
+  let parsedURI: Paytos.URI | undefined;
   let sendingAmount: AmountString | undefined;
-
-  let acName: string | undefined;
+  
   if (isRawPayto) {
     const res = Paytos.fromString(rawPaytoInput!);
 
     if (res && res.type === "ok") {
-      const p = res.body;
-      sendingAmount = p.params.amount as AmountString;
-      delete p.params.amount;
-      // if this payto is valid then it already have message
-      payto_uri = Paytos.toFullString(p);
-      acName =
-        p.targetType === undefined
-          ? undefined
-          : p.targetType === PaytoType.IBAN
-            ? p.iban
-            : p.targetType === PaytoType.TalerReserve ||
-                p.targetType === PaytoType.TalerReserveHttp
-              ? undefined // FIXME: unsupported payto://
-              : p.targetType === PaytoType.Bitcoin
-                ? p.address
-                : p.targetType === PaytoType.Ethereum
-                  ? p.address
-                  : p.targetType === PaytoType.TalerBank
-                    ? p.account
-                    : assertUnreachable(p);
-    }
+      parsedURI = res.body;
+      sendingAmount = parsedURI.params.amount as AmountString;
+      delete parsedURI.params.amount; // we don't want to send twice in the request
+   }
   } else if (account && subject) {
-    // if (!account || !subject) return;
-    let payto;
-    acName = account;
     switch (paytoType) {
       case "x-taler-bank": {
-        payto = Paytos.createTalerBank(url.host as HostPortPath, account);
+        parsedURI = Paytos.createTalerBank(url.host as HostPortPath, account);
         break;
       }
       case "iban": {
-        payto = Paytos.createIban(account as IbanString, undefined);
+        parsedURI = Paytos.createIban(account as IbanString, undefined);
         break;
       }
       default:
         assertUnreachable(paytoType);
     }
 
-    payto.params.message = encodeURIComponent(subject);
-    payto_uri = Paytos.toFullString(payto);
+    parsedURI.params.message = encodeURIComponent(subject);
     sendingAmount =
       `${limitWithFee.currency}:${trimmedAmountStr}` as AmountString;
   }
-  const puri = payto_uri;
   const sAmount = sendingAmount;
 
-  const request: TalerCorebankApi.CreateTransactionRequest | undefined =
-    !payto_uri
+  const send = safeFunctionHandler(
+    (
+      creds: LoggedIn,
+      amount: AmountString,
+      uri: Paytos.URI,
+      challengeIds: string[],
+    ) => api.createTransaction(creds, {payto_uri: Paytos.toFullString(uri), amount}, { challengeIds }),
+    (isRawPayto ? !!errorsPayto : !!errorsWire) || !sAmount || !parsedURI || credentials.status !== "loggedIn"
       ? undefined
-      : {
-          payto_uri: puri!,
-          amount: sAmount,
-        };
-
-  type reqType = TalerCorebankApi.CreateTransactionRequest;
-
-  const [doTransfer, repeatTransfer, lastCallingArgs] = mfa.withMfaHandler(
-    ({ challengeIds, onChallengeRequired }) =>
-      makeSafeCall(
-        i18n,
-        (credentials: LoggedIn, request: reqType) =>
-          api.createTransaction(credentials, request, {
-            challengeIds,
-          }),
-        (success) => {
-          notifyInfo(i18n.str`The wire transfer was successfully completed!`);
-          onSuccess();
-          setAmount(undefined);
-          setAccount(undefined);
-          setSubject(undefined);
-          rawPaytoInputSetter(undefined);
-        },
-        (fail) => {
-          switch (fail.case) {
-            case HttpStatusCode.BadRequest:
-              return i18n.str`The request was invalid or the payto://-URI used unacceptable features.`;
-            case HttpStatusCode.Unauthorized:
-              return i18n.str`Not enough permission to complete the operation.`;
-            case TalerErrorCode.BANK_ADMIN_CREDITOR:
-              return i18n.str`The bank administrator cannot be the transfer creditor.`;
-            case TalerErrorCode.BANK_UNKNOWN_CREDITOR:
-              return i18n.str`The destination account "${
-                acName ?? puri
-              }" was not found.`;
-            case TalerErrorCode.BANK_SAME_ACCOUNT:
-              return i18n.str`The origin and the destination of the transfer can't be the same.`;
-            case TalerErrorCode.BANK_UNALLOWED_DEBIT:
-              return i18n.str`Your balance is not sufficient for the operation.`;
-            case HttpStatusCode.NotFound:
-              return i18n.str`The origin account "${puri}" was not found.`;
-            case TalerErrorCode.BANK_TRANSFER_REQUEST_UID_REUSED: {
-              return i18n.str`The attempt to create the transaction has failed. Please try again.`;
-            }
-            case HttpStatusCode.Accepted: {
-              onChallengeRequired(fail.body);
-              return i18n.str`A second factor authentication is required.`;
-            }
-            default:
-              assertUnreachable(fail);
-          }
-        },
-      ),
+      : [credentials, sAmount, parsedURI, []],
   );
-  const sendHandler =
-    !request || credentials.status !== "loggedIn"
-      ? undefined
-      : () => notifyOnError(doTransfer)(credentials, request);
 
-  if (mfa.pendingChallenge && repeatTransfer) {
+  send.onSuccess = (success) => {
+    notifyInfo(i18n.str`The wire transfer was successfully completed!`);
+    onSuccess();
+    setAmount(undefined);
+    setAccount(undefined);
+    setSubject(undefined);
+    rawPaytoInputSetter(undefined);
+  };
+
+  send.onFail = (fail, creds, amount, uri) => {
+    switch (fail.case) {
+      case HttpStatusCode.BadRequest:
+        return i18n.str`The request was invalid or the payto://-URI used unacceptable features.`;
+      case HttpStatusCode.Unauthorized:
+        return i18n.str`Not enough permission to complete the operation.`;
+      case TalerErrorCode.BANK_ADMIN_CREDITOR:
+        return i18n.str`The bank administrator cannot be the transfer creditor.`;
+      case TalerErrorCode.BANK_UNKNOWN_CREDITOR:
+        return i18n.str`The destination account "${uri.displayName}" was not found.`;
+      case TalerErrorCode.BANK_SAME_ACCOUNT:
+        return i18n.str`The origin and the destination of the transfer can't be the same.`;
+      case TalerErrorCode.BANK_UNALLOWED_DEBIT:
+        return i18n.str`Your balance is not sufficient for the operation.`;
+      case HttpStatusCode.NotFound:
+        return i18n.str`The origin account "${uri.displayName}" was not found.`;
+      case TalerErrorCode.BANK_TRANSFER_REQUEST_UID_REUSED: {
+        return i18n.str`The attempt to create the transaction has failed. Please try again.`;
+      }
+      case HttpStatusCode.Accepted: {
+        mfa.onChallengeRequired(fail.body);
+        return i18n.str`A second factor authentication is required.`;
+      }
+      default:
+        assertUnreachable(fail);
+    }
+  };
+  const repeatSend = send.lambda((ids:string[]) => {
+    return [send.args![0],send.args![1],send.args![2], ids]
+  })
+  
+  if (mfa.pendingChallenge) {
     return (
       <SolveMFAChallenges
         currentChallenge={mfa.pendingChallenge}
         description={i18n.str`Confirm wire transfer.`}
         onCancel={mfa.doCancelChallenge}
-        username={lastCallingArgs[0].username}
-        onCompleted={repeatTransfer}
+        username={send.args![0].username}
+        onCompleted={repeatSend}
       />
     );
   }
@@ -675,8 +641,7 @@ export function PaytoWireTransferForm({
             type="submit"
             name="send"
             class="disabled:opacity-50 disabled:cursor-default cursor-pointer rounded-md bg-indigo-600 px-3 py-2 text-sm font-semibold text-white shadow-sm hover:bg-indigo-500 focus-visible:outline focus-visible:outline-2 focus-visible:outline-offset-2 focus-visible:outline-indigo-600"
-            disabled={isRawPayto ? !!errorsPayto : !!errorsWire}
-            onClick={sendHandler}
+            onClick={send}
           >
             <i18n.Translate>Send</i18n.Translate>
           </ButtonBetter>
