@@ -21,12 +21,18 @@
 
 import * as tests from "@gnu-taler/web-util/testing";
 import { QrCodeSection } from "./QrCodeSection.js";
-import { parseWithdrawUri } from "@gnu-taler/taler-util";
+import { TalerUriAction } from "@gnu-taler/taler-util";
+import { HostPortPath } from "@gnu-taler/taler-util";
 
 export default {
   title: "Qr Code Selection",
 };
 
 export const SimpleExample = tests.createExample(QrCodeSection, {
-  withdrawUri: parseWithdrawUri("taler://withdraw/bank.com/operationId"),
+  withdrawUri: {
+    bankIntegrationApiBaseUrl: "http://asd" as HostPortPath,
+    type: TalerUriAction.Withdraw,
+    withdrawalOperationId: "123",
+    externalConfirmation: false,
+  },
 });
