@@ -16,12 +16,12 @@
 import {
   AmountString,
   Amounts,
+  HostPortPath,
+  IbanString,
   PaytoString,
+  Paytos,
   TalerCorebankApi,
   assertUnreachable,
-  buildPayto,
-  parsePaytoUri,
-  stringifyPaytoUri,
 } from "@gnu-taler/taler-util";
 import {
   CopyButton,
@@ -45,6 +45,9 @@ import {
   doAutoFocus,
 } from "../PaytoWireTransferForm.js";
 import { getRandomPassword } from "../rnd.js";
+import { PaytoType } from "@gnu-taler/taler-util";
+
+const TALER_SCREEN_ID = 120;
 
 const EMAIL_REGEX =
   /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
@@ -52,7 +55,6 @@ const REGEX_JUST_NUMBERS_REGEX = /^\+[0-9 ]*$/;
 
 export type AccountFormData = {
   debit_threshold?: string;
-  min_cashout?: string;
   isExchange?: boolean;
   isPublic?: boolean;
   name?: string;
@@ -114,17 +116,17 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
         config.default_debit_threshold ??
         `${config.currency}:0`,
     ),
-    min_cashout: Amounts.stringifyValue(
-      template?.min_cashout ?? `${config.currency}:0`,
-    ),
     isExchange: template?.is_taler_exchange,
     isPublic: template?.is_public,
     name: template?.name ?? "",
     cashout_payto_uri:
-      getAccountId(cashoutPaytoType, template?.cashout_payto_uri) ??
-      ("" as PaytoString),
+      getAccountId(
+        cashoutPaytoType,
+        template?.cashout_payto_uri as Paytos.FullPaytoString,
+      ) ?? "",
     payto_uri:
-      getAccountId(paytoType, template?.payto_uri) ?? ("" as PaytoString),
+      getAccountId(paytoType, template?.payto_uri as Paytos.FullPaytoString) ??
+      "",
     email: template?.contact_data?.email ?? "",
     phone: template?.contact_data?.phone ?? "",
     username: username ?? "",
@@ -146,15 +148,12 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
       (config.allow_edit_cashout_payto_uri || userIsAdmin));
   const editableThreshold =
     userIsAdmin && (purpose === "create" || purpose === "update");
-  const editableMinCashout =
-    userIsAdmin && (purpose === "create" || purpose === "update");
   const editableAccount = purpose === "create" && userIsAdmin;
 
+  const hasPhone = !!defaultValue.phone || !!form.phone;
+  const hasEmail = !!defaultValue.email || !!form.email;
+
   function updateForm(newForm: typeof defaultValue): void {
-    const trimmedMinCashoutStr = newForm.min_cashout?.trim();
-    const parsedMinCashout = Amounts.parse(
-      `${config.currency}:${trimmedMinCashoutStr}`,
-    );
     const trimmedDebitThresholdStr = newForm.debit_threshold?.trim();
     const parsedDebitThreshold = Amounts.parse(
       `${config.currency}:${trimmedDebitThresholdStr}`,
@@ -197,7 +196,7 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
         : !newForm.phone.startsWith("+") // FIXME: better phone number check
           ? i18n.str`Should start with +`
           : !REGEX_JUST_NUMBERS_REGEX.test(newForm.phone)
-            ? i18n.str`Phone number can't have other than numbers`
+            ? i18n.str`A phone number consists of numbers only`
             : undefined,
       debit_threshold: !editableThreshold
         ? undefined
@@ -206,13 +205,6 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
           : !parsedDebitThreshold
             ? i18n.str`Not valid`
             : undefined,
-      min_cashout: !editableMinCashout
-        ? undefined
-        : !trimmedMinCashoutStr
-          ? undefined
-          : !parsedMinCashout
-            ? i18n.str`Not valid`
-            : undefined,
       name: !editableName
         ? undefined // disabled
         : purpose === "update" && newForm.name === undefined
@@ -234,47 +226,52 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
     if (errors) {
       onChange(undefined);
     } else {
-      let cashout;
+      let cashout: Paytos.URI | undefined;
       if (newForm.cashout_payto_uri)
         switch (cashoutPaytoType) {
           case "x-taler-bank": {
-            cashout = buildPayto(
-              "x-taler-bank",
-              url.host,
+            cashout = Paytos.createTalerBank(
+              url.host as HostPortPath,
               newForm.cashout_payto_uri,
             );
             break;
           }
           case "iban": {
-            cashout = buildPayto("iban", newForm.cashout_payto_uri, undefined);
+            cashout = Paytos.createIban(
+              newForm.cashout_payto_uri as IbanString,
+              undefined,
+            );
             break;
           }
           default:
             assertUnreachable(cashoutPaytoType);
         }
-      const cashoutURI = !cashout ? undefined : stringifyPaytoUri(cashout);
-      let internal;
+      const cashoutURI = !cashout ? null : Paytos.toFullString(cashout);
+      let internal: Paytos.URI | undefined;
       if (newForm.payto_uri)
         switch (paytoType) {
           case "x-taler-bank": {
-            internal = buildPayto("x-taler-bank", url.host, newForm.payto_uri);
+            internal = Paytos.createTalerBank(
+              url.host as HostPortPath,
+              newForm.payto_uri,
+            );
             break;
           }
           case "iban": {
-            internal = buildPayto("iban", newForm.payto_uri, undefined);
+            internal = Paytos.createIban(
+              newForm.payto_uri as IbanString,
+              undefined,
+            );
             break;
           }
           default:
             assertUnreachable(paytoType);
         }
-      const internalURI = !internal ? undefined : stringifyPaytoUri(internal);
+      const internalURI = !internal ? undefined : Paytos.toFullString(internal);
 
       const threshold = !parsedDebitThreshold
         ? undefined
         : Amounts.stringify(parsedDebitThreshold);
-      const minCashout = !parsedMinCashout
-        ? undefined
-        : Amounts.stringify(parsedMinCashout);
 
       switch (purpose) {
         case "create": {
@@ -289,8 +286,7 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
               phone: !newForm.phone ? undefined : newForm.phone,
             }),
             debit_threshold: threshold ?? config.default_debit_threshold,
-            min_cashout: minCashout,
-            cashout_payto_uri: cashoutURI,
+            cashout_payto_uri: cashoutURI === null ? undefined : cashoutURI,
             payto_uri: internalURI,
             is_public: newForm.isPublic,
             is_taler_exchange: newForm.isExchange,
@@ -313,7 +309,6 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
               phone: !newForm.phone ? undefined : newForm.phone,
             }),
             debit_threshold: threshold,
-            min_cashout: minCashout,
             is_public: newForm.isPublic,
             name: newForm.name,
             tan_channel:
@@ -348,7 +343,7 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
               for="username"
             >
               {i18n.str`Login username`}
-              {editableUsername && <b style={{ color: "red" }}> *</b>}
+              {editableUsername && <b class="text-[red]"> *</b>}
             </label>
             <div class="mt-2">
               <input
@@ -373,7 +368,7 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
               />
             </div>
             <p class="mt-2 text-sm text-gray-500">
-              <i18n.Translate>Account id for authentication</i18n.Translate>
+              <i18n.Translate>Account ID for authentication</i18n.Translate>
             </p>
           </div>
 
@@ -383,7 +378,7 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
               for="name"
             >
               {i18n.str`Full name`}
-              {editableName && <b style={{ color: "red" }}> *</b>}
+              {editableName && <b class="text-[red]"> *</b>}
             </label>
             <div class="mt-2">
               <input
@@ -417,8 +412,8 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
               label={i18n.str`Internal account`}
               help={
                 purpose === "create"
-                  ? i18n.str`If empty a random account id will be assigned`
-                  : i18n.str`Share this id to receive bank transfers`
+                  ? i18n.str`If this field is empty, a random account ID will be assigned`
+                  : i18n.str`You can copy and share this IBAN number in order to receive wire transfers to your bank account`
               }
               error={errors?.payto_uri}
               onChange={(e) => {
@@ -506,6 +501,137 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
             </p>
           </div>
 
+          {!config.supported_tan_channels ||
+          config.supported_tan_channels.length === 0 ? undefined : (
+            <div class="sm:col-span-5">
+              <label
+                class="block text-sm font-medium leading-6 text-gray-900"
+                for="channel"
+              >
+                {i18n.str`Enable second factor authentication`}
+              </label>
+              <div class="mt-2 max-w-xl text-sm text-gray-500">
+                <div class="px-4 mt-4 grid grid-cols-1 gap-y-6">
+                  {config.supported_tan_channels.indexOf(TanChannel.EMAIL) ===
+                  -1 ? undefined : (
+                    <label
+                      onClick={(e) => {
+                        if (!hasEmail) return;
+                        if (form.tan_channel === TanChannel.EMAIL) {
+                          form.tan_channel = "remove";
+                        } else {
+                          form.tan_channel = TanChannel.EMAIL;
+                        }
+                        updateForm(structuredClone(form));
+                        e.preventDefault();
+                      }}
+                      data-disabled={purpose === "show" || !hasEmail}
+                      data-selected={
+                        (form.tan_channel ?? defaultValue.tan_channel) ===
+                        TanChannel.EMAIL
+                      }
+                      class="relative flex data-[disabled=false]:cursor-pointer rounded-lg border bg-white data-[disabled=true]:bg-gray-200 p-4 shadow-sm focus:outline-none border-gray-300 data-[selected=true]:ring-2 data-[selected=true]:ring-indigo-600"
+                    >
+                      <input
+                        type="radio"
+                        name="channel"
+                        value="Newsletter"
+                        class="sr-only"
+                      />
+                      <span class="flex flex-1">
+                        <span class="flex flex-col">
+                          <span
+                            id="project-type-0-label"
+                            class="block text-sm font-medium text-gray-900 "
+                          >
+                            <i18n.Translate>Using email</i18n.Translate>
+                          </span>
+                          {purpose !== "show" &&
+                            !hasEmail &&
+                            i18n.str`Add an email in your profile to enable this option`}
+                        </span>
+                      </span>
+                      <svg
+                        data-selected={
+                          (form.tan_channel ?? defaultValue.tan_channel) ===
+                          TanChannel.EMAIL
+                        }
+                        class="h-5 w-5 text-indigo-600 data-[selected=false]:hidden"
+                        viewBox="0 0 20 20"
+                        fill="currentColor"
+                        aria-hidden="true"
+                      >
+                        <path
+                          fill-rule="evenodd"
+                          d="M10 18a8 8 0 100-16 8 8 0 000 16zm3.857-9.809a.75.75 0 00-1.214-.882l-3.483 4.79-1.88-1.88a.75.75 0 10-1.06 1.061l2.5 2.5a.75.75 0 001.137-.089l4-5.5z"
+                          clip-rule="evenodd"
+                        />
+                      </svg>
+                    </label>
+                  )}
+
+                  {config.supported_tan_channels.indexOf(TanChannel.SMS) ===
+                  -1 ? undefined : (
+                    <label
+                      onClick={(e) => {
+                        if (!hasPhone) return;
+                        if (form.tan_channel === TanChannel.SMS) {
+                          form.tan_channel = "remove";
+                        } else {
+                          form.tan_channel = TanChannel.SMS;
+                        }
+                        updateForm(structuredClone(form));
+                        e.preventDefault();
+                      }}
+                      data-disabled={purpose === "show" || !hasPhone}
+                      data-selected={
+                        (form.tan_channel ?? defaultValue.tan_channel) ===
+                        TanChannel.SMS
+                      }
+                      class="relative flex data-[disabled=false]:cursor-pointer rounded-lg border data-[disabled=true]:bg-gray-200 p-4 shadow-sm focus:outline-none border-gray-300 data-[selected=true]:ring-2 data-[selected=true]:ring-indigo-600"
+                    >
+                      <input
+                        type="radio"
+                        name="channel"
+                        value="Existing Customers"
+                        class="sr-only"
+                      />
+                      <span class="flex flex-1">
+                        <span class="flex flex-col">
+                          <span
+                            id="project-type-1-label"
+                            class="block text-sm font-medium text-gray-900"
+                          >
+                            <i18n.Translate>Using SMS</i18n.Translate>
+                          </span>
+                          {purpose !== "show" &&
+                            !hasPhone &&
+                            i18n.str`Add a phone number in your profile to enable this option`}
+                        </span>
+                      </span>
+                      <svg
+                        data-selected={
+                          (form.tan_channel ?? defaultValue.tan_channel) ===
+                          TanChannel.SMS
+                        }
+                        class="h-5 w-5 text-indigo-600 data-[selected=false]:hidden"
+                        viewBox="0 0 20 20"
+                        fill="currentColor"
+                        aria-hidden="true"
+                      >
+                        <path
+                          fill-rule="evenodd"
+                          d="M10 18a8 8 0 100-16 8 8 0 000 16zm3.857-9.809a.75.75 0 00-1.214-.882l-3.483 4.79-1.88-1.88a.75.75 0 10-1.06 1.061l2.5 2.5a.75.75 0 001.137-.089l4-5.5z"
+                          clip-rule="evenodd"
+                        />
+                      </svg>
+                    </label>
+                  )}
+                </div>
+              </div>
+            </div>
+          )}
+
           {isCashoutEnabled && (
             <TextField
               id="cashout-account"
@@ -558,38 +684,6 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
             </p>
           </div>
 
-          <div class="sm:col-span-5">
-            <label
-              for="minCashout"
-              class="block text-sm font-medium leading-6 text-gray-900"
-            >{i18n.str`Minimum cashout`}</label>
-            <InputAmount
-              name="minCashout"
-              left
-              currency={config.currency}
-              value={form.min_cashout ?? defaultValue.min_cashout}
-              onChange={
-                !editableMinCashout
-                  ? undefined
-                  : (e) => {
-                      form.min_cashout = e as AmountString;
-                      updateForm(structuredClone(form));
-                    }
-              }
-            />
-            <ShowInputErrorLabel
-              message={
-                errors?.min_cashout ? String(errors?.min_cashout) : undefined
-              }
-              isDirty={form.min_cashout !== undefined}
-            />
-            <p class="mt-2 text-sm text-gray-500">
-              <i18n.Translate>
-                Custom minimum cashout amount for this account.
-              </i18n.Translate>
-            </p>
-          </div>
-
           <div class="sm:col-span-5">
             <div class="flex items-center justify-between">
               <span class="flex flex-grow flex-col">
@@ -641,7 +735,7 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
                     id="availability-label"
                   >
                     <i18n.Translate>
-                      Is this account a payment provider?
+                      Does this account belong to a Payment Service Provider?
                     </i18n.Translate>
                   </span>
                 </span>
@@ -685,178 +779,15 @@ export function AccountForm<PurposeType extends keyof ChangeByPurposeType>({
 
 function getAccountId(
   type: "iban" | "x-taler-bank",
-  s: PaytoString | undefined,
+  s: Paytos.FullPaytoString | undefined,
 ): string | undefined {
   if (s === undefined) return undefined;
-  const p = parsePaytoUri(s);
-  if (p === undefined) return undefined;
-  if (!p.isKnown) return "<unknown>";
-  if (type === "iban" && p.targetType === "iban") return p.iban;
-  if (type === "x-taler-bank" && p.targetType === "x-taler-bank")
-    return p.account;
+  const p = Paytos.fromString(s);
+  if (p === undefined || p.type === "fail") return undefined;
+  if (!p.body.targetType === undefined) return "<unknown>";
+  if (type === "iban" && p.body.targetType === PaytoType.IBAN)
+    return p.body.iban;
+  if (type === "x-taler-bank" && p.body.targetType === PaytoType.TalerBank)
+    return p.body.account;
   return "<unsupported>";
 }
-
-{
-  /* <div class="sm:col-span-5">
-            <label
-              class="block text-sm font-medium leading-6 text-gray-900"
-              for="cashout"
-            >
-              {}
-            </label>
-            <div class="mt-2">
-              <input
-                type="text"
-                ref={focus && purpose === "update" ? doAutoFocus : undefined}
-                data-error={!!errors?.cashout_payto_uri && form.cashout_payto_uri !== undefined}
-                class="block w-full disabled:bg-gray-100 rounded-md border-0 py-1.5 text-gray-900 shadow-sm ring-1 ring-inset ring-gray-300 data-[error=true]:ring-red-500 placeholder:text-gray-400 focus:ring-2 focus:ring-inset focus:ring-indigo-600 sm:text-sm sm:leading-6"
-                name="cashout"
-                id="cashout"
-                disabled={purpose === "show"}
-                value={form.cashout_payto_uri ?? defaultValue.cashout_payto_uri}
-                onChange={(e) => {
-                  form.cashout_payto_uri = e.currentTarget.value as PaytoString;
-                  if (!form.cashout_payto_uri) {
-                    form.cashout_payto_uri = undefined
-                  }
-                  updateForm(structuredClone(form));
-                }}
-                autocomplete="off"
-              />
-              <ShowInputErrorLabel
-                message={errors?.cashout_payto_uri}
-                isDirty={form.cashout_payto_uri !== undefined}
-              />
-            </div>
-            <p class="mt-2 text-sm text-gray-500" >
-              <i18n.Translate></i18n.Translate>
-            </p>
-          </div> */
-}
-
-// function PaytoField({
-//   name,
-//   label,
-//   help,
-//   type,
-//   value,
-//   disabled,
-//   onChange,
-//   error,
-// }: {
-//   error: TranslatedString | undefined;
-//   name: string;
-//   label: TranslatedString;
-//   help: TranslatedString;
-//   onChange: (s: string) => void;
-//   type: "iban" | "x-taler-bank" | "bitcoin";
-//   disabled?: boolean;
-//   value: string | undefined;
-// }): VNode {
-//   if (type === "iban") {
-//     return (
-//       <div class="sm:col-span-5">
-//         <label
-//           class="block text-sm font-medium leading-6 text-gray-900"
-//           for={name}
-//         >
-//           {label}
-//         </label>
-//         <div class="mt-2">
-//           <div class="flex justify-between">
-//             <input
-//               type="text"
-//               class="mr-4 w-full block-inline  disabled:bg-gray-100 rounded-md border-0 py-1.5 text-gray-900 shadow-sm ring-1 ring-inset ring-gray-300 data-[error=true]:ring-red-500 placeholder:text-gray-400 focus:ring-2 focus:ring-inset focus:ring-indigo-600 sm:text-sm sm:leading-6"
-//               name={name}
-//               id={name}
-//               disabled={disabled}
-//               value={value ?? ""}
-//               onChange={(e) => {
-//                 onChange(e.currentTarget.value);
-//               }}
-//             />
-//             <CopyButton
-//               class="p-2 rounded-full  text-black shadow-sm  focus-visible:outline focus-visible:outline-2 focus-visible:outline-offset-2 "
-//               getContent={() => value ?? ""}
-//             />
-//           </div>
-//           <ShowInputErrorLabel message={error} isDirty={value !== undefined} />
-//         </div>
-//         <p class="mt-2 text-sm text-gray-500">{help}</p>
-//       </div>
-//     );
-//   }
-//   if (type === "x-taler-bank") {
-//     return (
-//       <div class="sm:col-span-5">
-//         <label
-//           class="block text-sm font-medium leading-6 text-gray-900"
-//           for={name}
-//         >
-//           {label}
-//         </label>
-//         <div class="mt-2">
-//           <div class="flex justify-between">
-//             <input
-//               type="text"
-//               class="mr-4 w-full block-inline  disabled:bg-gray-100 rounded-md border-0 py-1.5 text-gray-900 shadow-sm ring-1 ring-inset ring-gray-300 data-[error=true]:ring-red-500 placeholder:text-gray-400 focus:ring-2 focus:ring-inset focus:ring-indigo-600 sm:text-sm sm:leading-6"
-//               name={name}
-//               id={name}
-//               disabled={disabled}
-//               value={value ?? ""}
-//               onChange={(e) => {
-//                 onChange(e.currentTarget.value);
-//               }}
-//             />
-//             <CopyButton
-//               class="p-2 rounded-full  text-black shadow-sm  focus-visible:outline focus-visible:outline-2 focus-visible:outline-offset-2 "
-//               getContent={() => value ?? ""}
-//             />
-//           </div>
-//           <ShowInputErrorLabel message={error} isDirty={value !== undefined} />
-//         </div>
-//         <p class="mt-2 text-sm text-gray-500">
-//           {help}
-//         </p>
-//       </div>
-//     );
-//   }
-//   if (type === "bitcoin") {
-//     return (
-//       <div class="sm:col-span-5">
-//         <label
-//           class="block text-sm font-medium leading-6 text-gray-900"
-//           for={name}
-//         >
-//           {label}
-//         </label>
-//         <div class="mt-2">
-//           <div class="flex justify-between">
-//             <input
-//               type="text"
-//               class="mr-4 w-full block-inline  disabled:bg-gray-100 rounded-md border-0 py-1.5 text-gray-900 shadow-sm ring-1 ring-inset ring-gray-300 data-[error=true]:ring-red-500 placeholder:text-gray-400 focus:ring-2 focus:ring-inset focus:ring-indigo-600 sm:text-sm sm:leading-6"
-//               name={name}
-//               id={name}
-//               disabled={disabled}
-//               value={value ?? ""}
-//             />
-//             <CopyButton
-//               class="p-2 rounded-full  text-black shadow-sm  focus-visible:outline focus-visible:outline-2 focus-visible:outline-offset-2 "
-//               getContent={() => value ?? ""}
-//             />
-//             <ShowInputErrorLabel
-//               message={error}
-//               isDirty={value !== undefined}
-//             />
-//           </div>
-//         </div>
-//         <p class="mt-2 text-sm text-gray-500">
-//           {/* <i18n.Translate>bitcoin address</i18n.Translate> */}
-//           {help}
-//         </p>
-//       </div>
-//     );
-//   }
-//   assertUnreachable(type);
-// }
