@@ -33,7 +33,6 @@ import {
   LocalNotificationBanner,
   RouteDefinition,
   ShowInputErrorLabel,
-  makeSafeCall,
   notifyInfo,
   useBankCoreApiContext,
   useChallengeHandler,
@@ -43,6 +42,11 @@ import {
 import { Fragment, VNode, h } from "preact";
 import { useEffect, useState } from "preact/hooks";
 
+import {
+  Paytos,
+  TalerCorebankApi,
+  opFixedSuccess,
+} from "@gnu-taler/taler-util";
 import { useAccountDetails } from "../../hooks/account.js";
 import {
   TransCalc,
@@ -60,8 +64,6 @@ import {
   doAutoFocus,
 } from "../PaytoWireTransferForm.js";
 import { SolveMFAChallenges } from "../SolveMFA.js";
-import { TalerCorebankApi } from "@gnu-taler/taler-util";
-import { Paytos } from "@gnu-taler/taler-util";
 
 const TALER_SCREEN_ID = 127;
 
@@ -221,7 +223,8 @@ function CreateCashoutInternal({
     estimateByDebit: calculateFromDebit,
   } = useCashoutEstimatorByUser(accountData.name);
   const [form, setForm] = useState<Partial<FormType>>({ isDebit: true });
-  const [notification, notifyOnError] = useLocalNotificationBetter();
+  const [notification, safeFunctionHandler] = useLocalNotificationBetter();
+
   const mfa = useChallengeHandler();
   const { i18n } = useTranslationContext();
   const {
@@ -266,40 +269,41 @@ function CreateCashoutInternal({
     : true;
   const notZero = Amounts.isNonZero(inputAmount);
 
-  const conversionCalculator = makeSafeCall(
-    i18n,
-    (isDebit: boolean, input: AmountJson, fee: AmountJson) =>
-      isDebit
-        ? calculateFromDebit(input, fee)
-        : calculateFromCredit(input, fee),
-    (success) => {
-      setCalculation(success.body);
-    },
-    (fail) => {
-      switch (fail.case) {
-        case HttpStatusCode.Conflict:
-          return i18n.str`The amount is too small.`;
-        case HttpStatusCode.BadRequest:
-          return i18n.str`Server didn't like our request`;
-        case HttpStatusCode.NotImplemented:
-          return i18n.str`Conversion is not enabled.`;
+  const conversionCalculator = safeFunctionHandler(
+    async (isDebit: boolean, input: AmountJson, fee: AmountJson) => {
+      if (notZero && higerThanMin) {
+        return isDebit
+          ? calculateFromDebit(input, fee)
+          : calculateFromCredit(input, fee);
+      } else {
+        return opFixedSuccess(zeroCalc);
       }
     },
+    [form.isDebit ?? false, inputAmount, sellFee],
   );
+  conversionCalculator.onSuccess = (success) => setCalculation(success);
+  conversionCalculator.onFail = (fail) => {
+    switch (fail.case) {
+      case HttpStatusCode.BadRequest:
+        return i18n.str`The server didn't understand the request.`;
+      case HttpStatusCode.Conflict:
+        return i18n.str`The amount is too small`;
+      case HttpStatusCode.NotImplemented:
+        return i18n.str`Conversion is not implemented.`;
+      case TalerErrorCode.GENERIC_PARAMETER_MISSING:
+        return i18n.str`At least debit or credit needs to be provided`;
+      case TalerErrorCode.GENERIC_PARAMETER_MALFORMED:
+        return i18n.str`The amount is malfored`;
+      case TalerErrorCode.GENERIC_CURRENCY_MISMATCH:
+        return i18n.str`The currency is not supported`;
+    }
+  };
 
   useEffect(() => {
-    async function doAsync() {
-      if (notZero && higerThanMin) {
-        await conversionCalculator(form.isDebit ?? false, inputAmount, sellFee);
-      } else {
-        setCalculation(zeroCalc);
-      }
-    }
-    doAsync();
+    conversionCalculator.call();
   }, [form.amount, form.isDebit, notZero, higerThanMin, rate.cashout_fee]);
 
-  const calc =
-    calculationResult === "amount-is-too-small" ? zeroCalc : calculationResult;
+  const calc = !calculationResult ? zeroCalc : calculationResult;
 
   const balanceAfter = IntAmounts.toIntAmount(
     account.balance,
@@ -315,7 +319,7 @@ function CreateCashoutInternal({
       ? i18n.str`Required`
       : !inputAmount
         ? i18n.str`Invalid`
-        : calculationResult === "amount-is-too-small"
+        : !calculationResult
           ? i18n.str`Amount needs to be higher`
           : Amounts.isZero(
                 balanceLimit
@@ -336,88 +340,83 @@ function CreateCashoutInternal({
   });
   const trimmedAmountStr = form.amount?.trim();
 
-  const [createCashout, repeatCashout] = mfa.withMfaHandler(
-    ({ challengeIds, onChallengeRequired }) =>
-      makeSafeCall(
-        i18n,
-        (calc: TransCalc, subject: string) =>
-          api.createCashout(
-            session,
-            {
-              request_uid: RANDOM_STRING,
-              amount_credit: Amounts.stringify(calc.credit),
-              amount_debit: Amounts.stringify(calc.debit),
-              subject,
-            },
-            { challengeIds },
-          ),
-        (success) => {
-          notifyInfo(i18n.str`Cashout created`);
-          onCashout();
-        },
-        (fail) => {
-          switch (fail.case) {
-            case HttpStatusCode.Accepted: {
-              // updateBankState("currentChallenge", {
-              //   operation: "create-cashout",
-              //   id: String(resp.body.challenge_id),
-              //   sent: AbsoluteTime.never(),
-              //   request,
-              // });
-              onChallengeRequired(fail.body);
-              return i18n.str`Second factor authentication required.`;
-            }
-            case HttpStatusCode.NotFound:
-              return i18n.str`Account not found`;
-            case TalerErrorCode.BANK_TRANSFER_REQUEST_UID_REUSED:
-              return i18n.str`Duplicated request detected, check if the operation succeeded or try again.`;
-            case TalerErrorCode.BANK_BAD_CONVERSION:
-              return i18n.str`The conversion rate was applied incorrectly`;
-            case TalerErrorCode.BANK_UNALLOWED_DEBIT:
-              return i18n.str`The account does not have sufficient funds`;
-            case HttpStatusCode.NotImplemented:
-              return i18n.str`Cashout is disabled`;
-            case TalerErrorCode.BANK_CONFIRM_INCOMPLETE:
-              return i18n.str`Missing cashout URI in the profile`;
-            case TalerErrorCode.BANK_CONVERSION_AMOUNT_TO_SMALL:
-              return i18n.str`The amount is below the minimum amount permitted.`;
-            case TalerErrorCode.BANK_TAN_CHANNEL_SCRIPT_FAILED:
-              return i18n.str`Sending the confirmation message failed, retry later or contact the administrator.`;
-            case TalerErrorCode.BANK_TAN_CHANNEL_NOT_SUPPORTED: {
-              return i18n.str`The server doesn't support the current TAN channel.`;
-            }
-          }
-        },
-      ),
-  );
-
   const subject = form.subject;
-  const cashoutHandler =
-    !!errors || !subject
-      ? undefined
-      : () => notifyOnError(createCashout)(calc, subject);
+
+  const cashout = safeFunctionHandler(
+    (calc: TransCalc, subject: string, challengeIds: string[]) =>
+      api.createCashout(
+        session,
+        {
+          request_uid: RANDOM_STRING,
+          amount_credit: Amounts.stringify(calc.credit),
+          amount_debit: Amounts.stringify(calc.debit),
+          subject,
+        },
+        { challengeIds },
+      ),
+    !!errors || !subject ? undefined : [calc, subject, []],
+  );
+  cashout.onSuccess = (success) => {
+    notifyInfo(i18n.str`Cashout created`);
+    onCashout();
+  };
+  cashout.onFail = (fail) => {
+    switch (fail.case) {
+      case HttpStatusCode.Accepted: {
+        mfa.onChallengeRequired(fail.body);
+        return i18n.str`Second factor authentication required.`;
+      }
+      case HttpStatusCode.NotFound:
+        return i18n.str`Account not found`;
+      case TalerErrorCode.BANK_TRANSFER_REQUEST_UID_REUSED:
+        return i18n.str`Duplicated request detected, check if the operation succeeded or try again.`;
+      case TalerErrorCode.BANK_BAD_CONVERSION:
+        return i18n.str`The conversion rate was applied incorrectly`;
+      case TalerErrorCode.BANK_UNALLOWED_DEBIT:
+        return i18n.str`The account does not have sufficient funds`;
+      case HttpStatusCode.NotImplemented:
+        return i18n.str`Cashout is disabled`;
+      case TalerErrorCode.BANK_CONFIRM_INCOMPLETE:
+        return i18n.str`Missing cashout URI in the profile`;
+      case TalerErrorCode.BANK_CONVERSION_AMOUNT_TO_SMALL:
+        return i18n.str`The amount is below the minimum amount permitted.`;
+      case TalerErrorCode.BANK_TAN_CHANNEL_SCRIPT_FAILED:
+        return i18n.str`Sending the confirmation message failed, retry later or contact the administrator.`;
+      case TalerErrorCode.BANK_TAN_CHANNEL_NOT_SUPPORTED: {
+        return i18n.str`The server doesn't support the current TAN channel.`;
+      }
+    }
+  };
+
+  const retryCashout = cashout.lambda((ids: string[]) => [
+    cashout.args![0],
+    cashout.args![1],
+    ids,
+  ]);
 
   const cashoutDisabled = !accountData.cashout_payto_uri;
 
   const cashoutAccount = !accountData.cashout_payto_uri
     ? undefined
     : Paytos.fromString(accountData.cashout_payto_uri);
-  const cashoutAccountName = !cashoutAccount || cashoutAccount.type === "fail"
-    ? undefined
-    : cashoutAccount.body.displayName;
+  const cashoutAccountName =
+    !cashoutAccount || cashoutAccount.type === "fail"
+      ? undefined
+      : cashoutAccount.body.displayName;
 
-  const cashoutLegalName = !cashoutAccount || cashoutAccount.type === "fail"
-    ? undefined
-    : cashoutAccount.body.params["receiver-name"];
+  const cashoutLegalName =
+    !cashoutAccount || cashoutAccount.type === "fail"
+      ? undefined
+      : cashoutAccount.body.params["receiver-name"];
 
-  if (mfa.pendingChallenge && repeatCashout) {
+  if (mfa.pendingChallenge) {
     return (
       <SolveMFAChallenges
         currentChallenge={mfa.pendingChallenge}
         username={accountData.name}
         description={i18n.str`Create cashout.`}
         onCancel={mfa.doCancelChallenge}
-        onCompleted={repeatCashout}
+        onCompleted={retryCashout}
       />
     );
   }
@@ -646,25 +645,6 @@ function CreateCashoutInternal({
                     {i18n.str`Amount`}
                     <b class="text-[red]"> *</b>
                   </label>
-                  {/* <button
-                    type="button"
-                    data-enabled={form.isDebit}
-                    class="bg-indigo-600 data-[enabled=false]:bg-gray-200 relative inline-flex h-6 w-11 flex-shrink-0 cursor-pointer rounded-full border-2 border-transparent transition-colors duration-200 ease-in-out focus:outline-none focus:ring-2 focus:ring-indigo-600 focus:ring-offset-2"
-                    role="switch"
-                    aria-checked="false"
-                    aria-labelledby="availability-label"
-                    aria-describedby="availability-description"
-                    onClick={() => {
-                      form.isDebit = !form.isDebit;
-                      updateForm(structuredClone(form));
-                    }}
-                  >
-                    <span
-                      aria-hidden="true"
-                      data-enabled={form.isDebit}
-                      class="translate-x-5 data-[enabled=false]:translate-x-0 pointer-events-none inline-block h-5 w-5 transform rounded-full bg-white shadow ring-0 transition duration-200 ease-in-out"
-                    ></span>
-                  </button> */}
                 </div>
                 <div class="mt-2">
                   <InputAmount
@@ -767,7 +747,7 @@ function CreateCashoutInternal({
               type="submit"
               name="cashout"
               class="disabled:opacity-50 disabled:cursor-default cursor-pointer rounded-md bg-indigo-600 px-3 py-2 text-sm font-semibold text-white shadow-sm hover:bg-indigo-500 focus-visible:outline focus-visible:outline-2 focus-visible:outline-offset-2 focus-visible:outline-indigo-600"
-              onClick={cashoutHandler}
+              onClick={cashout}
             >
               <i18n.Translate>Cashout</i18n.Translate>
             </ButtonBetter>
