@@ -30,6 +30,7 @@ import {
   useTranslationContext,
 } from "@gnu-taler/web-util/browser";
 
+const TALER_SCREEN_ID = 2;
 /**
  * Validate (the number part of) an amount.  If needed,
  * replace comma with a dot.  Returns 'false' whenever
@@ -120,7 +121,6 @@ export enum CashoutStatus {
   PENDING = "pending",
 }
 
-
 export const PAGINATED_LIST_SIZE = 5;
 // when doing paginated request, ask for one more
 // and use it to know if there are more to request
@@ -142,7 +142,7 @@ export async function withRuntimeErrorHandling<T>(
         i18n.str`Operation failed, please report`,
         (error instanceof Error
           ? error.message
-          : JSON.stringify(error)) as TranslatedString,
+          : (error)) as TranslatedString,
       );
     }
   }
@@ -159,7 +159,7 @@ export function buildRequestErrorMessage(
         type: "error",
         title: i18n.str`Request timeout`,
         description: cause.message as TranslatedString,
-        debug: JSON.stringify(cause.errorDetail, undefined, 2),
+        debug: cause.errorDetail,
         when: AbsoluteTime.now(),
       };
       break;
@@ -169,7 +169,7 @@ export function buildRequestErrorMessage(
         type: "error",
         title: i18n.str`Request throttled`,
         description: cause.message as TranslatedString,
-        debug: JSON.stringify(cause.errorDetail, undefined, 2),
+        debug: cause.errorDetail,
         when: AbsoluteTime.now(),
       };
       break;
@@ -179,7 +179,7 @@ export function buildRequestErrorMessage(
         type: "error",
         title: i18n.str`Malformed response`,
         description: cause.message as TranslatedString,
-        debug: JSON.stringify(cause.errorDetail, undefined, 2),
+        debug: cause.errorDetail,
         when: AbsoluteTime.now(),
       };
       break;
@@ -189,7 +189,7 @@ export function buildRequestErrorMessage(
         type: "error",
         title: i18n.str`Network error`,
         description: cause.message as TranslatedString,
-        debug: JSON.stringify(cause.errorDetail, undefined, 2),
+        debug: cause.errorDetail,
         when: AbsoluteTime.now(),
       };
       break;
@@ -199,7 +199,7 @@ export function buildRequestErrorMessage(
         type: "error",
         title: i18n.str`Unexpected request error`,
         description: cause.message as TranslatedString,
-        debug: JSON.stringify(cause.errorDetail, undefined, 2),
+        debug: cause.errorDetail,
         when: AbsoluteTime.now(),
       };
       break;
@@ -209,7 +209,7 @@ export function buildRequestErrorMessage(
         type: "error",
         title: i18n.str`Unexpected error`,
         description: cause.message as TranslatedString,
-        debug: JSON.stringify(cause.errorDetail, undefined, 2),
+        debug: cause.errorDetail,
         when: AbsoluteTime.now(),
       };
       break;
@@ -384,7 +384,7 @@ export function validateIBAN(
   i18n: InternationalizationAPI,
 ): TranslatedString | undefined {
   if (!IBAN_REGEX.test(account)) {
-    return i18n.str`IBAN only have uppercased letters and numbers`;
+    return i18n.str`An IBAN consists of capital letters and numbers only`;
   }
   // Check total length
   if (account.length < 4) return i18n.str`IBAN numbers have more that 4 digits`;
@@ -426,14 +426,14 @@ function calculate_iban_checksum(str: string): number {
   return result;
 }
 
-const USERNAME_REGEX = /^[A-Za-z][A-Za-z0-9]*$/;
-
+export const USERNAME_REGEX = /^[a-zA-Z0-9\-\.\_\~]*$/;
+// [a-zA-Z0-9\\-\\._~]+
 export function validateTalerBank(
   account: string,
   i18n: InternationalizationAPI,
 ): TranslatedString | undefined {
   if (!USERNAME_REGEX.test(account)) {
-    return i18n.str`Account only have letters and numbers`;
+    return i18n.str`Use letters, numbers or any of these characters: - . _ ~`;
   }
   return undefined;
 }
