@@ -140,6 +140,7 @@ test("WPT idbfactory-open7.htm", async (t) => {
 
     open_rq.onupgradeneeded = function () {};
     open_rq.onsuccess = function (e: any) {
+      console.log("open7 - opening higher version DB");
       var db = e.target.result;
       db.close();
 
@@ -152,8 +153,12 @@ test("WPT idbfactory-open7.htm", async (t) => {
     };
 
     function open_current_db(e: any) {
-      var open_rq3 = indexedDB.open(e.target.result.name);
+      console.log("open7 - opening current DB");
+      const name = e.target.result.name;
+      console.log(`open7 - name is ${name}`)
+      var open_rq3 = indexedDB.open(name);
       open_rq3.onsuccess = function (e: any) {
+        console.log("open7 - success opening current DB");
         t.deepEqual(e.target.result.version, 14, "db.version");
         open_rq2.result.close();
         open_rq3.result.close();
@@ -278,6 +283,8 @@ test("WPT idbfactory-open9.htm", async (t) => {
   await should_work(1.5, 1);
   await should_work(Number.MAX_SAFE_INTEGER, Number.MAX_SAFE_INTEGER); // 0x20000000000000 - 1
   await should_work(undefined, 1);
+
+  console.error("test at end");
 });
 
 // IDBFactory.open() - error in version change transaction aborts open
