@@ -451,7 +451,10 @@ export default class BTree<K = any, V = any>
     var nu = this.greedyClone();
     var del: any;
     nu.editAll((k, v, i) => {
-      if (!callback(k, v, i)) return (del = Delete);
+      if (!callback(k, v, i)) {
+        return (del = Delete);
+      }
+      return undefined;
     });
     if (!del && returnThisIfUnchanged) return this;
     return nu;
@@ -549,6 +552,7 @@ export default class BTree<K = any, V = any>
               return { done: false, value: reusedArray as [K, V] };
             }
             state = 2;
+            continue;
           case 2:
             // Advance to the next leaf node
             for (var level = -1; ; ) {
@@ -621,6 +625,7 @@ export default class BTree<K = any, V = any>
               return { done: false, value: reusedArray as [K, V] };
             }
             state = 2;
+          continue jump;
           case 2:
             // Advance to the next leaf node
             for (var level = -1; ; ) {
@@ -833,6 +838,7 @@ export default class BTree<K = any, V = any>
         _compare,
         onlyOther,
       );
+    return undefined;
   }
 
   ///////////////////////////////////////////////////////////////////////////
