@@ -24,7 +24,6 @@ import {
 } from "@gnu-taler/taler-util";
 import {
   BrowserHashNavigationProvider,
-  CommonPreferenceProvider,
   ExchangeApiProvider,
   Loading,
   TalerWalletIntegrationBrowserProvider,
@@ -59,61 +58,59 @@ export function App(): VNode {
   const baseUrl = getInitialBackendBaseURL(settings.backendBaseURL);
   return (
     <SettingsProvider value={settings}>
-      <CommonPreferenceProvider>
-        <TranslationProvider
-          source={strings}
-          completeness={{
-            es: strings["es"].completeness,
-            de: strings["de"].completeness,
+      <TranslationProvider
+        source={strings}
+        completeness={{
+          es: strings["es"].completeness,
+          de: strings["de"].completeness,
+        }}
+      >
+        <ExchangeApiProvider
+          baseUrl={new URL("/", baseUrl)}
+          frameOnError={Frame}
+          evictors={{
+            exchange: evictExchangeSwrCache,
           }}
         >
-          <ExchangeApiProvider
-            baseUrl={new URL("/", baseUrl)}
-            frameOnError={Frame}
-            evictors={{
-              exchange: evictExchangeSwrCache,
+          <SWRConfig
+            value={{
+              provider: WITH_LOCAL_STORAGE_CACHE
+                ? localStorageProvider
+                : undefined,
+              // normally, do not revalidate
+              revalidateOnFocus: false,
+              revalidateOnReconnect: false,
+              revalidateIfStale: false,
+              revalidateOnMount: undefined,
+              focusThrottleInterval: undefined,
+
+              // normally, do not refresh
+              refreshInterval: undefined,
+              dedupingInterval: 2000,
+              refreshWhenHidden: false,
+              refreshWhenOffline: false,
+
+              // ignore errors
+              shouldRetryOnError: false,
+              errorRetryCount: 0,
+              errorRetryInterval: undefined,
+
+              // do not go to loading again if already has data
+              keepPreviousData: true,
             }}
           >
-            <SWRConfig
-              value={{
-                provider: WITH_LOCAL_STORAGE_CACHE
-                  ? localStorageProvider
-                  : undefined,
-                // normally, do not revalidate
-                revalidateOnFocus: false,
-                revalidateOnReconnect: false,
-                revalidateIfStale: false,
-                revalidateOnMount: undefined,
-                focusThrottleInterval: undefined,
-
-                // normally, do not refresh
-                refreshInterval: undefined,
-                dedupingInterval: 2000,
-                refreshWhenHidden: false,
-                refreshWhenOffline: false,
-
-                // ignore errors
-                shouldRetryOnError: false,
-                errorRetryCount: 0,
-                errorRetryInterval: undefined,
-
-                // do not go to loading again if already has data
-                keepPreviousData: true,
-              }}
-            >
-              <TalerWalletIntegrationBrowserProvider>
-                <BrowserHashNavigationProvider>
-                  <UiFormsProvider value={forms}>
-                    <NotifierProvider>
-                      <Routing />
-                    </NotifierProvider>
-                  </UiFormsProvider>
-                </BrowserHashNavigationProvider>
-              </TalerWalletIntegrationBrowserProvider>
-            </SWRConfig>
-          </ExchangeApiProvider>
-        </TranslationProvider>
-      </CommonPreferenceProvider>
+            <TalerWalletIntegrationBrowserProvider>
+              <BrowserHashNavigationProvider>
+                <UiFormsProvider value={forms}>
+                  <NotifierProvider>
+                    <Routing />
+                  </NotifierProvider>
+                </UiFormsProvider>
+              </BrowserHashNavigationProvider>
+            </TalerWalletIntegrationBrowserProvider>
+          </SWRConfig>
+        </ExchangeApiProvider>
+      </TranslationProvider>
     </SettingsProvider>
   );
 }
