@@ -53,7 +53,9 @@ import UpdateCategory from "./paths/instance/categories/update/index.js";
 import ListKYCPage from "./paths/instance/kyc/list/index.js";
 import OrderCreatePage from "./paths/instance/orders/create/index.js";
 import OrderDetailsPage from "./paths/instance/orders/details/index.js";
-import OrderListPage from "./paths/instance/orders/list/index.js";
+import OrderListPage, {
+  OrderListSection,
+} from "./paths/instance/orders/list/index.js";
 import ValidatorCreatePage from "./paths/instance/otp_devices/create/index.js";
 import ValidatorListPage from "./paths/instance/otp_devices/list/index.js";
 import ValidatorUpdatePage from "./paths/instance/otp_devices/update/index.js";
@@ -110,6 +112,7 @@ export enum InstancePaths {
   inventory_new = "/inventory/new",
 
   order_list = "/orders",
+  order_list_section = "/orders/:section",
   order_new = "/order/new",
   order_details = "/order/:oid/details",
 
@@ -223,7 +226,12 @@ export function Routing(_p: Props): VNode {
             onCancel={() => route(InstancePaths.order_list)}
             onReseted={() => route(InstancePaths.order_list)}
           />
-          <Route default component={() => <LoginPage showCreateAccount={config.have_self_provisioning} />} />
+          <Route
+            default
+            component={() => (
+              <LoginPage showCreateAccount={config.have_self_provisioning} />
+            )}
+          />
         </Router>
       </Fragment>
     );
@@ -264,17 +272,30 @@ export function Routing(_p: Props): VNode {
         <Fragment>
           <NotificationCard
             notification={{
-              message: "Internal error, please report",
+              message: "Internal error.",
               type: "ERROR",
 
               description: (
-                <pre>
-                  {
-                    (error instanceof Error
-                      ? error.stack
-                      : String(error)) as TranslatedString
-                  }
-                </pre>
+                <Fragment>
+                  <i18n.Translate>
+                    The application is in a unexpected state and can't recover
+                    from here. You can report the problem to the developers at{" "}
+                    <a
+                      href="https://bugs.gnunet.org/"
+                      target="_blank"
+                      referrerpolicy="no-referrer"
+                    >
+                      https://bugs.gnunet.org/
+                    </a>
+                  </i18n.Translate>
+                  <pre>
+                    {
+                      (error instanceof Error
+                        ? error.stack
+                        : String(error)) as TranslatedString
+                    }
+                  </pre>
+                </Fragment>
               ),
             }}
           />
@@ -491,12 +512,40 @@ export function Routing(_p: Props): VNode {
         <Route
           path={InstancePaths.order_list}
           component={OrderListPage}
+          section={OrderListSection.NEW}
           onCreate={() => {
             route(InstancePaths.order_new);
           }}
           onSelect={(id: string) => {
             route(InstancePaths.order_details.replace(":oid", id));
           }}
+          onChangeSection={(s?: OrderListSection) => {
+            if (!s) {
+              route(InstancePaths.order_list);
+            } else {
+              route(InstancePaths.order_list_section.replace(":section", s));
+            }
+          }}
+        />
+        {/**
+         * Order pages
+         */}
+        <Route
+          path={InstancePaths.order_list_section}
+          component={OrderListPage}
+          onCreate={() => {
+            route(InstancePaths.order_new);
+          }}
+          onSelect={(id: string) => {
+            route(InstancePaths.order_details.replace(":oid", id));
+          }}
+          onChangeSection={(s?: OrderListSection) => {
+            if (!s) {
+              route(InstancePaths.order_list);
+            } else {
+              route(InstancePaths.order_list_section.replace(":section", s));
+            }
+          }}
         />
         <Route
           path={InstancePaths.order_details}
@@ -689,10 +738,7 @@ export function Routing(_p: Props): VNode {
         {/**
          * Statistics pages
          */}
-        <Route
-          path={InstancePaths.statistics}
-          component={Statistics}
-        />
+        <Route path={InstancePaths.statistics} component={Statistics} />
         {/**
          * Example pages
          */}
