@@ -83,7 +83,11 @@ export function InputBoolean<T>({
             </label>
             {help}
           </p>
-          {error && <p class="help is-danger">{error}</p>}
+          {error && (
+            <p class="help is-danger" style={{ fontSize: 16 }}>
+              {error}
+            </p>
+          )}
         </div>
       </div>
     </div>
