@@ -75,6 +75,11 @@ export function InputDate<T>({
       <div class="field-label is-normal">
         <label class="label">
           {label}
+          {required && (
+            <span class="has-text-danger" style={{marginLeft:5}}>
+              *
+            </span>
+          )}
           {tooltip && (
             <span class="icon has-tooltip-right" data-tooltip={tooltip}>
               <i class="mdi mdi-information" />
@@ -102,11 +107,6 @@ export function InputDate<T>({
                   if (!readonly) setOpened(true);
                 }}
               />
-              {required && (
-                <span class="icon has-text-danger is-right">
-                  <i class="mdi mdi-alert" />
-                </span>
-              )}
               {help}
             </p>
             <div
