@@ -36,7 +36,7 @@ export const InitialValueEmpty = (): VNode => {
   return (
     <FormProvider<T> object={state} errors={{}} valueHandler={setState}>
       Initial value: ''
-      <InputSecured<T> name="auth_token" label="Access token" />
+      <InputSecured<T> name="auth_token" label="Password" />
     </FormProvider>
   );
 };
@@ -45,7 +45,7 @@ export const InitialValueToken = (): VNode => {
   const [state, setState] = useState<Partial<T>>({ auth_token: "token" });
   return (
     <FormProvider<T> object={state} errors={{}} valueHandler={setState}>
-      <InputSecured<T> name="auth_token" label="Access token" />
+      <InputSecured<T> name="auth_token" label="Password" />
     </FormProvider>
   );
 };
@@ -55,7 +55,7 @@ export const InitialValueNull = (): VNode => {
   return (
     <FormProvider<T> object={state} errors={{}} valueHandler={setState}>
       Initial value: ''
-      <InputSecured<T> name="auth_token" label="Access token" />
+      <InputSecured<T> name="auth_token" label="Password" />
     </FormProvider>
   );
 };
