@@ -50,6 +50,11 @@ export function InputSelector<T>({
       <div class="field-label is-normal">
         <label class="label">
           {label}
+          {required && (
+            <span class="has-text-danger" style={{ marginLeft: 5 }}>
+              *
+            </span>
+          )}
           {tooltip && (
             <span class="icon has-tooltip-right" data-tooltip={tooltip}>
               <i class="mdi mdi-information" />
@@ -80,14 +85,6 @@ export function InputSelector<T>({
             </select>
           </p>
           <p class="help">{help}</p>
-          {required && (
-            <span
-              class="icon has-text-danger is-right"
-              style={{ height: "2.5em" }}
-            >
-              <i class="mdi mdi-alert" />
-            </span>
-          )}
           {error && (
             <p class="help is-danger" style={{ fontSize: 16 }}>
               {error}
