@@ -60,6 +60,11 @@ export function InputToggle<T>({
       <div class="field-label is-normal">
         <label class="label">
           {label}
+          {required && (
+            <span class="has-text-danger" style={{marginLeft:5}}>
+              *
+            </span>
+          )}
           {tooltip && (
             <span class="icon has-tooltip-right" data-tooltip={tooltip}>
               <i class="mdi mdi-information" />
@@ -95,11 +100,6 @@ export function InputToggle<T>({
                 style={{ cursor: readonly ? "default" : undefined }}
               ></div>
             </label>
-            {required && (
-              <span class="icon has-text-danger is-right">
-                <i class="mdi mdi-alert" />
-              </span>
-            )}
             <p>{help}</p>
           </p>
           {error && (
