@@ -32,7 +32,8 @@ import { InputLocation } from "../form/InputLocation.js";
 import { InputToggle } from "../form/InputToggle.js";
 import { InputWithAddon } from "../form/InputWithAddon.js";
 import { FragmentPersonaFlag } from "../menu/SideBar.js";
-
+import { RoundingInterval } from "@gnu-taler/taler-util";
+import { InputSelector } from "../form/InputSelector.js";
 
 const TALER_SCREEN_ID = 16;
 
@@ -115,11 +116,57 @@ export function DefaultInstanceFormFields({
           tooltip={i18n.str`Time customers have to pay an order before the offer expires by default.`}
         />
 
+        <InputDuration<Entity>
+          name="default_refund_delay"
+          label={i18n.str`Default refund delay`}
+          tooltip={i18n.str`Time merchants have to refund an order.`}
+        />
+
         <InputDuration<Entity>
           name="default_wire_transfer_delay"
           label={i18n.str`Default wire transfer delay`}
           tooltip={i18n.str`Maximum time an exchange is allowed to delay wiring funds to the merchant, enabling it to aggregate smaller payments into larger wire transfers and reducing wire fees.`}
         />
+
+        <InputSelector<Entity>
+          name="default_wire_transfer_rounding_interval"
+          label={i18n.str`Default wire transfer rounding interval`}
+          tooltip={i18n.str`Interval to which wire deadlines should be rounded up to.`}
+          help={i18n.str`As an example if you set the interval to day the wire transfer deadline will be rounded to midnight.`}
+          values={[
+            RoundingInterval.DAY,
+            RoundingInterval.WEEK,
+            RoundingInterval.SECOND,
+            RoundingInterval.HOUR,
+            RoundingInterval.MINUTE,
+            RoundingInterval.MONTH,
+            RoundingInterval.QUARTER,
+            RoundingInterval.YEAR,
+            RoundingInterval.NONE,
+          ]}
+          toStr={(v: RoundingInterval) => {
+            switch (v) {
+              case RoundingInterval.NONE:
+                return i18n.str`No rounding`;
+              case RoundingInterval.SECOND:
+                return i18n.str`To second`;
+              case RoundingInterval.MINUTE:
+                return i18n.str`To minute`;
+              case RoundingInterval.HOUR:
+                return i18n.str`To hour`;
+              case RoundingInterval.DAY:
+                return i18n.str`To day`;
+              case RoundingInterval.WEEK:
+                return i18n.str`To week`;
+              case RoundingInterval.MONTH:
+                return i18n.str`To month`;
+              case RoundingInterval.QUARTER:
+                return i18n.str`To quarter`;
+              case RoundingInterval.YEAR:
+                return i18n.str`To year`;
+            }
+          }}
+        />
       </FragmentPersonaFlag>
     </Fragment>
   );
