@@ -47,6 +47,8 @@ import { NotificationCard } from "../../../../components/menu/index.js";
 import { SolveMFAChallenges } from "../../../../components/SolveMFA.js";
 import { useSessionContext } from "../../../../context/session.js";
 import { undefinedIfEmpty } from "../../../../utils/table.js";
+import { getAvailableForPersona } from "../../../../components/menu/SideBar.js";
+import { UIElement, usePreference } from "../../../../hooks/preference.js";
 
 const TALER_SCREEN_ID = 29;
 
@@ -62,7 +64,7 @@ interface Props {
   onBack?: () => void;
 }
 
-const VALID_TOKEN_SCOPE = [
+const ALL_VALID_TOKEN_SCOPE = [
   "",
   LoginTokenScope.ReadOnly,
   LoginTokenScope.OrderSimple,
@@ -77,6 +79,15 @@ const VALID_TOKEN_SCOPE = [
   LoginTokenScope.OrderFull_Refreshable,
   LoginTokenScope.All,
 ];
+const SANE_VALID_TOKEN_SCOPE = [
+  "",
+  LoginTokenScope.ReadOnly,
+  LoginTokenScope.OrderSimple,
+  LoginTokenScope.OrderPos,
+  LoginTokenScope.OrderManagement,
+  LoginTokenScope.OrderFull,
+  LoginTokenScope.All,
+];
 
 export function CreatePage({ onCreated, onBack }: Props): VNode {
   const { i18n } = useTranslationContext();
@@ -90,6 +101,12 @@ export function CreatePage({ onCreated, onBack }: Props): VNode {
     description: !state.description ? i18n.str`Required` : undefined,
     scope: !state.scope ? i18n.str`Required` : undefined,
   });
+  const [{ persona }] = usePreference();
+  const scopeList = getAvailableForPersona(persona ?? "developer")[
+    UIElement.option_refreshableScopes
+  ]
+    ? ALL_VALID_TOKEN_SCOPE
+    : SANE_VALID_TOKEN_SCOPE;
 
   const hasErrors = errors !== undefined;
 
@@ -117,7 +134,8 @@ export function CreatePage({ onCreated, onBack }: Props): VNode {
   create.onFail = (fail) => {
     switch (fail.case) {
       case HttpStatusCode.Accepted:
-        return i18n.str`Second factor authentication required.`;
+        mfa.onChallengeRequired(fail.body);
+        return undefined;
       case HttpStatusCode.Unauthorized:
         return i18n.str`Check the password.`;
       case HttpStatusCode.NotFound:
@@ -178,7 +196,7 @@ export function CreatePage({ onCreated, onBack }: Props): VNode {
                 name="scope"
                 label={i18n.str`Scope`}
                 tooltip={i18n.str`The scope defines the set of permissions for the access token. Refreshable tokens has the permission to extend the expiration time.`}
-                values={VALID_TOKEN_SCOPE}
+                values={scopeList}
                 help={((s) => {
                   if (!s) return "";
                   switch (s) {
