@@ -50,6 +50,7 @@ export default function AccessTokenCreatePage({
           active
           onCancel={onConfirm}
           description={i18n.str`Access token created`}
+          label={i18n.str`Confirm`}
         >
           <div class="table-container">
             <table>
@@ -57,8 +58,7 @@ export default function AccessTokenCreatePage({
                 <tr>
                   <td colSpan={3}>
                     <i18n.Translate>
-                      Copy the access token velue and save it because you won't
-                      be able to get it again.
+                      Copy the value of the access token and save it, as you cannot retrieve it again.
                     </i18n.Translate>
                   </td>
                 </tr>
