@@ -23,6 +23,7 @@ import {
   HttpStatusCode,
   TalerError,
   TokenInfo,
+  TranslatedString,
   assertUnreachable,
 } from "@gnu-taler/taler-util";
 import {
@@ -113,8 +114,8 @@ export default function AccessTokenListPage({ onCreate }: Props): VNode {
         />
         {deleting && (
           <ConfirmModal
-            label={`Delete access token`}
-            description={deleting.description}
+            label={i18n.str`Delete access token`}
+            description={deleting.description as TranslatedString}
             danger
             active
             onCancel={() => setDeleting(null)}
