@@ -21,34 +21,34 @@
 
 import {
   AccessToken,
-  ChallengeResponse,
+  BasicOrTokenAuth,
   FacadeCredentials,
   HttpStatusCode,
   OperationFail,
   OperationOk,
   PaytoString,
+  Paytos,
   TalerError,
   TalerMerchantApi,
   TalerRevenueHttpClient,
   opFixedSuccess,
 } from "@gnu-taler/taler-util";
+import { readUnexpectedResponseDetails, type HttpRequestLibrary } from "@gnu-taler/taler-util/http";
 import {
   BrowserFetchHttpLib,
+  LocalNotificationBannerBulma,
   useChallengeHandler,
+  useLocalNotificationBetter,
   useTranslationContext,
 } from "@gnu-taler/web-util/browser";
 import { Fragment, VNode, h } from "preact";
 import { useState } from "preact/hooks";
 import { NotificationCard } from "../../../../components/menu/index.js";
+import { SolveMFAChallenges } from "../../../../components/SolveMFA.js";
 import { useSessionContext } from "../../../../context/session.js";
 import { Notification } from "../../../../utils/types.js";
 import { CreatePage } from "./CreatePage.js";
-import { BasicOrTokenAuth } from "@gnu-taler/taler-util";
-import type {
-  HttpRequestLibrary,
-  HeadersImpl,
-} from "@gnu-taler/taler-util/http";
-import { SolveMFAChallenges } from "../../../../components/SolveMFA.js";
+import { Session } from "inspector";
 
 export type Entity = TalerMerchantApi.AccountAddDetails;
 interface Props {
@@ -57,76 +57,22 @@ interface Props {
 }
 
 export default function CreateValidator({ onConfirm, onBack }: Props): VNode {
-  const { state, lib } = useSessionContext();
-  const [notif, setNotif] = useState<Notification | undefined>(undefined);
-
-  const { i18n } = useTranslationContext();
-
-  const mfa = useChallengeHandler();
-  const [doCreate, repeatCreate] = mfa.withMfaHandler(
-    ({ challengeIds, onChallengeRequired }) =>
-      async function doCreateImpl(request: Entity) {
-        try {
-          const resp = await lib.instance.addBankAccount(state.token, request, {
-            challengeIds,
-          });
-          if (resp.type === "fail") {
-            if (resp.case === HttpStatusCode.Accepted) {
-              onChallengeRequired(resp.body);
-              return;
-            }
-            setNotif({
-              message: i18n.str`Could not create account`,
-              type: "ERROR",
-              description: resp.detail?.hint,
-            });
-            return;
-          }
-          onConfirm();
-        } catch (error) {
-          setNotif({
-            message: i18n.str`Could not create account`,
-            type: "ERROR",
-            description: error instanceof Error ? error.message : String(error),
-          });
-        }
-      },
-  );
-
-  if (mfa.pendingChallenge) {
-    return (
-      <SolveMFAChallenges
-        currentChallenge={mfa.pendingChallenge}
-        onCompleted={repeatCreate}
-        onCancel={mfa.doCancelChallenge}
-      />
-    );
-  }
 
   return (
     <>
-      <NotificationCard notification={notif} />
-      <CreatePage onBack={onBack} onCreate={doCreate} />
+      <CreatePage onBack={onBack} onCreated={onConfirm} />
     </>
   );
 }
 
 export enum TestRevenueErrorType {
-  ANOTHER_ACCOUNT,
   CANT_VALIDATE,
 }
 
 export async function testRevenueAPI(
   revenueAPI: URL,
   creds: FacadeCredentials | undefined,
-): Promise<
-  | OperationOk<PaytoString>
-  | OperationFail<TestRevenueErrorType.CANT_VALIDATE>
-  | OperationFail<HttpStatusCode.NotFound>
-  | OperationFail<HttpStatusCode.Unauthorized>
-  | OperationFail<HttpStatusCode.BadRequest>
-  | TalerError
-> {
+) {
   const httpLib: HttpRequestLibrary = new BrowserFetchHttpLib();
   const api = new TalerRevenueHttpClient(revenueAPI.href, httpLib);
   const auth: BasicOrTokenAuth | undefined =
@@ -161,21 +107,17 @@ export async function testRevenueAPI(
 
     if (!resp.body.credit_account) {
       return {
-        type: "fail",
+        type: "fail" as const,
         case: TestRevenueErrorType.CANT_VALIDATE,
         detail: undefined,
       };
     }
-    return opFixedSuccess(resp.body.credit_account as PaytoString);
+    const str = resp.body.credit_account as Paytos.FullPaytoString
+    const uri = Paytos.fromString(str)
+    if (uri.type === "fail") return uri
+    return opFixedSuccess(uri.body);
   } catch (err) {
-    if (err instanceof TalerError) {
-      return err;
-      // return {
-      //   type: "fail",
-      //   case: TestRevenueErrorType.GENERIC_ERROR,
-      //   detail: err.errorDetail,
-      // };
-    }
+    // FIXME: should we return some other error code here?
     throw err;
   }
 }
