@@ -19,16 +19,24 @@
  * @author Sebastian Javier Marchano (sebasjm)
  */
 
-import { TalerMerchantApi } from "@gnu-taler/taler-util";
-import { useTranslationContext } from "@gnu-taler/web-util/browser";
-import { h, VNode } from "preact";
+import { HttpStatusCode, TalerMerchantApi } from "@gnu-taler/taler-util";
+import {
+  ButtonBetterBulma,
+  LocalNotificationBannerBulma,
+  SafeHandlerTemplate,
+  useLocalNotificationBetter,
+  useTranslationContext,
+} from "@gnu-taler/web-util/browser";
+import { Fragment, h, VNode } from "preact";
 import { StateUpdater, useState } from "preact/hooks";
+import { useSessionContext } from "../../../../context/session.js";
+
+const TALER_SCREEN_ID = 38;
 
 type Entity = TalerMerchantApi.CategoryListEntry;
 
 interface Props {
   devices: Entity[];
-  onDelete: (e: Entity) => void;
   onSelect: (e: Entity) => void;
   onCreate: () => void;
   onLoadMoreBefore?: () => void;
@@ -38,7 +46,6 @@ interface Props {
 export function CardTable({
   devices,
   onCreate,
-  onDelete,
   onSelect,
   onLoadMoreAfter,
   onLoadMoreBefore,
@@ -46,55 +53,73 @@ export function CardTable({
   const [rowSelection, rowSelectionHandler] = useState<string[]>([]);
 
   const { i18n } = useTranslationContext();
+  const { state: session, lib } = useSessionContext();
+  const [notification, safeFunctionHandler] = useLocalNotificationBetter();
 
+  const remove = safeFunctionHandler(
+    lib.instance.deleteCategory.bind(lib.instance),
+  ).lambda((id: string) => (!session.token ? undefined! : [session.token, id]));
+  remove.onSuccess = () => i18n.str`Category deleted`;
+  remove.onFail = (fail) => {
+    switch (fail.case) {
+      case HttpStatusCode.Unauthorized:
+        return i18n.str`Unauthorized`;
+      case HttpStatusCode.NotFound:
+        return i18n.str`Not found`;
+    }
+  };
   return (
-    <div class="card has-table">
-      <header class="card-header">
-        <p class="card-header-title">
-          <span class="icon">
-            <i class="mdi mdi-label" />
-          </span>
-          <i18n.Translate>Categories</i18n.Translate>
-        </p>
-        <div class="card-header-icon" aria-label="more options">
-          <span
-            class="has-tooltip-left"
-            data-tooltip={i18n.str`Add new devices`}
-          >
-            <button class="button is-info" type="button" onClick={onCreate}>
-              <span class="icon is-small">
-                <i class="mdi mdi-plus mdi-36px" />
-              </span>
-            </button>
-          </span>
-        </div>
-      </header>
-      <div class="card-content">
-        <div class="b-table has-pagination">
-          <div class="table-wrapper has-mobile-cards">
-            {devices.length > 0 ? (
-              <Table
-                instances={devices}
-                onDelete={onDelete}
-                onSelect={onSelect}
-                rowSelection={rowSelection}
-                rowSelectionHandler={rowSelectionHandler}
-                onLoadMoreAfter={onLoadMoreAfter}
-                onLoadMoreBefore={onLoadMoreBefore}
-              />
-            ) : (
-              <EmptyTable />
-            )}
+    <Fragment>
+      <LocalNotificationBannerBulma notification={notification} />
+
+      <div class="card has-table">
+        <header class="card-header">
+          <p class="card-header-title">
+            <span class="icon">
+              <i class="mdi mdi-label" />
+            </span>
+            <i18n.Translate>Categories</i18n.Translate>
+          </p>
+          <div class="card-header-icon" aria-label="more options">
+            <span
+              class="has-tooltip-left"
+              data-tooltip={i18n.str`Add new devices`}
+            >
+              <button class="button is-info" accessKey="+" type="button" onClick={onCreate}>
+                <span class="icon is-small">
+                  <i class="mdi mdi-plus mdi-36px" />
+                </span>
+              </button>
+            </span>
+          </div>
+        </header>
+        <div class="card-content">
+          <div class="b-table has-pagination">
+            <div class="table-wrapper has-mobile-cards">
+              {devices.length > 0 ? (
+                <Table
+                  instances={devices}
+                  onDelete={remove}
+                  onSelect={onSelect}
+                  rowSelection={rowSelection}
+                  rowSelectionHandler={rowSelectionHandler}
+                  onLoadMoreAfter={onLoadMoreAfter}
+                  onLoadMoreBefore={onLoadMoreBefore}
+                />
+              ) : (
+                <EmptyTable />
+              )}
+            </div>
           </div>
         </div>
       </div>
-    </div>
+    </Fragment>
   );
 }
 interface TableProps {
   rowSelection: string[];
   instances: Entity[];
-  onDelete: (e: Entity) => void;
+  onDelete: SafeHandlerTemplate<[id: string], unknown>;
   onSelect: (e: Entity) => void;
   rowSelectionHandler: StateUpdater<string[]>;
   onLoadMoreBefore?: () => void;
@@ -112,7 +137,7 @@ function Table({
   return (
     <div class="table-container">
       {onLoadMoreBefore && (
-        <button
+        <button type="button" 
           class="button is-fullwidth"
           data-tooltip={i18n.str`Load more devices before the first one`}
           onClick={onLoadMoreBefore}
@@ -159,13 +184,13 @@ function Table({
                 </td>
                 <td class="is-actions-cell right-sticky">
                   <div class="buttons is-right">
-                    <button
+                    <ButtonBetterBulma
                       class="button is-danger is-small has-tooltip-left"
                       data-tooltip={i18n.str`Delete selected category from the database`}
-                      onClick={() => onDelete(i)}
+                      onClick={onDelete.withArgs(String(i.category_id))}
                     >
                       <i18n.Translate>Delete</i18n.Translate>
-                    </button>
+                    </ButtonBetterBulma>
                   </div>
                 </td>
               </tr>
@@ -174,7 +199,7 @@ function Table({
         </tbody>
       </table>
       {onLoadMoreAfter && (
-        <button
+        <button type="button" 
           class="button is-fullwidth"
           data-tooltip={i18n.str`Load more devices after the last one`}
           onClick={onLoadMoreAfter}
