@@ -25,8 +25,10 @@ import {
   Amounts,
   Duration,
   HttpStatusCode,
+  OrderVersion,
   TalerMerchantApi,
   TalerProtocolDuration,
+  durationAdd,
 } from "@gnu-taler/taler-util";
 import {
   ButtonBetterBulma,
@@ -60,7 +62,6 @@ import { rate } from "../../../../utils/amount.js";
 import { undefinedIfEmpty } from "../../../../utils/table.js";
 import { FragmentPersonaFlag } from "../../../../components/menu/SideBar.js";
 
-
 const TALER_SCREEN_ID = 42;
 
 export interface Props {
@@ -72,6 +73,7 @@ export interface Props {
 interface InstanceConfig {
   use_stefan: boolean;
   default_pay_delay: TalerProtocolDuration;
+  default_refund_delay: TalerProtocolDuration;
   default_wire_transfer_delay: TalerProtocolDuration;
 }
 
@@ -79,15 +81,14 @@ function with_defaults(
   config: InstanceConfig,
   _currency: string,
 ): Partial<Entity> {
-  const defaultPayDeadline = Duration.fromTalerProtocolDuration(
+  const defaultPayDelay = Duration.fromTalerProtocolDuration(
     config.default_pay_delay,
   );
-  const defaultWireDeadline = Duration.fromTalerProtocolDuration(
+  const defaultWireDelay = Duration.fromTalerProtocolDuration(
     config.default_wire_transfer_delay,
   );
-  const defaultRefundDeadline = Duration.min(
-    defaultWireDeadline,
-    Duration.fromSpec({ days: 15 }),
+  const defaultRefundDelay = Duration.fromTalerProtocolDuration(
+    config.default_refund_delay,
   );
 
   return {
@@ -97,9 +98,9 @@ function with_defaults(
     payments: {
       max_fee: undefined,
       createToken: true,
-      pay_deadline: defaultPayDeadline,
-      refund_deadline: defaultRefundDeadline,
-      wire_transfer_deadline: defaultWireDeadline,
+      pay_delay: defaultPayDelay,
+      refund_delay: defaultRefundDelay,
+      wire_transfer_delay: defaultWireDelay,
     },
     shipping: {},
     extra: {},
@@ -126,10 +127,10 @@ interface Shipping extends TalerForm {
   fulfillment_message?: string;
 }
 interface Payments extends TalerForm {
-  refund_deadline: Duration;
-  pay_deadline: Duration;
-  wire_transfer_deadline: Duration;
-  auto_refund_deadline?: Duration;
+  pay_delay: Duration;
+  refund_delay: Duration;
+  wire_transfer_delay: Duration;
+  auto_refund_delay?: Duration;
   max_fee?: string;
   createToken: boolean;
   minimum_age?: number;
@@ -162,7 +163,6 @@ export function CreatePage({
   const instance_default = with_defaults(instanceConfig, config.currency);
   const [value, valueHandler] = useState(instance_default);
   const zero = Amounts.zeroOfCurrency(config.currency);
-  const [pref, updatePrefs] = usePreference();
   const inventoryList = Object.values(value.inventoryProducts || {});
   const productList = Object.values(value.products || {});
 
@@ -184,40 +184,18 @@ export function CreatePage({
             : undefined,
     }),
     payments: undefinedIfEmpty({
-      refund_deadline: !value.payments?.refund_deadline
-        ? undefined
-        : value.payments.pay_deadline &&
-            Duration.cmp(
-              value.payments.refund_deadline,
-              value.payments.pay_deadline,
-            ) === -1
-          ? i18n.str`The refund deadline cannot be earlier than the payment deadline.`
-          : value.payments.wire_transfer_deadline &&
-              Duration.cmp(
-                value.payments.wire_transfer_deadline,
-                value.payments.refund_deadline,
-              ) === -1
-            ? i18n.str`Wire transfer deadline can't be before refund deadline`
-            : undefined,
-      pay_deadline: !value.payments?.pay_deadline
-        ? i18n.str`Required`
-        : value.payments.wire_transfer_deadline &&
-            Duration.cmp(
-              value.payments.wire_transfer_deadline,
-              value.payments.pay_deadline,
-            ) === -1
-          ? i18n.str`Wire transfer deadline can't be before pay deadline`
-          : undefined,
-      wire_transfer_deadline: !value.payments?.wire_transfer_deadline
+      wire_transfer_delay: !value.payments?.wire_transfer_delay
         ? i18n.str`Required`
         : undefined,
-      auto_refund_deadline: !value.payments?.auto_refund_deadline
+      // refund_delay: !value.payments?.refund_delay ? i18n.str`Required` : undefined,
+      pay_delay: !value.payments?.pay_delay ? i18n.str`Required` : undefined,
+      auto_refund_delay: !value.payments?.auto_refund_delay
         ? undefined
-        : !value.payments?.refund_deadline
+        : !value.payments?.refund_delay
           ? i18n.str`Must have a refund deadline`
           : Duration.cmp(
-                value.payments.refund_deadline,
-                value.payments.auto_refund_deadline,
+                value.payments.refund_delay,
+                value.payments.auto_refund_delay,
               ) == -1
             ? i18n.str`Auto refund can't be after refund deadline`
             : undefined,
@@ -243,45 +221,84 @@ export function CreatePage({
             : undefined,
     }),
   });
-  const hasErrors = errors !== undefined;
 
   const order = value;
   const price = order.pricing?.order_price as AmountString | undefined;
   const summary = order.pricing?.summary;
 
+  const payDelay = !value.payments?.pay_delay
+    ? Duration.getZero()
+    : value.payments.pay_delay;
+
+  const refundDelay = !value.payments?.refund_delay
+    ? Duration.getZero()
+    : Duration.add(
+        payDelay,
+        !value.payments?.refund_delay
+          ? Duration.getZero()
+          : value.payments.refund_delay,
+      );
+
+  const autoRefundDelay = !value.payments?.auto_refund_delay
+    ? Duration.getZero()
+    : Duration.add(
+        payDelay,
+        !value.payments?.auto_refund_delay
+          ? Duration.getZero()
+          : value.payments.auto_refund_delay,
+      );
+
+  const wireDelay = !value.payments?.wire_transfer_delay
+    ? Duration.getZero()
+    : Duration.add(
+        refundDelay,
+        !value.payments?.wire_transfer_delay
+          ? Duration.getZero()
+          : value.payments.wire_transfer_delay,
+      );
+
+  const pay_deadline = !value.payments?.pay_delay
+    ? undefined
+    : AbsoluteTime.toProtocolTimestamp(
+        AbsoluteTime.addDuration(AbsoluteTime.now(), payDelay),
+      );
+
+  const refund_deadline = !value.payments?.refund_delay
+    ? undefined
+    : AbsoluteTime.toProtocolTimestamp(
+        AbsoluteTime.addDuration(AbsoluteTime.now(), refundDelay),
+      );
+
+  const wire_transfer_deadline =
+    !value.payments || !value.payments.wire_transfer_delay
+      ? undefined
+      : AbsoluteTime.toProtocolTimestamp(
+          AbsoluteTime.addDuration(AbsoluteTime.now(), wireDelay),
+        );
+
   const request: undefined | TalerMerchantApi.PostOrderRequest =
     !value.payments || !value.shipping || !price || !summary
       ? undefined
       : {
           order: {
+            version: OrderVersion.V0,
             amount: price,
+            // version: OrderVersion.V1,
+            // choices: [{
+            //   amount: price,
+            //   max_fee: value.payments.max_fee as AmountString,
+            // }],
             summary: summary,
             products: productList,
             extra: undefinedIfEmpty(value.extra),
-            pay_deadline: AbsoluteTime.toProtocolTimestamp(
-              AbsoluteTime.addDuration(
-                AbsoluteTime.now(),
-                value.payments.pay_deadline!,
-              ),
-            ),
-            wire_transfer_deadline: AbsoluteTime.toProtocolTimestamp(
-              AbsoluteTime.addDuration(
-                AbsoluteTime.now(),
-                value.payments.wire_transfer_deadline!,
-              ),
-            ),
-            refund_deadline: AbsoluteTime.toProtocolTimestamp(
-              AbsoluteTime.addDuration(
-                AbsoluteTime.now(),
-                value.payments.refund_deadline!,
-              ),
-            ),
-            auto_refund: value.payments.auto_refund_deadline
+            pay_deadline,
+            refund_deadline,
+            wire_transfer_deadline,
+            auto_refund: value.payments.auto_refund_delay
               ? Duration.toTalerProtocolDuration(
-                  value.payments.auto_refund_deadline,
+                  value.payments.auto_refund_delay,
                 )
               : undefined,
-            max_fee: value.payments.max_fee as AmountString,
             delivery_date: value.shipping.delivery_date
               ? { t_s: value.shipping.delivery_date.getTime() / 1000 }
               : undefined,
@@ -405,11 +422,11 @@ export function CreatePage({
 
   // if there is no default pay deadline
   const noDefault_payDeadline =
-    !instance_default.payments || !instance_default.payments.pay_deadline;
+    !instance_default.payments || !instance_default.payments.pay_delay;
   // and there is no default wire deadline
   const noDefault_wireDeadline =
     !instance_default.payments ||
-    !instance_default.payments.wire_transfer_deadline;
+    !instance_default.payments.wire_transfer_delay;
   // user required to set the taler options
   const requiresSomeTalerOptions =
     noDefault_payDeadline || noDefault_wireDeadline;
@@ -565,17 +582,13 @@ export function CreatePage({
                     point={UIElement.option_advanceOrderCreation}
                     showAnywayIf={
                       noDefault_payDeadline ||
-                      errors?.payments?.pay_deadline !== undefined
+                      errors?.payments?.pay_delay !== undefined
                     }
                   >
                     <InputDuration
-                      name="payments.pay_deadline"
+                      name="payments.pay_delay"
                       label={i18n.str`Payment time`}
-                      help={
-                        <DeadlineHelp duration={value.payments?.pay_deadline} />
-                      }
-                      withForever
-                      withoutClear
+                      help={<DeadlineHelp duration={payDelay} />}
                       tooltip={i18n.str`Time for the customer to pay before the offer expires. Inventory products will be reserved until this deadline. The time starts after the order is created.`}
                       side={
                         <span>
@@ -587,8 +600,8 @@ export function CreatePage({
                                 ...value,
                                 payments: {
                                   ...(value.payments ?? {}),
-                                  pay_deadline:
-                                    instance_default.payments?.pay_deadline,
+                                  pay_delay:
+                                    instance_default.payments?.pay_delay,
                                 },
                               };
                               valueHandler(c);
@@ -602,20 +615,12 @@ export function CreatePage({
                   </FragmentPersonaFlag>
                   <FragmentPersonaFlag
                     point={UIElement.option_advanceOrderCreation}
-                    showAnywayIf={
-                      errors?.payments?.refund_deadline !== undefined
-                    }
+                    showAnywayIf={errors?.payments?.refund_delay !== undefined}
                   >
                     <InputDuration
-                      name="payments.refund_deadline"
+                      name="payments.refund_delay"
                       label={i18n.str`Refund time`}
-                      help={
-                        <DeadlineHelp
-                          duration={value.payments?.refund_deadline}
-                        />
-                      }
-                      withForever
-                      withoutClear
+                      help={<DeadlineHelp duration={refundDelay} />}
                       tooltip={i18n.str`Time while the order can be refunded by the merchant. Time starts after the order is created.`}
                       side={
                         <span>
@@ -627,8 +632,8 @@ export function CreatePage({
                                 ...value,
                                 payments: {
                                   ...(value.payments ?? {}),
-                                  refund_deadline:
-                                    instance_default.payments?.refund_deadline,
+                                  refund_delay:
+                                    instance_default.payments?.refund_delay,
                                 },
                               });
                             }}
@@ -644,19 +649,13 @@ export function CreatePage({
                     point={UIElement.option_advanceOrderCreation}
                     showAnywayIf={
                       noDefault_wireDeadline ||
-                      errors?.payments?.wire_transfer_deadline !== undefined
+                      errors?.payments?.wire_transfer_delay !== undefined
                     }
                   >
                     <InputDuration
-                      name="payments.wire_transfer_deadline"
+                      name="payments.wire_transfer_delay"
                       label={i18n.str`Wire transfer time`}
-                      help={
-                        <DeadlineHelp
-                          duration={value.payments?.wire_transfer_deadline}
-                        />
-                      }
-                      withoutClear
-                      withForever
+                      help={<DeadlineHelp duration={wireDelay} />}
                       tooltip={i18n.str`Time for the exchange to make the wire transfer. Time starts after the order is created.`}
                       side={
                         <span>
@@ -668,9 +667,9 @@ export function CreatePage({
                                 ...value,
                                 payments: {
                                   ...(value.payments ?? {}),
-                                  wire_transfer_deadline:
+                                  wire_transfer_delay:
                                     instance_default.payments
-                                      ?.wire_transfer_deadline,
+                                      ?.wire_transfer_delay,
                                 },
                               });
                             }}
@@ -684,17 +683,13 @@ export function CreatePage({
                   <FragmentPersonaFlag
                     point={UIElement.option_advanceOrderCreation}
                     showAnywayIf={
-                      errors?.payments?.auto_refund_deadline !== undefined
+                      errors?.payments?.auto_refund_delay !== undefined
                     }
                   >
                     <InputDuration
-                      name="payments.auto_refund_deadline"
+                      name="payments.auto_refund_delay"
                       label={i18n.str`Auto-refund time`}
-                      help={
-                        <DeadlineHelp
-                          duration={value.payments?.auto_refund_deadline}
-                        />
-                      }
+                      help={<DeadlineHelp duration={autoRefundDelay} />}
                       tooltip={i18n.str`Time until which the wallet will automatically check for refunds without user interaction.`}
                       withForever
                     />
@@ -870,7 +865,8 @@ function DeadlineHelp({ duration }: { duration?: Duration }): VNode {
       clearInterval(iid);
     };
   });
-  if (!duration) return <i18n.Translate>Disabled</i18n.Translate>;
+  if (!duration || !duration.d_ms)
+    return <i18n.Translate>Disabled</i18n.Translate>;
   const when = AbsoluteTime.addDuration(now, duration);
   if (when.t_ms === "never")
     return <i18n.Translate>No deadline</i18n.Translate>;
