@@ -20,17 +20,19 @@
  */
 
 import {
+  AbsoluteTime,
   AmountJson,
   Amounts,
   HostPortPath,
   MerchantContractVersion,
   TalerMerchantApi,
+  assertUnreachable,
   stringifyRefundUri,
 } from "@gnu-taler/taler-util";
 import { useTranslationContext } from "@gnu-taler/web-util/browser";
 import { format, formatDistance } from "date-fns";
 import { Fragment, VNode, h } from "preact";
-import { useState } from "preact/hooks";
+import { useEffect, useState } from "preact/hooks";
 import { FormProvider } from "../../../../components/form/FormProvider.js";
 import { Input } from "../../../../components/form/Input.js";
 import { InputCurrency } from "../../../../components/form/InputCurrency.js";
@@ -41,6 +43,7 @@ import { InputLocation } from "../../../../components/form/InputLocation.js";
 import { TextField } from "../../../../components/form/TextField.js";
 import { ProductList } from "../../../../components/product/ProductList.js";
 import { useSessionContext } from "../../../../context/session.js";
+import { useWaitForOrderPayment } from "../../../../hooks/order.js";
 import {
   datetimeFormatForSettings,
   usePreference,
@@ -48,12 +51,14 @@ import {
 import { mergeRefunds } from "../../../../utils/amount.js";
 import { RefundModal } from "../list/Table.js";
 import { Event, Timeline } from "./Timeline.js";
-
+import { NotificationCard } from "../../../../components/menu/index.js";
 
 const TALER_SCREEN_ID = 44;
 
 type Entity = TalerMerchantApi.MerchantOrderStatusResponse;
-type CT = TalerMerchantApi.MerchantContractTermsV0;
+type CT = TalerMerchantApi.MerchantContractTerms;
+type CT0 = TalerMerchantApi.MerchantContractTermsV0;
+type CT1 = TalerMerchantApi.MerchantContractTermsV1;
 
 export interface Props {
   onBack: () => void;
@@ -69,62 +74,76 @@ type Unpaid = TalerMerchantApi.CheckPaymentUnpaidResponse;
 type Claimed = TalerMerchantApi.CheckPaymentClaimedResponse;
 
 function ContractTerms({ value }: { value: CT }) {
+  if (value.version === undefined) {
+    return <ContractTerms_V0 value={value} />;
+  }
+  switch (value.version) {
+    case MerchantContractVersion.V0:
+      return <ContractTerms_V0 value={value} />;
+    case MerchantContractVersion.V1:
+      return <ContractTerms_V1 value={value} />;
+    default:
+      assertUnreachable(value.version);
+  }
+}
+
+function ContractTerms_V0({ value }: { value: CT0 }) {
   const { i18n } = useTranslationContext();
 
   return (
     <InputGroup name="contract_terms" label={i18n.str`Contract terms`}>
-      <FormProvider<CT> object={value} valueHandler={null}>
-        <Input<CT>
+      <FormProvider<CT0> object={value} valueHandler={null}>
+        <Input<CT0>
           readonly
           name="summary"
           label={i18n.str`Summary`}
           tooltip={i18n.str`Human-readable description of the whole purchase`}
         />
-        <InputCurrency<CT>
+        <InputCurrency<CT0>
           readonly
           name="amount"
           label={i18n.str`Amount`}
           tooltip={i18n.str`Total price for the transaction`}
         />
         {value.fulfillment_url && (
-          <Input<CT>
+          <Input<CT0>
             readonly
             name="fulfillment_url"
             label={i18n.str`Fulfillment URL`}
             tooltip={i18n.str`URL for this purchase`}
           />
         )}
-        <Input<CT>
+        <Input<CT0>
           readonly
           name="max_fee"
           label={i18n.str`Max fee`}
           tooltip={i18n.str`Maximum total deposit fee accepted by the merchant for this contract`}
         />
-        <InputDate<CT>
+        <InputDate<CT0>
           readonly
           name="timestamp"
           label={i18n.str`Created at`}
           tooltip={i18n.str`Time when this contract was generated`}
         />
-        <InputDate<CT>
+        <InputDate<CT0>
           readonly
           name="refund_deadline"
           label={i18n.str`Refund deadline`}
           tooltip={i18n.str`After this deadline has passed, no refunds will be accepted.`}
         />
-        <InputDate<CT>
+        <InputDate<CT0>
           readonly
           name="pay_deadline"
           label={i18n.str`Payment deadline`}
           tooltip={i18n.str`After this deadline, the merchant won't accept payments for the contract`}
         />
-        <InputDate<CT>
+        <InputDate<CT0>
           readonly
           name="wire_transfer_deadline"
           label={i18n.str`Wire transfer deadline`}
           tooltip={i18n.str`Transfer deadline for the exchange`}
         />
-        <InputDate<CT>
+        <InputDate<CT0>
           readonly
           name="delivery_date"
           label={i18n.str`Delivery date`}
@@ -137,13 +156,99 @@ function ContractTerms({ value }: { value: CT }) {
         >
           <InputLocation name="delivery_location" />
         </InputGroup>
-        <InputDuration<CT>
+        <InputDuration<CT0>
           readonly
           name="auto_refund"
           label={i18n.str`Auto-refund delay`}
           tooltip={i18n.str`How long the wallet should try to get an automatic refund for the purchase`}
         />
-        <Input<CT>
+        <Input<CT0>
+          readonly
+          name="extra"
+          label={i18n.str`Extra info`}
+          tooltip={i18n.str`Extra data that is only interpreted by the merchant frontend`}
+        />
+      </FormProvider>
+    </InputGroup>
+  );
+}
+
+function ContractTerms_V1({ value }: { value: CT1 }) {
+  const { i18n } = useTranslationContext();
+
+  return (
+    <InputGroup name="contract_terms" label={i18n.str`Contract terms`}>
+      <FormProvider<CT1> object={value} valueHandler={null}>
+        <Input<CT1>
+          readonly
+          name="summary"
+          label={i18n.str`Summary`}
+          tooltip={i18n.str`Human-readable description of the whole purchase`}
+        />
+        {/* <InputCurrency<CT1>
+          readonly
+          name="amount"
+          label={i18n.str`Amount`}
+          tooltip={i18n.str`Total price for the transaction`}
+        />
+        <Input<CT1>
+          readonly
+          name="max_fee"
+          label={i18n.str`Max fee`}
+          tooltip={i18n.str`Maximum total deposit fee accepted by the merchant for this contract`}
+        /> */}
+        {value.fulfillment_url && (
+          <Input<CT1>
+            readonly
+            name="fulfillment_url"
+            label={i18n.str`Fulfillment URL`}
+            tooltip={i18n.str`URL for this purchase`}
+          />
+        )}
+        <InputDate<CT1>
+          readonly
+          name="timestamp"
+          label={i18n.str`Created at`}
+          tooltip={i18n.str`Time when this contract was generated`}
+        />
+        <InputDate<CT1>
+          readonly
+          name="refund_deadline"
+          label={i18n.str`Refund deadline`}
+          tooltip={i18n.str`After this deadline has passed, no refunds will be accepted.`}
+        />
+        <InputDate<CT1>
+          readonly
+          name="pay_deadline"
+          label={i18n.str`Payment deadline`}
+          tooltip={i18n.str`After this deadline, the merchant won't accept payments for the contract`}
+        />
+        <InputDate<CT1>
+          readonly
+          name="wire_transfer_deadline"
+          label={i18n.str`Wire transfer deadline`}
+          tooltip={i18n.str`Transfer deadline for the exchange`}
+        />
+        <InputDate<CT1>
+          readonly
+          name="delivery_date"
+          label={i18n.str`Delivery date`}
+          tooltip={i18n.str`Time indicating when the order should be delivered`}
+        />
+        <InputGroup
+          name="delivery_location"
+          label={i18n.str`Delivery location`}
+          tooltip={i18n.str`Where the order will be delivered`}
+        >
+          <InputLocation name="delivery_location" />
+        </InputGroup>
+        <InputDuration<CT1>
+          readonly
+          name="auto_refund"
+          label={i18n.str`Auto-refund delay`}
+          tooltip={i18n.str`How long the wallet should try to get an automatic refund for the purchase`}
+        />
+        <Input<CT1>
           readonly
           name="extra"
           label={i18n.str`Extra info`}
@@ -161,12 +266,10 @@ function ClaimedPage({
   id: string;
   order: TalerMerchantApi.CheckPaymentClaimedResponse;
 }) {
-  if (order.contract_terms.version !== undefined &&
-    order.contract_terms.version !== MerchantContractVersion.V0
-  ) {
-    return <div>Unsupported contract version {order.contract_terms.version}</div>;
-  }
-
+  const { i18n } = useTranslationContext();
+  const [value, valueHandler] = useState<Partial<Claimed>>(order);
+  const [settings] = usePreference();
+  useWaitForOrderPayment(id, order);
   const now = new Date();
   const refundable =
     order.contract_terms.refund_deadline.t_s !== "never" &&
@@ -175,46 +278,35 @@ function ClaimedPage({
   if (order.contract_terms.timestamp.t_s !== "never") {
     events.push({
       when: new Date(order.contract_terms.timestamp.t_s * 1000),
-      description: "order created",
+      description: i18n.str`order created`,
       type: "start",
     });
   }
   if (order.contract_terms.pay_deadline.t_s !== "never") {
     events.push({
       when: new Date(order.contract_terms.pay_deadline.t_s * 1000),
-      description: "pay deadline",
-      type: "deadline",
+      description: i18n.str`pay deadline`,
+      type: "pay-deadline",
     });
   }
   if (order.contract_terms.refund_deadline.t_s !== "never" && refundable) {
     events.push({
       when: new Date(order.contract_terms.refund_deadline.t_s * 1000),
-      description: "refund deadline",
-      type: "deadline",
+      description: i18n.str`refund deadline`,
+      type: "refund-deadline",
     });
   }
-  // if (order.contract_terms.wire_transfer_deadline.t_s !== "never") {
-  //   events.push({
-  //     when: new Date(order.contract_terms.wire_transfer_deadline.t_s * 1000),
-  //     description: "wire deadline",
-  //     type: "deadline",
-  //   });
-  // }
   if (
     order.contract_terms.delivery_date &&
     order.contract_terms.delivery_date.t_s !== "never"
   ) {
     events.push({
       when: new Date(order.contract_terms.delivery_date?.t_s * 1000),
-      description: "delivery",
+      description: i18n.str`delivery`,
       type: "delivery",
     });
   }
 
-  const [value, valueHandler] = useState<Partial<Claimed>>(order);
-  const { i18n } = useTranslationContext();
-  const [settings] = usePreference();
-
   return (
     <div>
       <section class="section">
@@ -234,13 +326,14 @@ function ClaimedPage({
                   </div>
                 </div>
 
-                <div class="level">
+                {/* {order.contract_terms.version} */}
+                {/* <div class="level">
                   <div class="level-left">
                     <div class="level-item">
                       <h1 class="title">{order.contract_terms.amount}</h1>
                     </div>
                   </div>
-                </div>
+                </div> */}
 
                 <div class="level">
                   <div class="level-left" style={{ maxWidth: "100%" }}>
@@ -300,10 +393,21 @@ function ClaimedPage({
                       readonly
                       label={i18n.str`Amount`}
                     />
-                    <Input<Claimed>
+                    <Input<Paid>
                       name="order_status"
                       readonly
                       label={i18n.str`Order status`}
+                      toStr={(d) => {
+                        switch (d) {
+                          case "paid":
+                            return i18n.str`Paid`;
+                          case "claimed":
+                            return i18n.str`Claimed`;
+                          case "unpiad":
+                            return i18n.str`Unpaid`;
+                        }
+                        return d;
+                      }}
                     />
                   </FormProvider>
                 </div>
@@ -319,10 +423,7 @@ function ClaimedPage({
               </Fragment>
             ) : undefined}
 
-            {value.contract_terms && (
-              value.contract_terms.version === undefined
-                || value.contract_terms.version === MerchantContractVersion.V0
-            ) && (
+            {!value.contract_terms ? undefined : (
               <ContractTerms value={value.contract_terms} />
             )}
           </div>
@@ -341,30 +442,38 @@ function PaidPage({
   order: TalerMerchantApi.CheckPaymentPaidResponse;
   onRefund: (id: string) => void;
 }) {
-  if (order.contract_terms.version !== undefined &&
-    order.contract_terms.version !== MerchantContractVersion.V0
-  ) {
-    return <div>Unsupported contract version {order.contract_terms.version}</div>;
-  }
+  const [value, valueHandler] = useState<Partial<Paid>>(order);
+  const { state } = useSessionContext();
+  const { i18n } = useTranslationContext();
 
   const now = new Date();
-  const refundable =
+  const merchantCanRefund =
     order.contract_terms.refund_deadline.t_s !== "never" &&
     now.getTime() < order.contract_terms.refund_deadline.t_s * 1000;
 
+  const wireDeadlineInThePast =
+    order.contract_terms.wire_transfer_deadline.t_s !== "never" &&
+    order.contract_terms.wire_transfer_deadline.t_s * 1000 < now.getTime();
+  const [_, reload] = useState(false);
+  useEffect(() => {
+    if (wireDeadlineInThePast) return;
+    const deadline = order.contract_terms.wire_transfer_deadline;
+    if (deadline.t_s === "never") return;
+    const diff = deadline.t_s * 1000 - new Date().getTime();
+    setTimeout(() => {
+      reload(true);
+    }, diff + 100);
+  }, []);
+
   const events: Event[] = [];
-  if (order.contract_terms.refund_deadline.t_s !== "never" && refundable) {
+  if (
+    order.contract_terms.refund_deadline.t_s !== "never" &&
+    merchantCanRefund
+  ) {
     events.push({
       when: new Date(order.contract_terms.refund_deadline.t_s * 1000),
-      description: "refund deadline",
-      type: "deadline",
-    });
-  }
-  if (order.contract_terms.wire_transfer_deadline.t_s !== "never") {
-    events.push({
-      when: new Date(order.contract_terms.wire_transfer_deadline.t_s * 1000),
-      description: "wire deadline",
-      type: "deadline",
+      description: i18n.str`refund deadline`,
+      type: "refund-deadline",
     });
   }
   if (
@@ -374,87 +483,131 @@ function PaidPage({
     if (order.contract_terms.delivery_date)
       events.push({
         when: new Date(order.contract_terms.delivery_date?.t_s * 1000),
-        description: "delivery",
+        description: i18n.str`delivery`,
         type: "delivery",
       });
   }
-  order.refund_details.reduce(mergeRefunds, []).forEach((e) => {
-    if (e.timestamp.t_s !== "never") {
+
+  const sortedOrders = [...order.refund_details].sort((a, b) =>
+    AbsoluteTime.cmp(
+      AbsoluteTime.fromProtocolTimestamp(a.timestamp),
+      AbsoluteTime.fromProtocolTimestamp(b.timestamp),
+    ),
+  );
+  sortedOrders.reduce(mergeRefunds, []).forEach((e) => {
+    if (e.timestamp.t_s === "never") return;
+    if (e.pending) {
+      if (wireDeadlineInThePast) {
+        events.push({
+          when: new Date(e.timestamp.t_s * 1000),
+          description: !e.reason
+            ? i18n.str`refund missed: ${e.amount}`
+            : i18n.str`refund missed: ${e.amount}: ${e.reason}`,
+          type: "refund-missed",
+        });
+      } else {
+        events.push({
+          when: new Date(e.timestamp.t_s * 1000),
+          description: !e.reason
+            ? i18n.str`refund created: ${e.amount}`
+            : i18n.str`refund created: ${e.amount}: ${e.reason}`,
+          type: "refund-created",
+        });
+      }
+    } else {
       events.push({
         when: new Date(e.timestamp.t_s * 1000),
-        description: `refund: ${e.amount}: ${e.reason}`,
-        type: e.pending ? "refund" : "refund-taken",
+        description: !e.reason
+          ? i18n.str`refund taken: ${e.amount}`
+          : i18n.str`refund taken: ${e.amount}: ${e.reason}`,
+        type: "refund-taken",
       });
     }
   });
-  const ra = !order.refunded ? undefined : Amounts.parse(order.refund_amount);
-  const am = Amounts.parseOrThrow(order.contract_terms.amount);
-  if (ra && Amounts.cmp(ra, am) === 1) {
-    if (order.wire_details && order.wire_details.length) {
-      if (order.wire_details.length > 1) {
-        let last: TalerMerchantApi.TransactionWireTransfer | null = null;
-        let first: TalerMerchantApi.TransactionWireTransfer | null = null;
-        let total: AmountJson | null = null;
 
-        order.wire_details.forEach((w) => {
-          if (last === null || last.execution_time.t_s < w.execution_time.t_s) {
-            last = w;
-          }
-          if (
-            first === null ||
-            first.execution_time.t_s > w.execution_time.t_s
-          ) {
-            first = w;
-          }
-          total =
-            total === null
-              ? Amounts.parseOrThrow(w.amount)
-              : Amounts.add(total, Amounts.parseOrThrow(w.amount)).amount;
-        });
-        const last_time = last!.execution_time.t_s;
-        if (last_time !== "never") {
-          events.push({
-            when: new Date(last_time * 1000),
-            description: `wired ${Amounts.stringify(total!)}`,
-            type: "wired-range",
-          });
-        }
-        const first_time = first!.execution_time.t_s;
-        if (first_time !== "never") {
-          events.push({
-            when: new Date(first_time * 1000),
-            description: `wire transfer started...`,
-            type: "wired-range",
-          });
-        }
+  const orderAmounts = getOrderAmountAndWirefee(order);
+  if (orderAmounts === "v1-without-index") {
+    return (
+      <i18n.Translate>
+        The contract terms has a v1 order without choices_index.
+      </i18n.Translate>
+    );
+  }
+  if (orderAmounts === "v1-wrong-index") {
+    return (
+      <i18n.Translate>
+        The contract terms has a v1 order with a bad choices_index.
+      </i18n.Translate>
+    );
+  }
+  const { amount } = orderAmounts;
+
+  const wireMap: Record<
+    string,
+    {
+      time: number;
+      amount: AmountJson;
+      confirmed: boolean;
+    }
+  > = {};
+
+  let hasUnconfirmedWireTransfer = false;
+  if (order.wire_details.length) {
+    order.wire_details.forEach((w) => {
+      if (!wireMap[w.wtid]) {
+        const info = {
+          time:
+            w.execution_time.t_s === "never" ? 0 : w.execution_time.t_s * 1000,
+          amount: Amounts.parseOrThrow(w.amount),
+          confirmed: w.confirmed,
+        };
+        wireMap[w.wtid] = info;
       } else {
-        order.wire_details.forEach((e) => {
-          if (e.execution_time.t_s !== "never") {
-            events.push({
-              when: new Date(e.execution_time.t_s * 1000),
-              description: `wired ${e.amount}`,
-              type: "wired",
-            });
-          }
-        });
+        const info = {
+          time: wireMap[w.wtid].time, // keep the first time
+          confirmed: wireMap[w.wtid].confirmed && w.confirmed, // both should be confirmed
+          amount: Amounts.add(
+            Amounts.parseOrThrow(w.amount),
+            wireMap[w.wtid].amount,
+          ).amount,
+        };
+        wireMap[w.wtid] = info;
       }
+      hasUnconfirmedWireTransfer = hasUnconfirmedWireTransfer || !w.confirmed;
+    });
+    Object.values(wireMap).forEach((info) => {
+      events.push({
+        when: new Date(info.time),
+        description: i18n.str`wired ${Amounts.stringify(info.amount)}`,
+        type: info.confirmed ? "wired-confirmed" : "wired-pending",
+      });
+    });
+  } else {
+    if (order.contract_terms.wire_transfer_deadline.t_s !== "never") {
+      events.push({
+        when: new Date(order.contract_terms.wire_transfer_deadline.t_s * 1000),
+        description: i18n.str`wire deadline`,
+        type: "wire-deadline",
+      });
     }
   }
 
+  events.sort((a, b) => {
+    return b.when.getTime() - a.when.getTime();
+  });
+
   const nextEvent = events.find((e) => {
     return e.when.getTime() > now.getTime();
   });
 
-  const [value, valueHandler] = useState<Partial<Paid>>(order);
-  const { state } = useSessionContext();
+  const refundURI =
+    !order.refunded || wireDeadlineInThePast
+      ? undefined
+      : stringifyRefundUri({
+          merchantBaseUrl: state.backendUrl.href as HostPortPath,
+          orderId: order.contract_terms.order_id,
+        });
 
-  const refundurl = stringifyRefundUri({
-    merchantBaseUrl: state.backendUrl.href as HostPortPath,
-    orderId: order.contract_terms.order_id,
-  });
-  const { i18n } = useTranslationContext();
-
-  const amount = Amounts.parseOrThrow(order.contract_terms.amount);
   const refund_taken = order.refund_details.reduce((prev, cur) => {
     if (cur.pending) return prev;
     return Amounts.add(prev, Amounts.parseOrThrow(cur.amount)).amount;
@@ -492,7 +645,7 @@ function PaidPage({
                 <div class="level">
                   <div class="level-left">
                     <div class="level-item">
-                      <h1 class="title">{order.contract_terms.amount}</h1>
+                      <h1 class="title">{Amounts.stringify(amount)}</h1>
                     </div>
                   </div>
                   <div class="level-right">
@@ -502,14 +655,15 @@ function PaidPage({
                           <span
                             class="has-tooltip-left"
                             data-tooltip={
-                              refundable
+                              merchantCanRefund
                                 ? i18n.str`Refund order`
                                 : i18n.str`Not refundable`
                             }
                           >
-                            <button type="button" 
+                            <button
+                              type="button"
                               class="button is-danger"
-                              disabled={!refundable}
+                              disabled={!merchantCanRefund}
                               onClick={() => onRefund(id)}
                             >
                               <i18n.Translate>Refund</i18n.Translate>
@@ -549,6 +703,16 @@ function PaidPage({
               </div>
             </section>
 
+            {!hasUnconfirmedWireTransfer ? undefined : (
+              <NotificationCard
+                notification={{
+                  type: "INFO",
+                  message: i18n.str`The order was wired.`,
+                  description: i18n.str`Bank processing can take a few business days, depending on your bank.`,
+                }}
+              />
+            )}
+
             <section class="section">
               <div class="columns">
                 <div class="column is-4">
@@ -584,6 +748,17 @@ function PaidPage({
                       name="order_status"
                       readonly
                       label={i18n.str`Order status`}
+                      toStr={(d) => {
+                        switch (d) {
+                          case "paid":
+                            return i18n.str`Paid`;
+                          case "claimed":
+                            return i18n.str`Claimed`;
+                          case "unpiad":
+                            return i18n.str`Unpaid`;
+                        }
+                        return d;
+                      }}
                     />
                     <TextField<Paid>
                       name="order_status_url"
@@ -597,13 +772,13 @@ function PaidPage({
                         {order.order_status_url}
                       </a>
                     </TextField>
-                    {order.refunded && (
+                    {refundURI && (
                       <TextField<Paid>
                         name="order_status_url"
                         label={i18n.str`Refund URI`}
                       >
-                        <a target="_blank" rel="noreferrer" href={refundurl}>
-                          {refundurl}
+                        <a target="_blank" rel="noreferrer" href={refundURI}>
+                          {refundURI}
                         </a>
                       </TextField>
                     )}
@@ -621,10 +796,7 @@ function PaidPage({
               </Fragment>
             ) : undefined}
 
-            {value.contract_terms && (
-              value.contract_terms.version === undefined
-                || value.contract_terms.version === MerchantContractVersion.V0
-            ) && (
+            {!value.contract_terms ? undefined : (
               <ContractTerms value={value.contract_terms} />
             )}
           </div>
@@ -645,6 +817,8 @@ function UnpaidPage({
   const [value, valueHandler] = useState<Partial<Unpaid>>(order);
   const { i18n } = useTranslationContext();
   const [settings] = usePreference();
+  useWaitForOrderPayment(id, order);
+
   return (
     <div>
       <section class="hero is-hero-bar">
@@ -720,10 +894,21 @@ function UnpaidPage({
                 label={i18n.str`Amount`}
                 tooltip={i18n.str`Total price for the transaction`}
               />
-              <Input<Unpaid>
+              <Input<Paid>
                 name="order_status"
                 readonly
                 label={i18n.str`Order status`}
+                toStr={(d) => {
+                  switch (d) {
+                    case "paid":
+                      return i18n.str`Paid`;
+                    case "claimed":
+                      return i18n.str`Claimed`;
+                    case "unpiad":
+                      return i18n.str`Unpaid`;
+                  }
+                  return d;
+                }}
               />
               <Input<Unpaid>
                 name="order_status_url"
@@ -798,3 +983,27 @@ export function DetailPage({ id, selected, onRefunded, onBack }: Props): VNode {
     </Fragment>
   );
 }
+export function getOrderAmountAndWirefee(
+  order:
+    | TalerMerchantApi.CheckPaymentPaidResponse
+    | TalerMerchantApi.CheckPaymentPaidResponse,
+) {
+  if (
+    order.contract_terms.version === undefined ||
+    order.contract_terms.version === MerchantContractVersion.V0
+  ) {
+    const amount = Amounts.parseOrThrow(order.contract_terms.amount);
+    const wireFee = Amounts.parseOrThrow(order.contract_terms.max_fee);
+    return { amount, wireFee };
+  }
+  if (order.contract_terms.version === MerchantContractVersion.V1) {
+    if (order.choice_index === undefined) return "v1-without-index" as const;
+    if (order.choice_index > order.contract_terms.choices.length)
+      return "v1-wrong-index" as const;
+    const choice = order.contract_terms.choices[order.choice_index];
+    const amount = Amounts.parseOrThrow(choice.amount);
+    const wireFee = Amounts.parseOrThrow(choice.max_fee);
+    return { amount, wireFee };
+  }
+  assertUnreachable(order.contract_terms.version);
+}
