@@ -45,9 +45,7 @@ import { Input } from "../../../../components/form/Input.js";
 import { InputCurrency } from "../../../../components/form/InputCurrency.js";
 import { InputGroup } from "../../../../components/form/InputGroup.js";
 import { InputSelector } from "../../../../components/form/InputSelector.js";
-import {
-  HtmlPersonaFlag
-} from "../../../../components/menu/SideBar.js";
+import { HtmlPersonaFlag } from "../../../../components/menu/SideBar.js";
 import { ConfirmModal } from "../../../../components/modal/index.js";
 import { useSessionContext } from "../../../../context/session.js";
 import { WithId } from "../../../../declaration.js";
@@ -57,7 +55,8 @@ import {
   usePreference,
 } from "../../../../hooks/preference.js";
 import { mergeRefunds } from "../../../../utils/amount.js";
-
+import { getOrderAmountAndWirefee } from "../details/DetailPage.js";
+import { OrderListSection } from "./index.js";
 
 const TALER_SCREEN_ID = 48;
 
@@ -66,6 +65,7 @@ interface Props {
   orders: Entity[];
   onRefund: (value: Entity) => void;
   onCreate: () => void;
+  section?: OrderListSection;
   onSelect: (order: Entity) => void;
   onLoadMoreBefore?: () => void;
   onLoadMoreAfter?: () => void;
@@ -73,6 +73,7 @@ interface Props {
 
 export function CardTable({
   orders,
+  section,
   onCreate,
   onRefund,
   onSelect,
@@ -123,6 +124,7 @@ export function CardTable({
                 instances={orders}
                 onSelect={onSelect}
                 onRefund={onRefund}
+                section={section}
                 rowSelection={rowSelection}
                 rowSelectionHandler={rowSelectionHandler}
                 onLoadMoreAfter={onLoadMoreAfter}
@@ -145,10 +147,12 @@ interface TableProps {
   rowSelectionHandler: StateUpdater<string[]>;
   onLoadMoreBefore?: () => void;
   onLoadMoreAfter?: () => void;
+  section?: OrderListSection;
 }
 
 function Table({
   instances,
+  section,
   onSelect,
   onRefund,
   onLoadMoreAfter,
@@ -193,6 +197,12 @@ function Table({
               <th style={{ minWidth: 100 }}>
                 <i18n.Translate>Amount</i18n.Translate>
               </th>
+              {section === OrderListSection.REFUNDED ? (
+                <th style={{ minWidth: 100 }}>
+                  <i18n.Translate>Refunded</i18n.Translate>
+                </th>
+              ) : undefined}
+
               <th style={{ minWidth: 400 }}>
                 <i18n.Translate>Summary</i18n.Translate>
               </th>
@@ -220,6 +230,14 @@ function Table({
                   >
                     {i.amount}
                   </td>
+                  {section === OrderListSection.REFUNDED ? (
+                    <td
+                      onClick={(): void => onSelect(i)}
+                      style={{ cursor: "pointer" }}
+                    >
+                      {i.refund_amount}
+                    </td>
+                  ) : undefined}
                   <td
                     onClick={(): void => onSelect(i)}
                     style={{ cursor: "pointer" }}
@@ -311,18 +329,13 @@ export function RefundModal({
   const [notification, safeFunctionHandler] = useLocalNotificationBetter();
   const { state: session, lib } = useSessionContext();
 
-  let amount: AmountString;
+  let amount: AmountString | undefined;
   if (order.order_status === "paid") {
-    if (
-      order.contract_terms.version !== undefined &&
-      order.contract_terms.version !== MerchantContractVersion.V0
-    ) {
-      return (
-        <div>Unsupported contract version {order.contract_terms.version}</div>
-      );
-    }
-
-    amount = order.contract_terms.amount;
+    const orderam = getOrderAmountAndWirefee(order);
+    amount =
+      typeof orderam === "string"
+        ? undefined
+        : Amounts.stringify(orderam.amount);
   }
 
   const refunds = (
@@ -402,7 +415,8 @@ export function RefundModal({
   //FIXME: parameters in the translation
   return (
     <ConfirmModal
-      description="refund"
+      description={i18n.str`refund`}
+      label={i18n.str`Confirm`}
       danger
       active
       onCancel={onCancel}
