@@ -22,7 +22,7 @@
 import {
   ButtonBetterBulma,
   SafeHandlerTemplate,
-  useTranslationContext
+  useTranslationContext,
 } from "@gnu-taler/web-util/browser";
 import { Fragment, h, VNode } from "preact";
 import { useState } from "preact/hooks";
@@ -35,39 +35,39 @@ const TALER_SCREEN_ID = 53;
 interface Props {
   instanceId: string;
   onBack?: () => void;
-  changePassword: SafeHandlerTemplate<[pass: string], any>;
+  withoutCurrentPassword?: boolean;
+  changePassword: SafeHandlerTemplate<[current: string, new: string], any>;
 }
 
 export function DetailPage({
   instanceId,
   onBack,
   changePassword,
+  withoutCurrentPassword,
 }: Props): VNode {
   type State = {
-    // old_token: string;
-    new_token: string;
-    repeat_token: string;
+    current: string;
+    next: string;
+    repeat: string;
   };
   const [form, setValue] = useState<Partial<State>>({
-    // old_token: "",
-    new_token: "",
-    repeat_token: "",
+    current: "",
+    next: "",
+    repeat: "",
   });
 
   const { i18n } = useTranslationContext();
 
   const errors = undefinedIfEmpty({
-    // old_token:
-    //   hasPassword && !form.old_token
-    //     ? i18n.str`You need your password to perform the operation`
-    //     : undefined,
-    new_token: !form.new_token
+    current: withoutCurrentPassword
+      ? undefined
+      : !form.current
+        ? i18n.str`Required`
+        : undefined,
+    next: !form.next ? i18n.str`Required` : undefined,
+    repeat: !form.repeat
       ? i18n.str`Required`
-      : // : form.new_token === form.old_token
-        //   ? i18n.str`Can't be the same as the old password`
-        undefined,
-    repeat_token:
-      form.new_token !== form.repeat_token
+      : form.next !== form.repeat
         ? i18n.str`Is not the same`
         : undefined,
   });
@@ -97,25 +97,22 @@ export function DetailPage({
           <div class="column is-four-fifths">
             <FormProvider errors={errors} object={form} valueHandler={setValue}>
               <Fragment>
-                {/* {hasPassword && (
-                  <Fragment>
-                    <Input<State>
-                      name="old_token"
-                      label={i18n.str`Current password`}
-                      tooltip={i18n.str`Password currently in use`}
-                      inputType="password"
-                    />
-                  </Fragment>
-                )} */}
-
+                {withoutCurrentPassword ? undefined : (
+                  <Input<State>
+                    name="current"
+                    label={i18n.str`Current password`}
+                    tooltip={i18n.str`In order to verify that you have access.`}
+                    inputType="password"
+                  />
+                )}
                 <Input<State>
-                  name="new_token"
+                  name="next"
                   label={i18n.str`New password`}
                   tooltip={i18n.str`Next password to be used`}
                   inputType="password"
                 />
                 <Input<State>
-                  name="repeat_token"
+                  name="repeat"
                   label={i18n.str`Repeat password`}
                   tooltip={i18n.str`Confirm the same password`}
                   inputType="password"
@@ -134,7 +131,11 @@ export function DetailPage({
                       ? i18n.str`Please complete the marked fields`
                       : i18n.str`Confirm operation`
                   }
-                  onClick={changePassword}
+                  onClick={
+                    hasErrors
+                      ? changePassword
+                      : changePassword.withArgs(form.current ?? "", form.next!)
+                  }
                 >
                   <i18n.Translate>Confirm change</i18n.Translate>
                 </ButtonBetterBulma>
