@@ -26,9 +26,8 @@ import {
   TalerMerchantApi,
 } from "@gnu-taler/taler-util";
 import {
-  useCommonPreferences,
   useLocalNotificationBetter,
-  useTranslationContext,
+  useTranslationContext
 } from "@gnu-taler/web-util/browser";
 import { format } from "date-fns";
 import { ComponentChildren, Fragment, VNode, h } from "preact";
@@ -41,14 +40,14 @@ import {
 } from "../../../../components/form/FormProvider.js";
 import { InputCurrency } from "../../../../components/form/InputCurrency.js";
 import { InputNumber } from "../../../../components/form/InputNumber.js";
+import { FragmentPersonaFlag } from "../../../../components/menu/SideBar.js";
 import { useSessionContext } from "../../../../context/session.js";
 import { WithId } from "../../../../declaration.js";
 import {
-  dateFormatForSettings,
   UIElement,
+  dateFormatForSettings,
   usePreference,
 } from "../../../../hooks/preference.js";
-import { FragmentPersonaFlag } from "../../../../components/menu/SideBar.js";
 
 const TALER_SCREEN_ID = 56;
 
