@@ -64,11 +64,11 @@ export default function ProductList({ onCreate, onSelect }: Props): VNode {
     !session.token || !deleting ? undefined : [session.token, deleting.id],
   );
   remove.onSuccess = (suc, t, id) => {
-    setDeleting(null)
-    return i18n.str`Product (ID: ${id}) has been deleted`
-  }
-  remove.onFail = (fail) =>{
-    switch(fail.case) {
+    setDeleting(null);
+    return i18n.str`Product (ID: ${id}) has been deleted`;
+  };
+  remove.onFail = (fail) => {
+    switch (fail.case) {
       case HttpStatusCode.Unauthorized:
         return i18n.str`Unauthorized.`;
       case HttpStatusCode.NotFound:
@@ -76,7 +76,7 @@ export default function ProductList({ onCreate, onSelect }: Props): VNode {
       case HttpStatusCode.Conflict:
         return i18n.str`Conflict.`;
     }
-  }
+  };
   if (!result) return <Loading />;
   if (result instanceof TalerError) {
     return <ErrorLoadingMerchant error={result} />;
@@ -118,8 +118,8 @@ export default function ProductList({ onCreate, onSelect }: Props): VNode {
 
       {deleting && (
         <ConfirmModal
-          label={`Delete product`}
-          description={`Delete the product "${deleting.description}"`}
+          label={i18n.str`Delete product`}
+          description={i18n.str`Delete the product "${deleting.description}"`}
           danger
           active
           onCancel={() => setDeleting(null)}
