@@ -19,7 +19,7 @@
  * @author Sebastian Javier Marchano (sebasjm)
  */
 
-import { HttpStatusCode, TalerMerchantApi } from "@gnu-taler/taler-util";
+import { HttpStatusCode, TalerError, TalerMerchantApi } from "@gnu-taler/taler-util";
 import {
   ButtonBetterBulma,
   LocalNotificationBannerBulma,
@@ -30,6 +30,9 @@ import { h, VNode } from "preact";
 import { useState } from "preact/hooks";
 import { ProductForm } from "../../../../components/product/ProductForm.js";
 import { useSessionContext } from "../../../../context/session.js";
+import { useInstanceCategories } from "../../../../hooks/category.js";
+import { Loading } from "../../../../components/exception/loading.js";
+import { ErrorLoadingMerchant } from "../../../../components/ErrorLoadingMerchant.js";
 
 const TALER_SCREEN_ID = 57;
 
@@ -66,6 +69,17 @@ export function UpdatePage({ product, onBack, onConfirm }: Props): VNode {
 
   const { i18n } = useTranslationContext();
 
+    // FIXME: if the category list is big the will bring a lot of info
+    // we could find a lazy way to add up on searches
+    const categoriesResult = useInstanceCategories();
+    if (!categoriesResult) return <Loading  />;
+    if (categoriesResult instanceof TalerError) {
+      return <ErrorLoadingMerchant error={categoriesResult} />;
+    }
+    const categories =
+      categoriesResult.type === "fail" ? [] : categoriesResult.body.categories;
+  
+
   return (
     <div>
       <LocalNotificationBannerBulma notification={notification} />
@@ -89,7 +103,7 @@ export function UpdatePage({ product, onBack, onConfirm }: Props): VNode {
         <div class="columns">
           <div class="column" />
           <div class="column is-four-fifths">
-            <ProductForm initial={product} onSubscribe={setForm} alreadyExist />
+            <ProductForm initial={product} onSubscribe={setForm} alreadyExist categories={categories}/>
 
             <div class="buttons is-right mt-5">
               {onBack && (
