@@ -27,6 +27,7 @@ import {
   TalerError,
   TalerMerchantApi,
   TranslatedString,
+  assertUnreachable,
 } from "@gnu-taler/taler-util";
 import {
   ButtonBetterBulma,
@@ -78,7 +79,11 @@ interface Props {
   defaultSettingsDuration: Duration;
 }
 
-export function CreatePage({ defaultSettingsDuration, onCreated, onBack }: Props): VNode {
+export function CreatePage({
+  defaultSettingsDuration,
+  onCreated,
+  onBack,
+}: Props): VNode {
   const { i18n } = useTranslationContext();
   const { config, state: session, lib } = useSessionContext();
   const devices = useInstanceOtpDevices();
@@ -176,15 +181,19 @@ export function CreatePage({ defaultSettingsDuration, onCreated, onBack }: Props
 
   const create = safeFunctionHandler(
     lib.instance.addTemplate.bind(lib.instance),
-    !session.token ? undefined : [session.token, data],
+    !session.token || hasErrors ? undefined : [session.token, data],
   );
   create.onSuccess = onCreated;
   create.onFail = (fail) => {
     switch (fail.case) {
       case HttpStatusCode.Unauthorized:
-        return i18n.str`Unauthorized`;
+        return i18n.str`You don't have enough permissions.`;
       case HttpStatusCode.NotFound:
-        return i18n.str`Not found`;
+        return i18n.str`Instance not found.`;
+      case HttpStatusCode.Conflict:
+        return i18n.str`There is a template with this identifier, please choose another one.`;
+      default:
+        assertUnreachable(fail);
     }
   };
 
