@@ -135,8 +135,8 @@ export default function ListTemplates({
 
       {deleting && (
         <ConfirmModal
-          label={`Delete template`}
-          description={`Delete the template "${deleting.template_description}"`}
+          label={i18n.str`Delete template`}
+          description={i18n.str`Delete the template "${deleting.template_description}"`}
           danger
           active
           onCancel={() => setDeleting(null)}
