@@ -20,34 +20,46 @@
  */
 
 import {
-  AmountLike,
   AmountString,
   Amounts,
   Duration,
+  HttpStatusCode,
   TalerError,
   TalerMerchantApi,
+  TalerProtocolDuration,
   TranslatedString,
 } from "@gnu-taler/taler-util";
-import { useTranslationContext } from "@gnu-taler/web-util/browser";
+import {
+  ButtonBetterBulma,
+  LocalNotificationBannerBulma,
+  undefinedIfEmpty,
+  useLocalNotificationBetter,
+  useTranslationContext,
+} from "@gnu-taler/web-util/browser";
 import { Fragment, VNode, h } from "preact";
 import { useState } from "preact/hooks";
-import { AsyncButton } from "../../../../components/exception/AsyncButton.js";
 import {
   FormErrors,
   FormProvider,
 } from "../../../../components/form/FormProvider.js";
 import { Input } from "../../../../components/form/Input.js";
-import { InputCurrency } from "../../../../components/form/InputCurrency.js";
 import { InputDuration } from "../../../../components/form/InputDuration.js";
 import { InputNumber } from "../../../../components/form/InputNumber.js";
 import { InputSelector } from "../../../../components/form/InputSelector.js";
 import { InputToggle } from "../../../../components/form/InputToggle.js";
-import { TextField } from "../../../../components/form/TextField.js";
-import { useSessionContext } from "../../../../context/session.js";
-import { useInstanceOtpDevices } from "../../../../hooks/otp.js";
-import { WithId } from "../../../../declaration.js";
 import { InputWithAddon } from "../../../../components/form/InputWithAddon.js";
+import { TextField } from "../../../../components/form/TextField.js";
 import { NotificationCard } from "../../../../components/menu/index.js";
+import { useSessionContext } from "../../../../context/session.js";
+import { WithId } from "../../../../declaration.js";
+import { useInstanceOtpDevices } from "../../../../hooks/otp.js";
+import { UIElement } from "../../../../hooks/preference.js";
+import {
+  ComponentPersonaFlag,
+  FragmentPersonaFlag,
+} from "../../../../components/menu/SideBar.js";
+
+const TALER_SCREEN_ID = 65;
 
 type Entity = {
   description?: string;
@@ -63,13 +75,16 @@ type Entity = {
 };
 
 interface Props {
-  onUpdate: (d: TalerMerchantApi.TemplatePatchDetails) => Promise<void>;
+  onUpdated: () => void;
   onBack?: () => void;
   template: TalerMerchantApi.TemplateDetails & WithId;
 }
 
-function changeToCurrency(am: string | undefined, currency: string | undefined): string | undefined {
-  if (!am || !currency) return undefined
+function changeToCurrency(
+  am: string | undefined,
+  currency: string | undefined,
+): string | undefined {
+  if (!am || !currency) return undefined;
   const amount = Amounts.parse(am);
   if (!amount) return undefined;
   const newAmount = {
@@ -79,9 +94,10 @@ function changeToCurrency(am: string | undefined, currency: string | undefined):
   return Amounts.stringify(newAmount);
 }
 
-export function UpdatePage({ template, onUpdate, onBack }: Props): VNode {
+export function UpdatePage({ template, onUpdated, onBack }: Props): VNode {
   const { i18n } = useTranslationContext();
-  const { config, state: session } = useSessionContext();
+  const { config, state: session, lib } = useSessionContext();
+  const [notification, safeFunctionHandler] = useLocalNotificationBetter();
 
   const cList = Object.values(config.currencies).map((d) => d.name);
   const supportedCurrencies = Object.keys(config.currencies);
@@ -100,8 +116,8 @@ export function UpdatePage({ template, onUpdate, onBack }: Props): VNode {
     supportedCurrencies.indexOf(template_currency) === -1;
 
   const startingAmount = unsupportedCurrency
-      ? changeToCurrency(currentAmount, default_currency)
-      : currentAmount
+    ? changeToCurrency(currentAmount, default_currency)
+    : currentAmount;
 
   const [state, setState] = useState<Partial<Entity>>({
     description: template.template_description,
@@ -127,7 +143,7 @@ export function UpdatePage({ template, onUpdate, onBack }: Props): VNode {
       if (!newState.amount_editable) {
         newState.currency_editable = false;
       }
-      newState.amount = changeToCurrency(newState.amount, newState.currency)
+      newState.amount = changeToCurrency(newState.amount, newState.currency);
       return newState;
     });
   }
@@ -147,13 +163,18 @@ export function UpdatePage({ template, onUpdate, onBack }: Props): VNode {
 
   const parsedPrice = !state.amount ? undefined : Amounts.parse(state.amount);
 
-  const errors: FormErrors<Entity> = {
+  const errors: FormErrors<Entity> | undefined = undefinedIfEmpty({
     description: !state.description ? i18n.str`Required` : undefined,
+    summary: !state.summary
+      ? state.summary_editable
+        ? undefined
+        : i18n.str`Required`
+      : undefined, // more summary validations? none
     amount: !state.amount
       ? state.amount_editable
         ? undefined
         : i18n.str`Required`
-      : !parsedPrice
+      : !parsedPrice // more summary validations? is valid amount...
         ? i18n.str`Invalid`
         : Amounts.isZero(parsedPrice)
           ? state.amount_editable
@@ -171,49 +192,56 @@ export function UpdatePage({ template, onUpdate, onBack }: Props): VNode {
         : state.pay_duration.d_ms < 1000 // less than one second
           ? i18n.str`Too short`
           : undefined,
-  };
-
-  const hasErrors = Object.keys(errors).some(
-    (k) => (errors as Record<string, unknown>)[k] !== undefined,
-  );
+  });
 
   const zero = Amounts.stringify(
     Amounts.zeroOfCurrency(state.currency ?? default_currency),
   );
 
-  const submitForm = () => {
-    if (hasErrors) return Promise.reject();
-    const contract_amount = state.amount_editable
-      ? undefined
-      : (state.amount as AmountString);
-    const contract_summary = state.summary_editable ? undefined : state.summary;
-    const template_contract: TalerMerchantApi.TemplateContractDetails = {
-      minimum_age: state.minimum_age!,
-      pay_duration: Duration.toTalerProtocolDuration(state.pay_duration!),
-      amount: contract_amount,
-      summary: contract_summary,
+  const contract_amount = state.amount_editable
+    ? undefined
+    : (state.amount as AmountString);
+  const contract_summary = state.summary_editable ? undefined : state.summary;
+  const template_contract: TalerMerchantApi.TemplateContractDetails = {
+    minimum_age: state.minimum_age!,
+    pay_duration: state.pay_duration ? Duration.toTalerProtocolDuration(state.pay_duration) : TalerProtocolDuration.forever(),
+    amount: contract_amount,
+    summary: contract_summary,
+    currency:
+      cList.length > 1 && state.currency_editable ? undefined : state.currency,
+  };
+  const data: TalerMerchantApi.TemplatePatchDetails = {
+    template_description: state.description!,
+    template_contract,
+    editable_defaults: {
+      amount: !state.amount_editable ? undefined : state.amount ?? zero,
+      summary: !state.summary_editable ? undefined : state.summary ?? "",
       currency:
-        cList.length > 1 && state.currency_editable
+        cList.length === 1 || !state.currency_editable
           ? undefined
           : state.currency,
-    };
-    return onUpdate({
-      template_description: state.description!,
-      template_contract,
-      editable_defaults: {
-        amount: !state.amount_editable ? undefined : state.amount ?? zero,
-        summary: !state.summary_editable ? undefined : state.summary ?? "",
-        currency:
-          cList.length === 1 || !state.currency_editable
-            ? undefined
-            : state.currency,
-      },
-      otp_id: state.otpId!,
-    });
+    },
+    otp_id: state.otpId!,
+  };
+  const update = safeFunctionHandler(
+    lib.instance.updateTemplate.bind(lib.instance),
+    !session.token || !!errors ? undefined : [session.token, template.id, data],
+  );
+  update.onSuccess = onUpdated;
+  update.onFail = (fail) => {
+    switch (fail.case) {
+      case HttpStatusCode.Unauthorized:
+        return i18n.str`Unauthorized`;
+      case HttpStatusCode.NotFound:
+        return i18n.str`Not found`;
+      case HttpStatusCode.Conflict:
+        return i18n.str`Conflict`;
+    }
   };
 
   return (
     <div>
+      <LocalNotificationBannerBulma notification={notification} />
       <section class="section">
         <section class="hero is-hero-bar">
           <div class="hero-body">
@@ -254,14 +282,13 @@ export function UpdatePage({ template, onUpdate, onBack }: Props): VNode {
               >
                 <Input<Entity>
                   name="description"
-                  label={i18n.str`Description`}
-                  help=""
+                  label={i18n.str`Template name`}
                   tooltip={i18n.str`Describe what this template stands for`}
                 />
                 <Input<Entity>
                   name="summary"
                   inputType="multiline"
-                  label={i18n.str`Summary`}
+                  label={i18n.str`Order summary`}
                   tooltip={i18n.str`If specified, this template will create order with the same summary`}
                 />
                 <InputToggle<Entity>
@@ -274,13 +301,6 @@ export function UpdatePage({ template, onUpdate, onBack }: Props): VNode {
                     name="currency"
                     label={i18n.str`Supported currencies`}
                     values={supportedCurrencies}
-                    // toStr={(str) => {
-                    //   if (str === "none") return i18n.str`Without authentication`;
-                    //   if (str === "basic")
-                    //     return i18n.str`With username and password`;
-                    //   if (str === "bearer") return i18n.str`With token`;
-                    //   return i18n.str`Do not change`;
-                    // }}
                   />
                 ) : undefined}
 
@@ -311,23 +331,29 @@ export function UpdatePage({ template, onUpdate, onBack }: Props): VNode {
                     />
                   </Fragment>
                 )}
-                {/* <TextField name="sc" label={i18n.str`Supported currencies`}>
-                  <i18n.Translate>{cList.join(", ")}</i18n.Translate>
-                </TextField> */}
-                <InputNumber<Entity>
-                  name="minimum_age"
-                  label={i18n.str`Minimum age`}
-                  help=""
-                  tooltip={i18n.str`Is this contract restricted to some age?`}
-                />
-                <InputDuration<Entity>
-                  name="pay_duration"
-                  label={i18n.str`Payment timeout`}
-                  help=""
-                  tooltip={i18n.str`How much time has the customer to complete the payment once the order was created.`}
-                />
+                <FragmentPersonaFlag point={UIElement.option_ageRestriction}>
+                  <InputNumber<Entity>
+                    name="minimum_age"
+                    label={i18n.str`Minimum age`}
+                    tooltip={i18n.str`Is this contract restricted to some age?`}
+                  />
+                </FragmentPersonaFlag>
+                <FragmentPersonaFlag
+                  point={UIElement.option_paymentTimeoutOnTemplate}
+                >
+                  <InputDuration<Entity>
+                    name="pay_duration"
+                    label={i18n.str`Payment timeout`}
+                    help=""
+                    tooltip={i18n.str`How much time has the customer to complete the payment once the order was created.`}
+                    withoutClear
+                  />
+                </FragmentPersonaFlag>
+
                 {!deviceList.length ? (
-                  <TextField
+                  <ComponentPersonaFlag
+                    Comp={TextField}
+                    point={UIElement.option_otpDevicesOnTemplate}
                     name="otpId"
                     label={i18n.str`OTP device`}
                     tooltip={i18n.str`Use to verify transactions in offline mode.`}
@@ -336,7 +362,7 @@ export function UpdatePage({ template, onUpdate, onBack }: Props): VNode {
                     <a href="#/otp-devices/new">
                       <i18n.Translate>Add one first</i18n.Translate>
                     </a>
-                  </TextField>
+                  </ComponentPersonaFlag>
                 ) : (
                   <InputSelector<Entity>
                     name="otpId"
@@ -358,21 +384,21 @@ export function UpdatePage({ template, onUpdate, onBack }: Props): VNode {
 
               <div class="buttons is-right mt-5">
                 {onBack && (
-                  <button class="button" onClick={onBack}>
+                  <button type="button" class="button" onClick={onBack}>
                     <i18n.Translate>Cancel</i18n.Translate>
                   </button>
                 )}
-                <AsyncButton
-                  disabled={hasErrors}
+                <ButtonBetterBulma
                   data-tooltip={
-                    hasErrors
+                    errors !== undefined
                       ? i18n.str`Please complete the marked fields`
                       : i18n.str`Confirm operation`
                   }
-                  onClick={submitForm}
+                  type="submit"
+                  onClick={update}
                 >
                   <i18n.Translate>Confirm</i18n.Translate>
-                </AsyncButton>
+                </ButtonBetterBulma>
               </div>
             </div>
           </div>
