@@ -19,7 +19,7 @@
  * @author Christian Blättler
  */
 
-import { h, VNode, FunctionalComponent } from "preact";
+import { FunctionalComponent, h } from "preact";
 import { CreatePage as TestedComponent } from "./CreatePage.js";
 
 export default {
