@@ -89,9 +89,9 @@ export function DeletePage({ instanceId, onBack, onDeleted }: Props): VNode {
           fail.body,
           remove.lambda((ids: string[]) => [t, p, ids]),
         );
-        return i18n.str`Second factor authentication required.`;
+        return undefined;
       case HttpStatusCode.Unauthorized:
-        return i18n.str`Unaouthorized.`;
+        return i18n.str`Unauthorized.`;
       case HttpStatusCode.NotFound:
         return i18n.str`Not found.`;
       case HttpStatusCode.Conflict:
