@@ -59,6 +59,7 @@ export interface Account {
 }
 
 const twoHours = Duration.fromSpec({ hours: 2 });
+const oneDay = Duration.fromSpec({ days: 1 });
 const twoDays = Duration.fromSpec({ days: 2 });
 
 interface Props {
@@ -131,8 +132,13 @@ export function NewAccount({ onCancel, onCreated }: Props): VNode {
       method: MerchantAuthMethod.TOKEN,
       password: value.password!,
     },
-    default_pay_delay: Duration.toTalerProtocolDuration(twoHours),
-    default_wire_transfer_delay: Duration.toTalerProtocolDuration(twoDays),
+    default_pay_delay:
+      config.default_pay_delay ?? Duration.toTalerProtocolDuration(twoHours),
+    default_wire_transfer_delay:
+      config.default_wire_transfer_delay ??
+      Duration.toTalerProtocolDuration(oneDay),
+    default_refund_delay:
+      config.default_refund_delay ?? Duration.toTalerProtocolDuration(twoDays),
     id: value.id!,
     jurisdiction: {},
     name: value.name!,
@@ -159,11 +165,11 @@ export function NewAccount({ onCancel, onCreated }: Props): VNode {
     switch (fail.case) {
       case HttpStatusCode.Accepted:
         mfa.onChallengeRequired(fail.body);
-        return i18n.str`Second factor authentication required.`;
+        return undefined;
       case HttpStatusCode.Unauthorized:
         return i18n.str`Unauthorized`;
       case HttpStatusCode.Conflict:
-        return i18n.str`Conflict`;
+        return i18n.str`There is another instance with this username.`;
     }
   };
   const retry = create.lambda((ids: string[]) => [create.args![0], ids]);
@@ -245,17 +251,18 @@ export function NewAccount({ onCancel, onCreated }: Props): VNode {
                   name="tos"
                   help={
                     <i18n.Translate>
-                      Accept the{" "}
                       <a
                         href="/terms"
                         target="_blank"
                         referrerpolicy="no-referrer"
                       >
-                        <i18n.Translate>terms of service</i18n.Translate>
+                        <i18n.Translate>
+                          Terms of service
+                        </i18n.Translate>
                       </a>
                     </i18n.Translate>
                   }
-                  tooltip={i18n.str`You must accept the terms of service to continue.`}
+                  tooltip={i18n.str`You must accept the Terms of service to continue.`}
                 />
               </FormProvider>
             </section>
