@@ -271,7 +271,7 @@ function getJsxElementPath(node: ts.Node) {
   return path;
 }
 
-function translateJsxExpression(node: ts.Node, h) {
+function translateJsxExpression(node: ts.Expression, h) {
   switch (node.kind) {
     case ts.SyntaxKind.StringLiteral: {
       let e = node as ts.StringLiteral;
@@ -440,187 +440,217 @@ function processNode(
   knownMessageIds: Set<string>,
   projectPrefix: string,
 ) {
-  switch (node.kind) {
-    case ts.SyntaxKind.JsxElement:
-      let path = getJsxElementPath(node);
-      // <i18n.Translate>text</i18n.Translate>
-      if (arrayEq(path, ["i18n", "Translate"])) {
-        const content = getJsxContent(node);
-        const { line } = ts.getLineAndCharacterOfPosition(sourceFile, node.pos);
-        if (!content) {
-          throw Error(
-            `string to be translated can't be empty: ${sourceFile.fileName}:${line}`,
+  const { line } = ts.getLineAndCharacterOfPosition(sourceFile, node.pos);
+  try {
+    switch (node.kind) {
+      case ts.SyntaxKind.JsxElement:
+        let path = getJsxElementPath(node);
+        // <i18n.Translate>text</i18n.Translate>
+        if (arrayEq(path, ["i18n", "Translate"])) {
+          const content = getJsxContent(node);
+          if (!content) {
+            throw Error(
+              `string to be translated can't be empty: ${sourceFile.fileName}:${line}`,
+            );
+          }
+          const comment = getComment(
+            sourceFile,
+            preLastTokLine,
+            lastTokLine,
+            node,
           );
+          const context = getJsxAttribute(sourceFile, node)["context"] ?? "";
+          const msgid = context + content;
+          if (!knownMessageIds.has(msgid)) {
+            knownMessageIds.add(msgid);
+            const screenId = searchScreenId(parents, sourceFile);
+            formatScreenId(sourceFile, outChunks, screenId);
+            formatMsgComment(
+              projectPrefix,
+              sourceFile,
+              outChunks,
+              line,
+              comment,
+            );
+            formatMsgLine(outChunks, "msgctxt", context);
+            formatMsgLine(outChunks, "msgid", content);
+            outChunks.push(`msgstr ""\n`);
+            outChunks.push("\n");
+          }
+        } else if (arrayEq(path, ["i18n", "TranslateSwitch"])) {
+          const { line } = ts.getLineAndCharacterOfPosition(
+            sourceFile,
+            node.pos,
+          );
+          const comment = getComment(
+            sourceFile,
+            preLastTokLine,
+            lastTokLine,
+            node,
+          );
+          formatMsgComment(projectPrefix, sourceFile, outChunks, line, comment);
+          const content = getJsxSingular(node);
+          if (!content) {
+            throw Error(
+              `string to be translated can't be empty, singular is missing: ${sourceFile.fileName}:${line}`,
+            );
+          }
+          const pluralForm = getJsxPlural(node);
+          if (!pluralForm) {
+            throw Error(
+              `string to be translated can't be empty, plural is missing: ${sourceFile.fileName}:${line}`,
+            );
+          }
+          const context = getJsxAttribute(sourceFile, node)["context"] ?? "";
+          const msgid = context + content;
+          if (!knownMessageIds.has(msgid)) {
+            knownMessageIds.add(msgid);
+            const screenId = searchScreenId(parents, sourceFile);
+            formatScreenId(sourceFile, outChunks, screenId);
+            formatMsgLine(outChunks, "msgctxt", context);
+            formatMsgLine(outChunks, "msgid", content);
+            formatMsgLine(outChunks, "msgid_plural", pluralForm);
+            outChunks.push(`msgstr[0] ""\n`);
+            outChunks.push(`msgstr[1] ""\n`);
+            outChunks.push(`\n`);
+          }
         }
-        const comment = getComment(
+        break;
+      case ts.SyntaxKind.CallExpression: {
+        // might be i18n.plural(i18n[.X]`...`, i18n[.X]`...`)
+        let ce = <ts.CallExpression>node;
+        let path = getPath(ce.expression);
+        if (!arrayEq(path.path, ["i18n", "plural"])) {
+          break;
+        }
+        if (ce.arguments[0].kind != ts.SyntaxKind.TaggedTemplateExpression) {
+          break;
+        }
+        if (ce.arguments[1].kind != ts.SyntaxKind.TaggedTemplateExpression) {
+          break;
+        }
+        let { line } = ts.getLineAndCharacterOfPosition(sourceFile, ce.pos);
+        const tte1 = <ts.TaggedTemplateExpression>ce.arguments[0];
+        let lc1 = ts.getLineAndCharacterOfPosition(sourceFile, tte1.pos);
+        if (lc1.line != lastTokLine) {
+          preLastTokLine = lastTokLine; // HERE
+          lastTokLine = lc1.line;
+        }
+        const t1 = processTaggedTemplateExpression(
           sourceFile,
           preLastTokLine,
           lastTokLine,
-          node,
+          tte1,
         );
-        const context = getJsxAttribute(sourceFile, node)["context"] ?? "";
-        const msgid = context + content;
+        const content = t1.template;
+        if (!content) {
+          throw new ParseErrror(
+            `string to be translated can't be empty`,
+            sourceFile.fileName,
+            line,
+          );
+        }
+
+        const tte2 = <ts.TaggedTemplateExpression>ce.arguments[1];
+        let lc2 = ts.getLineAndCharacterOfPosition(sourceFile, tte2.pos);
+        if (lc2.line != lastTokLine) {
+          preLastTokLine = lastTokLine; // HERE
+          lastTokLine = lc2.line;
+        }
+        let t2 = processTaggedTemplateExpression(
+          sourceFile,
+          preLastTokLine,
+          lastTokLine,
+          tte2,
+        );
+        let comment = getComment(sourceFile, preLastTokLine, lastTokLine, ce);
+        const msgid = path.ctx + content;
+        if (!knownMessageIds.has(msgid)) {
+          knownMessageIds.add(msgid);
+          const screenId = searchScreenId(parents, sourceFile);
+          formatScreenId(sourceFile, outChunks, screenId);
+          formatMsgComment(projectPrefix, sourceFile, outChunks, line, comment);
+          formatMsgLine(outChunks, "msgctxt", path.ctx);
+          formatMsgLine(outChunks, "msgid", content);
+          formatMsgLine(outChunks, "msgid_plural", t2.template);
+          outChunks.push(`msgstr[0] ""\n`);
+          outChunks.push(`msgstr[1] ""\n`);
+          outChunks.push("\n");
+        }
+
+        // Important: no processing for child i18n expressions here
+        return;
+      }
+      case ts.SyntaxKind.TaggedTemplateExpression: {
+        let tte = <ts.TaggedTemplateExpression>node;
+        let lc2 = ts.getLineAndCharacterOfPosition(sourceFile, tte.pos);
+        if (lc2.line != lastTokLine) {
+          preLastTokLine = lastTokLine;
+          lastTokLine = lc2.line;
+        }
+        const { comment, template, line, path, context } =
+          processTaggedTemplateExpression(
+            sourceFile,
+            preLastTokLine,
+            lastTokLine,
+            tte,
+          );
+        if (path[0] != "i18n") {
+          break;
+        }
+        if (!template) {
+          throw new ParseErrror(
+            `string to be translated can't be empty`,
+            sourceFile.fileName,
+            line,
+          );
+        }
+        const msgid = context + template;
         if (!knownMessageIds.has(msgid)) {
           knownMessageIds.add(msgid);
           const screenId = searchScreenId(parents, sourceFile);
           formatScreenId(sourceFile, outChunks, screenId);
           formatMsgComment(projectPrefix, sourceFile, outChunks, line, comment);
           formatMsgLine(outChunks, "msgctxt", context);
-          formatMsgLine(outChunks, "msgid", content);
+          formatMsgLine(outChunks, "msgid", template);
           outChunks.push(`msgstr ""\n`);
           outChunks.push("\n");
         }
-        return;
-      }
-      if (arrayEq(path, ["i18n", "TranslateSwitch"])) {
-        const { line } = ts.getLineAndCharacterOfPosition(sourceFile, node.pos);
-        const comment = getComment(
-          sourceFile,
-          preLastTokLine,
-          lastTokLine,
-          node,
-        );
-        formatMsgComment(projectPrefix, sourceFile, outChunks, line, comment);
-        const content = getJsxSingular(node);
-        if (!content) {
-          throw Error(
-            `string to be translated can't be empty, singular is missing: ${sourceFile.fileName}:${line}`,
-          );
-        }
-        const pluralForm = getJsxPlural(node);
-        if (!pluralForm) {
-          throw Error(
-            `string to be translated can't be empty, plural is missing: ${sourceFile.fileName}:${line}`,
-          );
-        }
-        const context = getJsxAttribute(sourceFile, node)["context"] ?? "";
-        const msgid = context + content;
-        if (!knownMessageIds.has(msgid)) {
-          knownMessageIds.add(msgid);
-          const screenId = searchScreenId(parents, sourceFile);
-          formatScreenId(sourceFile, outChunks, screenId);
-          formatMsgLine(outChunks, "msgctxt", context);
-          formatMsgLine(outChunks, "msgid", content);
-          formatMsgLine(outChunks, "msgid_plural", pluralForm);
-          outChunks.push(`msgstr[0] ""\n`);
-          outChunks.push(`msgstr[1] ""\n`);
-          outChunks.push(`\n`);
-        }
-        return;
-      }
-      break;
-    case ts.SyntaxKind.CallExpression: {
-      // might be i18n.plural(i18n[.X]`...`, i18n[.X]`...`)
-      let ce = <ts.CallExpression>node;
-      let path = getPath(ce.expression);
-      if (!arrayEq(path.path, ["i18n", "plural"])) {
         break;
       }
-      if (ce.arguments[0].kind != ts.SyntaxKind.TaggedTemplateExpression) {
-        break;
-      }
-      if (ce.arguments[1].kind != ts.SyntaxKind.TaggedTemplateExpression) {
-        break;
-      }
-      let { line } = ts.getLineAndCharacterOfPosition(sourceFile, ce.pos);
-      const tte1 = <ts.TaggedTemplateExpression>ce.arguments[0];
-      let lc1 = ts.getLineAndCharacterOfPosition(sourceFile, tte1.pos);
-      if (lc1.line != lastTokLine) {
-        preLastTokLine = lastTokLine; // HERE
-        lastTokLine = lc1.line;
-      }
-      const t1 = processTaggedTemplateExpression(
-        sourceFile,
-        preLastTokLine,
-        lastTokLine,
-        tte1,
-      );
-      const content = t1.template;
-      if (!content) {
-        throw Error(
-          `string to be translated can't be empty: ${sourceFile.fileName}:${line}`,
-        );
-      }
-
-      const tte2 = <ts.TaggedTemplateExpression>ce.arguments[1];
-      let lc2 = ts.getLineAndCharacterOfPosition(sourceFile, tte2.pos);
-      if (lc2.line != lastTokLine) {
-        preLastTokLine = lastTokLine; // HERE
-        lastTokLine = lc2.line;
-      }
-      let t2 = processTaggedTemplateExpression(
-        sourceFile,
-        preLastTokLine,
-        lastTokLine,
-        tte2,
-      );
-      let comment = getComment(sourceFile, preLastTokLine, lastTokLine, ce);
-      const msgid = path.ctx + content;
-      if (!knownMessageIds.has(msgid)) {
-        knownMessageIds.add(msgid);
-        const screenId = searchScreenId(parents, sourceFile);
-        formatScreenId(sourceFile, outChunks, screenId);
-        formatMsgComment(projectPrefix, sourceFile, outChunks, line, comment);
-        formatMsgLine(outChunks, "msgctxt", path.ctx);
-        formatMsgLine(outChunks, "msgid", content);
-        formatMsgLine(outChunks, "msgid_plural", t2.template);
-        outChunks.push(`msgstr[0] ""\n`);
-        outChunks.push(`msgstr[1] ""\n`);
-        outChunks.push("\n");
-      }
-
-      // Important: no processing for child i18n expressions here
-      return;
     }
-    case ts.SyntaxKind.TaggedTemplateExpression: {
-      let tte = <ts.TaggedTemplateExpression>node;
-      let lc2 = ts.getLineAndCharacterOfPosition(sourceFile, tte.pos);
-      if (lc2.line != lastTokLine) {
-        preLastTokLine = lastTokLine;
-        lastTokLine = lc2.line;
-      }
-      const { comment, template, line, path, context } =
-        processTaggedTemplateExpression(
-          sourceFile,
-          preLastTokLine,
-          lastTokLine,
-          tte,
-        );
-      if (path[0] != "i18n") {
-        break;
-      }
-      if (!template) {
-        throw Error(
-          `string to be translated can't be empty: ${sourceFile.fileName}:${line}`,
-        );
-      }
-      const msgid = context + template;
-      if (!knownMessageIds.has(msgid)) {
-        knownMessageIds.add(msgid);
-        const screenId = searchScreenId(parents, sourceFile);
-        formatScreenId(sourceFile, outChunks, screenId);
-        formatMsgComment(projectPrefix, sourceFile, outChunks, line, comment);
-        formatMsgLine(outChunks, "msgctxt", context);
-        formatMsgLine(outChunks, "msgid", template);
-        outChunks.push(`msgstr ""\n`);
-        outChunks.push("\n");
-      }
-      break;
+
+    ts.forEachChild(node, (child) => {
+      processNode(
+        [node, ...parents],
+        child,
+        lastTokLine,
+        preLastTokLine,
+        sourceFile,
+        outChunks,
+        knownMessageIds,
+        projectPrefix,
+      );
+    });
+  } catch (error) {
+    if (error instanceof ParseErrror) {
+      throw error;
+    } else {
+      throw new ParseErrror(String(error), sourceFile.fileName, line);
     }
   }
+}
 
-  ts.forEachChild(node, (child) => {
-    processNode(
-      [node, ...parents],
-      child,
-      lastTokLine,
-      preLastTokLine,
-      sourceFile,
-      outChunks,
-      knownMessageIds,
-      projectPrefix,
-    );
-  });
+class ParseErrror extends Error {
+  line: number;
+  filename: string;
+  reason: string;
+  constructor(reason: string, filename: string, line: number) {
+    super(`failed by "${reason}" at ${filename}:${line}`);
+    this.reason = reason;
+    this.filename = filename;
+    this.line = line;
+  }
 }
 
 export function processFileForTesting(sourceFile: ts.SourceFile): string {
@@ -718,7 +748,7 @@ export function potextract() {
 
   if (SCREEN_INFO.missing.size) {
     console.error(
-      `There are some files with translation strings that doesnt have a constant TALER_SCREEN_ID on the root. This constant should be a unquie integer number to facilitate the identification from other locations. Add a "const TALER_SCREEN_ID = <number>;" after the last import. It doesn't need to be exported and it can be removed from runtime. Files:`,
+      `There are some files with translation strings that do not have a constant TALER_SCREEN_ID on the root. This constant should be a unique integer number to facilitate the identification from other locations. Add a "const TALER_SCREEN_ID = <number>;" after the last import. It does not need to be exported and it can be removed from runtime. Files:`,
     );
     SCREEN_INFO.missing.forEach((fileName) => {
       console.error(` * ${fileName}`);
