@@ -66,7 +66,9 @@ export async function runBench2(configJson: any): Promise<void> {
 
   const reserveAmount = (numDeposits + 1) * 10;
 
-  const denomselAllowLate = false;
+  const merchantPair = await cryptoApi.createEddsaKeypair({});
+  const merchantPub = merchantPair.pub;
+  const merchantPriv = merchantPair.priv;
 
   for (let i = 0; i < numIter; i++) {
     const exchangeInfo = await downloadExchangeInfo(benchConf.exchange, http);
@@ -89,9 +91,7 @@ export async function runBench2(configJson: any): Promise<void> {
 
     console.log("reserve found");
 
-    const d1 = findDenomOrThrow(exchangeInfo, `${curr}:8` as AmountString, {
-      denomselAllowLate,
-    });
+    const d1 = findDenomOrThrow(exchangeInfo, `${curr}:8` as AmountString);
 
     for (let j = 0; j < numDeposits; j++) {
       console.log("withdrawing coin");
@@ -115,15 +115,12 @@ export async function runBench2(configJson: any): Promise<void> {
         exchangeBaseUrl: benchConf.exchange,
         http,
         depositPayto: benchConf.payto,
+        merchantPriv,
       });
 
       const refreshDenoms = [
-        findDenomOrThrow(exchangeInfo, `${curr}:1` as AmountString, {
-          denomselAllowLate,
-        }),
-        findDenomOrThrow(exchangeInfo, `${curr}:1` as AmountString, {
-          denomselAllowLate,
-        }),
+        findDenomOrThrow(exchangeInfo, `${curr}:1` as AmountString),
+        findDenomOrThrow(exchangeInfo, `${curr}:1` as AmountString),
       ];
 
       console.log("refreshing coin");
