@@ -1633,7 +1633,7 @@ export class ExchangeService implements ExchangeServiceInterface {
    * Update keys signing the keys generated by the security module
    * with the offline signing key.
    */
-  async keyup(): Promise<void> {
+  async keyup(opts: { skipGlobalFees?: boolean } = {}): Promise<void> {
     await runCommand(
       this.globalState,
       "exchange-offline",
@@ -1705,31 +1705,33 @@ export class ExchangeService implements ExchangeServiceInterface {
       }
     }
 
-    await runCommand(
-      this.globalState,
-      "exchange-offline",
-      "taler-exchange-offline",
-      [
-        "-c",
-        this.configFilename,
-        "global-fee",
-        // year
-        "now",
-        // history fee
-        `${this.exchangeConfig.currency}:0.01`,
-        // account fee
-        `${this.exchangeConfig.currency}:0.01`,
-        // purse fee
-        `${this.exchangeConfig.currency}:0.00`,
-        // purse timeout
-        "1h",
-        // history expiration
-        "1year",
-        // free purses per account
-        "5",
-        "upload",
-      ],
-    );
+    if (!opts.skipGlobalFees) {
+      await runCommand(
+        this.globalState,
+        "exchange-offline",
+        "taler-exchange-offline",
+        [
+          "-c",
+          this.configFilename,
+          "global-fee",
+          // year
+          "now",
+          // history fee
+          `${this.exchangeConfig.currency}:0.01`,
+          // account fee
+          `${this.exchangeConfig.currency}:0.01`,
+          // purse fee
+          `${this.exchangeConfig.currency}:0.00`,
+          // purse timeout
+          "1h",
+          // history expiration
+          "1year",
+          // free purses per account
+          "5",
+          "upload",
+        ],
+      );
+    }
   }
 
   async revokeDenomination(denomPubHash: string) {
@@ -1857,7 +1859,11 @@ export class ExchangeService implements ExchangeServiceInterface {
   }
 
   async start(
-    opts: { skipDbinit?: boolean; skipKeyup?: boolean } = {},
+    opts: {
+      skipDbinit?: boolean;
+      skipKeyup?: boolean;
+      skipGlobalFees?: boolean;
+    } = {},
   ): Promise<void> {
     if (this.isRunning()) {
       throw Error("exchange is already running");
@@ -1910,7 +1916,7 @@ export class ExchangeService implements ExchangeServiceInterface {
     const skipKeyup = opts.skipKeyup ?? false;
 
     if (!skipKeyup) {
-      await this.keyup();
+      await this.keyup({ skipGlobalFees: opts.skipGlobalFees });
     } else {
       logger.info("skipping keyup");
     }
@@ -2128,6 +2134,15 @@ export class MerchantService implements MerchantServiceInterface {
     );
   }
 
+  async runReconciliationOnce() {
+    await runCommand(
+      this.globalState,
+      `merchant-${this.name}-reconciliation-once`,
+      "taler-merchant-reconciliation",
+      [...this.timetravelArgArr, "-LINFO", "-c", this.configFilename, "-t"],
+    );
+  }
+
   async runKyccheckOnce() {
     await runCommand(
       this.globalState,
