@@ -30,6 +30,8 @@ import {
   KycRule,
   KycStatusLongPollingReason,
   LimitOperationType,
+  MerchantAccountKycRedirectsResponse,
+  MerchantAccountKycStatus,
   OfficerAccount,
   OfficerId,
   parsePaytoUriOrThrow,
@@ -64,6 +66,7 @@ import {
   harnessHttpLib,
   MerchantService,
   setupDb,
+  waitMs,
   WalletClient,
   WalletService,
 } from "./harness.js";
@@ -692,12 +695,13 @@ export async function createTopsEnvironment(
 
   const merchantAdminPayto = getTestHarnessPaytoForLabel("merchant-default");
 
-  const { accessToken: adminAccessToken } = await merchant.addInstanceWithWireAccount({
-    id: "admin",
-    name: "Default Instance",
-    paytoUris: [merchantAdminPayto],
-    defaultWireTransferDelay: TalerProtocolDuration.fromSpec({ minutes: 1 }),
-  });
+  const { accessToken: adminAccessToken } =
+    await merchant.addInstanceWithWireAccount({
+      id: "admin",
+      name: "Default Instance",
+      paytoUris: [merchantAdminPayto],
+      defaultWireTransferDelay: TalerProtocolDuration.fromSpec({ minutes: 1 }),
+    });
 
   await bankClient.registerAccountExtended({
     name: "merchant-default",
@@ -709,12 +713,15 @@ export async function createTopsEnvironment(
   const merchantInstId = "minst1";
   const merchantInstPaytoUri = getTestHarnessPaytoForLabel(merchantInstId);
 
-  await merchant.addInstanceWithWireAccount({
-    id: merchantInstId,
-    name: merchantInstId,
-    paytoUris: [merchantInstPaytoUri],
-    defaultWireTransferDelay: TalerProtocolDuration.fromSpec({ minutes: 1 }),
-  }, { adminAccessToken });
+  await merchant.addInstanceWithWireAccount(
+    {
+      id: merchantInstId,
+      name: merchantInstId,
+      paytoUris: [merchantInstPaytoUri],
+      defaultWireTransferDelay: TalerProtocolDuration.fromSpec({ minutes: 1 }),
+    },
+    { adminAccessToken },
+  );
 
   await bankClient.registerAccountExtended({
     name: merchantInstId,
@@ -834,25 +841,45 @@ export async function doTopsKycAuth(
     bank: BankServiceHandle;
   },
 ): Promise<{ accessToken: AccessToken; merchantPaytoHash: string }> {
-  const { merchantClient, wireGatewayApi, exchangeBankAccount, merchantAdminAccessToken } = args;
+  const {
+    merchantClient,
+    wireGatewayApi,
+    exchangeBankAccount,
+    merchantAdminAccessToken,
+  } = args;
   {
-    const kycStatus = await merchantClient.getCurrentInstanceKycStatus(
-      merchantAdminAccessToken,
-      {},
-    );
+    let kycBody: MerchantAccountKycRedirectsResponse | undefined;
+    while (kycBody == null) {
+      const kycStatus = await merchantClient.getCurrentInstanceKycStatus(
+        merchantAdminAccessToken,
+        {},
+      );
 
-    console.log(`kyc status: ${j2s(kycStatus)}`);
+      console.log(`kyc status: ${j2s(kycStatus)}`);
 
-    t.assertDeepEqual(kycStatus.case, "ok");
+      t.assertDeepEqual(kycStatus.case, "ok");
 
-    t.assertTrue(kycStatus.body != null);
+      t.assertTrue(kycStatus.body != null);
 
-    t.assertDeepEqual(kycStatus.body.kyc_data[0].status, "kyc-wire-required");
+      if (
+        kycStatus.body.kyc_data[0].status ===
+        MerchantAccountKycStatus.EXCHANGE_UNREACHABLE
+      ) {
+        logger.info(`merchant claims exchange is still unreachable for KYC`);
+        await waitMs(500);
+      } else {
+        t.assertDeepEqual(
+          kycStatus.body.kyc_data[0].status,
+          "kyc-wire-required",
+        );
+        kycBody = kycStatus.body;
+      }
+    }
 
-    const depositPaytoUri = kycStatus.body.kyc_data[0].payto_uri;
-    t.assertTrue(kycStatus.body.kyc_data[0].payto_kycauths != null);
+    const depositPaytoUri = kycBody.kyc_data[0].payto_uri;
+    t.assertTrue(kycBody.kyc_data[0].payto_kycauths != null);
     const authTxPayto = parsePaytoUriOrThrow(
-      kycStatus.body.kyc_data[0]?.payto_kycauths[0],
+      kycBody.kyc_data[0]?.payto_kycauths[0],
     );
     const authTxMessage = authTxPayto?.params["message"];
     t.assertTrue(typeof authTxMessage === "string");
@@ -904,7 +931,13 @@ export async function doTopsAcceptTos(
     merchant: MerchantService;
   },
 ): Promise<void> {
-  const { exchangeClient, merchant, merchantClient, accessToken, merchantAdminAccessToken } = args;
+  const {
+    exchangeClient,
+    merchant,
+    merchantClient,
+    accessToken,
+    merchantAdminAccessToken,
+  } = args;
   {
     const kycInfo = await exchangeClient.checkKycInfo(
       accessToken,
@@ -959,6 +992,7 @@ export async function doTopsAcceptTos(
  * Helpers for the test.
  */
 export interface MeasuresTestEnvironment {
+  exchange: ExchangeService;
   expectInfo: () => Promise<void>;
   expectFrozen: () => Promise<void>;
   expectNotFrozen: () => Promise<void>;
@@ -969,12 +1003,14 @@ export interface MeasuresTestEnvironment {
     address: any,
   ) => Promise<void>;
   submitForm: (form: string, data: any) => Promise<void>;
+  submitOfficerForm: (form: string, data: any) => Promise<void>;
   decideMeasure: (measure: string) => Promise<{
     currentDecision: AmlDecision;
   }>;
   decideReset: () => Promise<void>;
   challengerPostal: TestfakeChallengerService;
   challengerSms: TestfakeChallengerService;
+  accountPaytoHash: string;
   officerAcc: OfficerAccount;
   exchangeClient: TalerExchangeHttpClient;
 }
@@ -1044,6 +1080,29 @@ export async function setupMeasuresTestEnvironment(
     t.assertDeepEqual(uploadRes.case, "ok");
   };
 
+  const submitOfficerForm = async (form: string, data: any) => {
+    const decisionsResp = succeedOrThrow(
+      await exchangeClient.getAmlDecisions(officerAcc, {
+        active: true,
+      }),
+    );
+    console.log(`existing decision:`, j2s(decisionsResp));
+
+    const currDec = decisionsResp.records[0];
+
+    succeedOrThrow(
+      await exchangeClient.makeAmlDesicion(officerAcc, {
+        decision_time: TalerProtocolTimestamp.now(),
+        h_payto: merchantPaytoHash,
+        justification: "bla",
+        properties: currDec.properties || {},
+        keep_investigating: currDec.to_investigate,
+        new_rules: currDec.limits,
+        attributes: data,
+      }),
+    );
+  };
+
   const fakeChallenger = async (
     challenger: TestfakeChallengerService,
     address: any,
@@ -1118,13 +1177,16 @@ export async function setupMeasuresTestEnvironment(
   };
 
   return {
+    exchange,
     challengerPostal,
     challengerSms,
+    accountPaytoHash: merchantPaytoHash,
     expectInfo,
     fakeChallenger,
     decideMeasure: myTriggerMeasure,
     decideReset: myTriggerReset,
     submitForm,
+    submitOfficerForm,
     async expectFrozen() {
       const dec = await getCurrentDecision();
       t.assertTrue(isFrozen(dec));
@@ -1214,7 +1276,7 @@ async function doTriggerReset(
       is_and_combinator: config
         .getYesNo(secName, "IS_AND_COMBINATIOR")
         .orDefault(false),
-      rule_name: secName.substring(rulePrefix.length),
+      rule_name: secName.substring(rulePrefix.length).toLowerCase(),
     });
   }
   succeedOrThrow(
