@@ -25,7 +25,7 @@ import {
   createSimpleTestkudosEnvironmentV3,
   makeTestPaymentV2,
   withdrawViaBankV3,
-} from "../harness/helpers.js";
+} from "../harness/environments.js";
 
 /**
  * Run test for basic, bank-integrated withdrawal and payment.
@@ -55,7 +55,7 @@ export async function runClauseSchnorrTest(t: GlobalTestState) {
     name: "rsa_dummy",
   });
 
-  const { walletClient, bankClient, exchange, merchant } =
+  const { walletClient, bankClient, exchange, merchant, merchantAdminAccessToken } =
     await createSimpleTestkudosEnvironmentV3(t, coinConfig);
 
   // Withdraw digital cash into the wallet.
@@ -74,7 +74,7 @@ export async function runClauseSchnorrTest(t: GlobalTestState) {
     fulfillment_url: "taler://fulfillment-success/thx",
   };
 
-  await makeTestPaymentV2(t, { walletClient, merchant, order });
+  await makeTestPaymentV2(t, { walletClient, merchant, order, merchantAdminAccessToken });
   await walletClient.call(WalletApiOperation.TestingWaitTransactionsFinal, {});
 
   // Test JSON normalization of contract terms: Does the wallet
@@ -85,7 +85,7 @@ export async function runClauseSchnorrTest(t: GlobalTestState) {
     fulfillment_url: "taler://fulfillment-success/thx",
   };
 
-  await makeTestPaymentV2(t, { walletClient, merchant, order: order2 });
+  await makeTestPaymentV2(t, { walletClient, merchant, order: order2, merchantAdminAccessToken });
   await walletClient.call(WalletApiOperation.TestingWaitTransactionsFinal, {});
 
   // Test JSON normalization of contract terms: Does the wallet
@@ -96,7 +96,7 @@ export async function runClauseSchnorrTest(t: GlobalTestState) {
     fulfillment_url: "taler://fulfillment-success/thx",
   };
 
-  await makeTestPaymentV2(t, { walletClient, merchant, order: order3 });
+  await makeTestPaymentV2(t, { walletClient, merchant, order: order3, merchantAdminAccessToken });
   await walletClient.call(WalletApiOperation.TestingWaitTransactionsFinal, {});
 }
 
