@@ -40,9 +40,6 @@ import {
   setupDb,
 } from "../harness/harness.js";
 
-/**
- * Run test for basic, bank-integrated withdrawal and payment.
- */
 export async function runCurrencyScopeTest(t: GlobalTestState) {
   // Set up test environment
   const dbDefault = await setupDb(t);
@@ -156,23 +153,27 @@ export async function runCurrencyScopeTest(t: GlobalTestState) {
   await merchant.start();
   await merchant.pingUntilAvailable();
 
-  const { accessToken: adminAccessToken } = await merchant.addInstanceWithWireAccount({
-    id: "admin",
-    name: "Default Instance",
-    paytoUris: [getTestHarnessPaytoForLabel("merchant-default")],
-    defaultWireTransferDelay: Duration.toTalerProtocolDuration(
-      Duration.fromSpec({ minutes: 1 }),
-    ),
-  });
+  const { accessToken: adminAccessToken } =
+    await merchant.addInstanceWithWireAccount({
+      id: "admin",
+      name: "Default Instance",
+      paytoUris: [getTestHarnessPaytoForLabel("merchant-default")],
+      defaultWireTransferDelay: Duration.toTalerProtocolDuration(
+        Duration.fromSpec({ minutes: 1 }),
+      ),
+    });
 
-  await merchant.addInstanceWithWireAccount({
-    id: "minst1",
-    name: "minst1",
-    paytoUris: [getTestHarnessPaytoForLabel("minst1")],
-    defaultWireTransferDelay: Duration.toTalerProtocolDuration(
-      Duration.fromSpec({ minutes: 1 }),
-    ),
-  }, {adminAccessToken});
+  await merchant.addInstanceWithWireAccount(
+    {
+      id: "minst1",
+      name: "minst1",
+      paytoUris: [getTestHarnessPaytoForLabel("minst1")],
+      defaultWireTransferDelay: Duration.toTalerProtocolDuration(
+        Duration.fromSpec({ minutes: 1 }),
+      ),
+    },
+    { adminAccessToken },
+  );
 
   const { walletClient } = await createWalletDaemonWithClient(t, {
     name: "wallet",
@@ -251,7 +252,8 @@ export async function runCurrencyScopeTest(t: GlobalTestState) {
   t.assertDeepEqual(bal2.balances.length, 1);
 
   const payRes = await makeTestPaymentV2(t, {
-    merchant, merchantAdminAccessToken: adminAccessToken,
+    merchant,
+    merchantAdminAccessToken: adminAccessToken,
     walletClient,
     order: {
       amount: "TESTKUDOS:10",
