@@ -19,7 +19,6 @@
  */
 import {
   AmountString,
-  NotificationType,
   TransactionMajorState,
   TransactionMinorState,
   j2s,
@@ -45,14 +44,15 @@ export async function runDepositTest(t: GlobalTestState) {
 
   // Withdraw digital cash into the wallet.
 
-  const withdrawalResult = await withdrawViaBankV3(t, {
-    walletClient,
-    bankClient,
-    exchange,
-    amount: "TESTKUDOS:20",
-  });
-
-  await withdrawalResult.withdrawalFinishedCond;
+  {
+    const withdrawalResult = await withdrawViaBankV3(t, {
+      walletClient,
+      bankClient,
+      exchange,
+      amount: "TESTKUDOS:20",
+    });
+    await withdrawalResult.withdrawalFinishedCond;
+  }
 
   const depositPaytoUri = getTestHarnessPaytoForLabel("foo");
 
@@ -133,6 +133,48 @@ export async function runDepositTest(t: GlobalTestState) {
   const balAfter = await walletClient.call(WalletApiOperation.GetBalances, {});
   console.log(`balances after deposit: ${j2s(balAfter)}`);
   t.assertAmountEquals(balAfter.balances[0].pendingOutgoing, "TESTKUDOS:0");
+
+  // Now, test tiny deposits where fees eat the amount!
+
+  {
+    const withdrawalResult = await withdrawViaBankV3(t, {
+      walletClient,
+      bankClient,
+      exchange,
+      amount: "TESTKUDOS:5",
+    });
+    await withdrawalResult.withdrawalFinishedCond;
+  }
+
+  {
+    const amt = "TESTKUDOS:0.01" as AmountString;
+    const res = await walletClient.call(WalletApiOperation.CheckDeposit, {
+      amount: amt,
+      depositPaytoUri,
+    });
+    console.log(`check res: ${j2s(res)}`);
+    const depositGroupResult = await walletClient.client.call(
+      WalletApiOperation.CreateDepositGroup,
+      {
+        amount: amt,
+        depositPaytoUri,
+      },
+    );
+
+    console.log(`create result:`);
+    console.log(j2s(depositGroupResult));
+
+    const transactions = await walletClient.call(
+      WalletApiOperation.GetTransactionsV2,
+      {},
+    );
+    console.log(j2s(transactions));
+    t.assertTrue(
+      transactions.transactions.find(
+        (x) => x.transactionId === depositGroupResult.transactionId,
+      ) != null,
+    );
+  }
 }
 
 runDepositTest.suites = ["wallet"];
