@@ -17,9 +17,10 @@
 /**
  * Imports.
  */
+import { j2s } from "@gnu-taler/taler-util";
 import { WalletApiOperation } from "@gnu-taler/taler-wallet-core";
-import { GlobalTestState } from "../harness/harness.js";
 import { createSimpleTestkudosEnvironmentV3 } from "../harness/environments.js";
+import { GlobalTestState } from "../harness/harness.js";
 
 /**
  * Test if the wallet handles outdated exchange versions correctly.
@@ -77,6 +78,35 @@ export async function runExchangeManagementTest(
   );
 
   t.assertDeepEqual(exchangesListResult4.exchanges.length, 1);
+
+  await walletClient.call(WalletApiOperation.DeleteExchange, {
+    exchangeBaseUrl: exchange.baseUrl,
+  });
+
+  const url = new URL(exchange.baseUrl);
+
+  {
+    await t.assertThrowsAsync(async () => {
+      await walletClient.call(WalletApiOperation.AddExchange, {
+        uri: `${url.hostname}:${url.port}`,
+      });
+    });
+  }
+
+  {
+    const err = await t.assertThrowsTalerErrorAsync(async () => {
+      const res = await walletClient.call(WalletApiOperation.AddExchange, {
+        uri: `${url.hostname}:${url.port}`,
+        allowCompletion: true,
+      });
+    });
+    console.log(j2s(err));
+    // Tries to complete to https://, but we use http in the local test.
+    t.assertDeepEqual(
+      (err.errorDetail as any).innerError.requestUrl,
+      "https://localhost:8081/keys",
+    );
+  }
 }
 
 runExchangeManagementTest.suites = ["wallet", "exchange"];
