@@ -20,31 +20,35 @@
 import {
   codecForMerchantOrderStatusUnpaid,
   ConfirmPayResultType,
-  MerchantApiClient,
+  j2s,
   PreparePayResultType,
+  succeedOrThrow,
   TalerCorebankApiClient,
+  TalerErrorCode,
+  TalerMerchantInstanceHttpClient,
+  TypedTalerErrorDetail,
 } from "@gnu-taler/taler-util";
 import { WalletApiOperation } from "@gnu-taler/taler-wallet-core";
-import { URL } from "url";
+import { URL } from "node:url";
 import { defaultCoinConfig } from "../harness/denomStructures.js";
+import {
+  createWalletDaemonWithClient,
+  FaultyMerchantTestEnvironmentNg,
+  withdrawViaBankV3,
+} from "../harness/environments.js";
 import {
   FaultInjectedExchangeService,
   FaultInjectedMerchantService,
 } from "../harness/faultInjection.js";
 import {
-    BankService,
+  BankService,
   ExchangeService,
-  generateRandomPayto,
+  getTestHarnessPaytoForLabel,
   GlobalTestState,
   harnessHttpLib,
   MerchantService,
   setupDb,
 } from "../harness/harness.js";
-import {
-  createWalletDaemonWithClient,
-  FaultyMerchantTestEnvironmentNg,
-  withdrawViaBankV3,
-} from "../harness/helpers.js";
 
 /**
  * Run a test case with a simple TESTKUDOS Taler environment, consisting
@@ -71,7 +75,6 @@ export async function createConfusedMerchantTestkudosEnvironment(
 
   const merchant = await MerchantService.create(t, {
     name: "testmerchant-1",
-    currency: "TESTKUDOS",
     httpPort: 8083,
     database: db.connStr,
   });
@@ -86,13 +89,18 @@ export async function createConfusedMerchantTestkudosEnvironment(
 
   let receiverName = "Exchange";
   let exchangeBankUsername = "exchange";
-  let exchangeBankPassword = "mypw";
-  let exchangePaytoUri = generateRandomPayto(exchangeBankUsername);
+  let exchangeBankPassword = "mypw-password";
+  let exchangePaytoUri = getTestHarnessPaytoForLabel(exchangeBankUsername);
 
   await exchange.addBankAccount("1", {
-    accountName: exchangeBankUsername,
-    accountPassword: exchangeBankPassword,
-    wireGatewayApiBaseUrl: new URL("accounts/exchange/taler-wire-gateway/", bank.baseUrl).href,
+    wireGatewayAuth: {
+      username: exchangeBankUsername,
+      password: exchangeBankPassword,
+    },
+    wireGatewayApiBaseUrl: new URL(
+      "accounts/exchange/taler-wire-gateway/",
+      bank.baseUrl,
+    ).href,
     accountPaytoUri: exchangePaytoUri,
   });
 
@@ -105,7 +113,7 @@ export async function createConfusedMerchantTestkudosEnvironment(
   const bankClient = new TalerCorebankApiClient(bank.corebankApiBaseUrl, {
     auth: {
       username: "admin",
-      password: "adminpw",
+      password: "admin-password",
     },
   });
 
@@ -128,17 +136,17 @@ export async function createConfusedMerchantTestkudosEnvironment(
   await merchant.start();
   await merchant.pingUntilAvailable();
 
-  await merchant.addInstanceWithWireAccount({
-    id: "default",
+  const { accessToken: adminAccessToken } = await merchant.addInstanceWithWireAccount({
+    id: "admin",
     name: "Default Instance",
-    paytoUris: [generateRandomPayto("merchant-default")],
+    paytoUris: [getTestHarnessPaytoForLabel("merchant-default")],
   });
 
   await merchant.addInstanceWithWireAccount({
     id: "minst1",
     name: "minst1",
-    paytoUris: [generateRandomPayto("minst1")],
-  });
+    paytoUris: [getTestHarnessPaytoForLabel("minst1")],
+  }, {adminAccessToken});
 
   console.log("setup done!");
 
@@ -150,6 +158,7 @@ export async function createConfusedMerchantTestkudosEnvironment(
     commonDb: db,
     exchange,
     merchant,
+    merchantAdminAccessToken: adminAccessToken,
     walletClient,
     bankClient,
     faultyMerchant,
@@ -164,7 +173,7 @@ export async function createConfusedMerchantTestkudosEnvironment(
 export async function runMerchantExchangeConfusionTest(t: GlobalTestState) {
   // Set up test environment
 
-  const { walletClient, bankClient, faultyExchange, faultyMerchant } =
+  const { walletClient, bankClient, faultyExchange, faultyMerchant, merchantAdminAccessToken } =
     await createConfusedMerchantTestkudosEnvironment(t);
 
   // Withdraw digital cash into the wallet.
@@ -178,7 +187,7 @@ export async function runMerchantExchangeConfusionTest(t: GlobalTestState) {
 
   await wres.withdrawalFinishedCond;
 
-  /**
+  /*
    * =========================================================================
    * Create an order and let the wallet pay under a session ID
    *
@@ -189,20 +198,25 @@ export async function runMerchantExchangeConfusionTest(t: GlobalTestState) {
 
   const merchant = faultyMerchant;
 
-  const merchantClient = new MerchantApiClient(merchant.makeInstanceBaseUrl());
+  const merchantClient = new TalerMerchantInstanceHttpClient(
+    merchant.makeInstanceBaseUrl(),
+  );
 
-  let orderResp = await merchantClient.createOrder({
-    order: {
-      summary: "Buy me!",
-      amount: "TESTKUDOS:5",
-      fulfillment_url: "https://example.com/article42",
-    },
-  });
+  let orderResp = succeedOrThrow(
+    await merchantClient.createOrder(merchantAdminAccessToken, {
+      order: {
+        summary: "Buy me!",
+        amount: "TESTKUDOS:5",
+        fulfillment_url: "https://example.com/article42",
+      },
+    }),
+  );
 
-  let orderStatus = await merchantClient.queryPrivateOrderStatus({
-    orderId: orderResp.order_id,
-    sessionId: "mysession-one",
-  });
+  let orderStatus = succeedOrThrow(
+    await merchantClient.getOrderDetails(merchantAdminAccessToken, orderResp.order_id, {
+      sessionId: "mysession-one",
+    }),
+  );
 
   t.assertTrue(orderStatus.order_status === "unpaid");
 
@@ -232,7 +246,7 @@ export async function runMerchantExchangeConfusionTest(t: GlobalTestState) {
 
   t.assertTrue(preparePayResp.status === PreparePayResultType.PaymentPossible);
 
-  const proposalId = preparePayResp.proposalId;
+  const proposalTransactionId = preparePayResp.transactionId;
 
   const orderUrlWithHash = new URL(publicOrderStatusUrl);
   orderUrlWithHash.searchParams.set(
@@ -255,10 +269,28 @@ export async function runMerchantExchangeConfusionTest(t: GlobalTestState) {
   );
 
   const confirmPayRes = await walletClient.call(WalletApiOperation.ConfirmPay, {
-    proposalId: proposalId,
+    transactionId: proposalTransactionId,
   });
 
-  t.assertTrue(confirmPayRes.type === ConfirmPayResultType.Done);
+  t.assertTrue(confirmPayRes.type === ConfirmPayResultType.Pending);
+
+  console.log(j2s(confirmPayRes.lastError));
+
+  // Merchant should not accept the payment!
+  // Something is clearly wrong, as the exchange now announces
+  // its own base URL and something is wrong.
+
+  // FIXME: This error code should probably be refined in the future.
+
+  t.assertDeepEqual(
+    confirmPayRes.lastError?.code,
+    TalerErrorCode.WALLET_UNEXPECTED_REQUEST_ERROR,
+  );
+
+  const err =
+    confirmPayRes.lastError as TypedTalerErrorDetail<TalerErrorCode.WALLET_UNEXPECTED_REQUEST_ERROR>;
+
+  t.assertDeepEqual(err.httpStatusCode, 400);
 }
 
 runMerchantExchangeConfusionTest.suites = ["merchant"];
