@@ -18,6 +18,7 @@
  * Imports.
  */
 import {
+  j2s,
   PreparePayResultType,
   succeedOrThrow,
   TalerErrorCode,
@@ -37,14 +38,19 @@ import { GlobalTestState } from "../harness/harness.js";
 export async function runPaymentClaimTest(t: GlobalTestState) {
   // Set up test environment
 
-  const { walletClient, bankClient, exchange, merchant, merchantAdminAccessToken } =
-    await createSimpleTestkudosEnvironmentV3(t);
+  const {
+    walletClient,
+    bankClient,
+    exchange,
+    merchant,
+    merchantAdminAccessToken,
+  } = await createSimpleTestkudosEnvironmentV3(t);
 
   const merchantClient = new TalerMerchantInstanceHttpClient(
     merchant.makeInstanceBaseUrl(),
   );
 
-  const w2 = await createWalletDaemonWithClient(t, { name: "w2" });
+  const w2 = await createWalletDaemonWithClient(t, { name: "w2", persistent: true });
 
   // Withdraw digital cash into the wallet.
 
@@ -70,7 +76,10 @@ export async function runPaymentClaimTest(t: GlobalTestState) {
   );
 
   let orderStatus = succeedOrThrow(
-    await merchantClient.getOrderDetails(merchantAdminAccessToken, orderResp.order_id),
+    await merchantClient.getOrderDetails(
+      merchantAdminAccessToken,
+      orderResp.order_id,
+    ),
   );
 
   t.assertTrue(orderStatus.order_status === "unpaid");
@@ -90,11 +99,11 @@ export async function runPaymentClaimTest(t: GlobalTestState) {
     preparePayResult.status === PreparePayResultType.PaymentPossible,
   );
 
-  const errOne = t.assertThrowsTalerErrorAsyncLegacy(
-    w2.walletClient.call(WalletApiOperation.PreparePayForUri, {
+  const errOne = await t.assertThrowsTalerErrorAsync(async () => {
+    await w2.walletClient.call(WalletApiOperation.PreparePayForUri, {
       talerPayUri,
-    })
-  );
+    });
+  });
 
   console.log(errOne);
 
@@ -105,22 +114,29 @@ export async function runPaymentClaimTest(t: GlobalTestState) {
   // Check if payment was successful.
 
   orderStatus = succeedOrThrow(
-    await merchantClient.getOrderDetails(merchantAdminAccessToken, orderResp.order_id),
+    await merchantClient.getOrderDetails(
+      merchantAdminAccessToken,
+      orderResp.order_id,
+    ),
   );
 
   t.assertTrue(orderStatus.order_status === "paid");
 
   await w2.walletClient.call(WalletApiOperation.ClearDb, {});
 
-  const err = await t.assertThrowsTalerErrorAsyncLegacy(
-    w2.walletClient.call(WalletApiOperation.PreparePayForUri, {
+  const err = await t.assertThrowsTalerErrorAsync(async () => {
+    await w2.walletClient.call(WalletApiOperation.PreparePayForUri, {
       talerPayUri,
-    })
-  );
+    });
+  });
 
   t.assertTrue(err.hasErrorCode(TalerErrorCode.WALLET_ORDER_ALREADY_CLAIMED));
 
-  await t.shutdown();
+  const txn = await w2.walletClient.call(WalletApiOperation.GetTransactionsV2, {
+    includeAll: true,
+  });
+
+  console.log(j2s(txn));
 }
 
 runPaymentClaimTest.suites = ["wallet"];
