@@ -23,7 +23,7 @@ import {
   createSimpleTestkudosEnvironmentV3,
   withdrawViaBankV3,
   makeTestPaymentV2,
-} from "../harness/helpers.js";
+} from "../harness/environments.js";
 import { TransactionMajorState } from "@gnu-taler/taler-util";
 
 /**
@@ -33,7 +33,7 @@ import { TransactionMajorState } from "@gnu-taler/taler-util";
 export async function runPaymentZeroTest(t: GlobalTestState) {
   // Set up test environment
 
-  const { walletClient, bankClient, exchange, merchant } =
+  const { walletClient, bankClient, exchange, merchant, merchantAdminAccessToken } =
     await createSimpleTestkudosEnvironmentV3(t);
 
   // First, make a "free" payment when we don't even have
@@ -47,6 +47,7 @@ export async function runPaymentZeroTest(t: GlobalTestState) {
   await makeTestPaymentV2(t, {
     walletClient,
     merchant,
+    merchantAdminAccessToken,
     order: {
       summary: "I am free!",
       amount: "TESTKUDOS:0",
