@@ -24,11 +24,11 @@ import {
   j2s,
 } from "@gnu-taler/taler-util";
 import { WalletApiOperation } from "@gnu-taler/taler-wallet-core";
-import { GlobalTestState } from "../harness/harness.js";
 import {
-  createSimpleTestkudosEnvironmentV2,
-  withdrawViaBankV2,
-} from "../harness/helpers.js";
+  createSimpleTestkudosEnvironmentV3,
+  withdrawViaBankV3,
+} from "../harness/environments.js";
+import { GlobalTestState } from "../harness/harness.js";
 
 /**
  * Basic time travel test.
@@ -36,14 +36,14 @@ import {
 export async function runTimetravelWithdrawTest(t: GlobalTestState) {
   // Set up test environment
 
-  const { walletClient, bank, exchange, merchant } =
-    await createSimpleTestkudosEnvironmentV2(t);
+  const { walletClient, bankClient, exchange, merchant } =
+    await createSimpleTestkudosEnvironmentV3(t);
 
   // Withdraw digital cash into the wallet.
 
-  const wres1 = await withdrawViaBankV2(t, {
+  const wres1 = await withdrawViaBankV3(t, {
     walletClient,
-    bank,
+    bankClient,
     exchange,
     amount: "TESTKUDOS:15",
   });
@@ -70,9 +70,9 @@ export async function runTimetravelWithdrawTest(t: GlobalTestState) {
   console.log("starting withdrawal via bank");
 
   // This should fail, as the wallet didn't time travel yet.
-  const wres2 = await withdrawViaBankV2(t, {
+  const wres2 = await withdrawViaBankV3(t, {
     walletClient,
-    bank,
+    bankClient,
     exchange,
     amount: "TESTKUDOS:20",
   });
@@ -97,7 +97,7 @@ export async function runTimetravelWithdrawTest(t: GlobalTestState) {
 
   // Now we also let the wallet time travel
 
-  walletClient.call(WalletApiOperation.TestingSetTimetravel, {
+  await walletClient.call(WalletApiOperation.TestingSetTimetravel, {
     offsetMs: Duration.toMilliseconds(timetravelDuration),
   });
 
