@@ -19,20 +19,22 @@
  */
 import {
   AmountString,
-  NotificationType,
   TransactionMajorState,
   TransactionMinorState,
   j2s,
 } from "@gnu-taler/taler-util";
 import { WalletApiOperation } from "@gnu-taler/taler-wallet-core";
 import { CoinConfig } from "../harness/denomStructures.js";
-import { GlobalTestState, generateRandomPayto } from "../harness/harness.js";
 import {
   createSimpleTestkudosEnvironmentV3,
   createWalletDaemonWithClient,
   makeTestPaymentV2,
   withdrawViaBankV3,
-} from "../harness/helpers.js";
+} from "../harness/environments.js";
+import {
+  GlobalTestState,
+  getTestHarnessPaytoForLabel,
+} from "../harness/harness.js";
 
 const coinCommon = {
   cipher: "RSA" as const,
@@ -65,7 +67,7 @@ export async function runWalletBlockedDepositTest(t: GlobalTestState) {
     },
   ];
 
-  const { bankClient, exchange, merchant } =
+  const { bankClient, exchange, merchant, merchantAdminAccessToken } =
     await createSimpleTestkudosEnvironmentV3(t, coinConfigList);
 
   // Withdraw digital cash into the wallet.
@@ -97,6 +99,7 @@ export async function runWalletBlockedDepositTest(t: GlobalTestState) {
 
   await makeTestPaymentV2(t, {
     merchant,
+    merchantAdminAccessToken,
     walletClient: w1,
     order: {
       summary: "test",
@@ -104,7 +107,7 @@ export async function runWalletBlockedDepositTest(t: GlobalTestState) {
     },
   });
 
-  const userPayto = generateRandomPayto("foo");
+  const userPayto = getTestHarnessPaytoForLabel("foo");
 
   const bal = await w1.call(WalletApiOperation.GetBalances, {});
   console.log(`balance: ${j2s(bal)}`);
@@ -114,7 +117,7 @@ export async function runWalletBlockedDepositTest(t: GlobalTestState) {
   });
   console.log(`balance details: ${j2s(balDet)}`);
 
-  const depositCheckResp = await w1.call(WalletApiOperation.PrepareDeposit, {
+  const depositCheckResp = await w1.call(WalletApiOperation.CheckDeposit, {
     amount: "TESTKUDOS:18" as AmountString,
     depositPaytoUri: userPayto,
   });
@@ -131,20 +134,17 @@ export async function runWalletBlockedDepositTest(t: GlobalTestState) {
 
   console.log(`create resp: ${j2s(depositCreateResp)}`);
 
-  const depositTrackCond = w1.waitForNotificationCond((n) => {
-    return (
-      n.type === NotificationType.TransactionStateTransition &&
-      n.transactionId === depositCreateResp.transactionId &&
-      n.newTxState.major === TransactionMajorState.Pending &&
-      n.newTxState.minor === TransactionMinorState.Track
-    );
-  });
-
   await w1.call(WalletApiOperation.ApplyDevExperiment, {
     devExperimentUri: "taler://dev-experiment/stop-block-refresh",
   });
 
-  await depositTrackCond;
+  await w1.call(WalletApiOperation.TestingWaitTransactionState, {
+    transactionId: depositCreateResp.transactionId,
+    txState: {
+      major: TransactionMajorState.Finalizing,
+      minor: TransactionMinorState.Track,
+    },
+  });
 }
 
 runWalletBlockedDepositTest.suites = ["wallet"];
