@@ -28,7 +28,7 @@ import {
   applyTimeTravelV2,
   createSimpleTestkudosEnvironmentV3,
   withdrawViaBankV3,
-} from "../harness/helpers.js";
+} from "../harness/environments.js";
 
 const logger = new Logger("test-exchange-timetravel.ts");
 
