@@ -24,62 +24,24 @@
  */
 import { AmountString, Amounts, CoinStatus } from "@gnu-taler/taler-util";
 import { WalletApiOperation } from "@gnu-taler/taler-wallet-core";
-import { CoinConfig, defaultCoinConfig } from "../harness/denomStructures.js";
+import { createSimpleTestkudosEnvironmentV3 } from "../harness/environments.js";
 import { GlobalTestState, setupDb } from "../harness/harness.js";
-import {
-  SimpleTestEnvironmentNg3,
-  createSimpleTestkudosEnvironmentV3,
-  createWalletDaemonWithClient,
-} from "../harness/helpers.js";
-
-const merchantAuthToken = "secret-token:sandbox";
-
-/**
- * Run a test case with a simple TESTKUDOS Taler environment, consisting
- * of one exchange, one bank and one merchant.
- */
-export async function createMyEnvironment(
-  t: GlobalTestState,
-  coinConfig: CoinConfig[] = defaultCoinConfig.map((x) => x("TESTKUDOS")),
-): Promise<SimpleTestEnvironmentNg3> {
-  const db = await setupDb(t);
-
-  const { bankClient, exchange, merchant, exchangeBankAccount } =
-    await createSimpleTestkudosEnvironmentV3(t, coinConfig, {});
-
-  console.log("setup done!");
-
-  const { walletClient, walletService } = await createWalletDaemonWithClient(
-    t,
-    {
-      name: "w1",
-    },
-  );
-
-  return {
-    commonDb: db,
-    exchange,
-    merchant,
-    walletClient,
-    walletService,
-    bankClient,
-    exchangeBankAccount,
-  };
-}
 
 /**
  * Run test for basic, bank-integrated withdrawal.
  */
 export async function runWallettestingTest(t: GlobalTestState) {
-  const { walletClient, bankClient, exchange, merchant } =
-    await createMyEnvironment(t);
+  const db = await setupDb(t);
+
+  const { bankClient, walletClient, exchange, merchant, merchantAdminAccessToken } =
+    await createSimpleTestkudosEnvironmentV3(t, undefined, {});
 
   await walletClient.call(WalletApiOperation.RunIntegrationTest, {
     amountToSpend: "TESTKUDOS:5" as AmountString,
     amountToWithdraw: "TESTKUDOS:10" as AmountString,
     corebankApiBaseUrl: bankClient.baseUrl,
     exchangeBaseUrl: exchange.baseUrl,
-    merchantAuthToken: merchantAuthToken,
+    merchantAuthToken: merchantAdminAccessToken,
     merchantBaseUrl: merchant.makeInstanceBaseUrl(),
   });
 
@@ -108,7 +70,7 @@ export async function runWallettestingTest(t: GlobalTestState) {
 
   await walletClient.call(WalletApiOperation.TestPay, {
     amount: "TESTKUDOS:5" as AmountString,
-    merchantAuthToken: merchantAuthToken,
+    merchantAuthToken: merchantAdminAccessToken,
     merchantBaseUrl: merchant.makeInstanceBaseUrl(),
     summary: "foo",
   });
@@ -161,7 +123,7 @@ export async function runWallettestingTest(t: GlobalTestState) {
   await t.assertThrowsAsync(async () => {
     await walletClient.call(WalletApiOperation.TestPay, {
       amount: "TESTKUDOS:5" as AmountString,
-      merchantAuthToken: merchantAuthToken,
+      merchantAuthToken: merchantAdminAccessToken,
       merchantBaseUrl: merchant.makeInstanceBaseUrl(),
       summary: "foo",
     });
@@ -176,18 +138,22 @@ export async function runWallettestingTest(t: GlobalTestState) {
 
   await walletClient.call(WalletApiOperation.TestPay, {
     amount: "TESTKUDOS:5" as AmountString,
-    merchantAuthToken: merchantAuthToken,
+    merchantAuthToken: merchantAdminAccessToken,
     merchantBaseUrl: merchant.makeInstanceBaseUrl(),
     summary: "foo",
   });
 
   await walletClient.call(WalletApiOperation.ClearDb, {});
+  t.logStep("cleared-before-integration-test");
   await walletClient.call(WalletApiOperation.RunIntegrationTestV2, {
     corebankApiBaseUrl: bankClient.baseUrl,
     exchangeBaseUrl: exchange.baseUrl,
-    merchantAuthToken: merchantAuthToken,
+    merchantAuthToken: merchantAdminAccessToken,
     merchantBaseUrl: merchant.makeInstanceBaseUrl(),
   });
+  t.logStep("after-integration-test");
+
+  console.log("end of test");
 }
 
 runWallettestingTest.suites = ["wallet"];
