@@ -1,6 +1,6 @@
 /*
  This file is part of GNU Taler
- (C) 2020 Taler Systems S.A.
+ (C) 2020-2025 Taler Systems S.A.
 
  GNU Taler is free software; you can redistribute it and/or modify it under the
  terms of the GNU General Public License as published by the Free Software
@@ -20,7 +20,7 @@
 import { TalerErrorCode } from "@gnu-taler/taler-util";
 import { WalletApiOperation } from "@gnu-taler/taler-wallet-core";
 import { GlobalTestState } from "../harness/harness.js";
-import { createSimpleTestkudosEnvironmentV3 } from "../harness/helpers.js";
+import { createSimpleTestkudosEnvironmentV3 } from "../harness/environments.js";
 
 /**
  * Run test for basic, bank-integrated withdrawal.
@@ -60,12 +60,12 @@ export async function runWithdrawalAbortBankTest(t: GlobalTestState) {
   //
   // WHY ?!
   //
-  const e = await t.assertThrowsTalerErrorAsync(async () => {
-    await walletClient.call(WalletApiOperation.AcceptBankIntegratedWithdrawal, {
+  const e = await t.assertThrowsTalerErrorAsyncLegacy(
+    walletClient.call(WalletApiOperation.AcceptBankIntegratedWithdrawal, {
       exchangeBaseUrl: exchange.baseUrl,
       talerWithdrawUri: wop.taler_withdraw_uri,
-    });
-  });
+    })
+  );
   t.assertDeepEqual(
     e.errorDetail.code,
     TalerErrorCode.WALLET_WITHDRAWAL_OPERATION_ABORTED_BY_BANK,
