@@ -16,9 +16,11 @@
 
 import {
   CancellationToken,
+  j2s,
   Logger,
   minimatch,
   setGlobalLogLevelFromString,
+  TalerError,
 } from "@gnu-taler/taler-util";
 import * as child_process from "child_process";
 import { spawnSync } from "child_process";
@@ -42,6 +44,7 @@ import { runBankApiTest } from "./test-bank-api.js";
 import { runBankWopTest } from "./test-bank-wop.js";
 import { runClaimLoopTest } from "./test-claim-loop.js";
 import { runClauseSchnorrTest } from "./test-clause-schnorr.js";
+import { runCurrencyScopeSeparationTest } from "./test-currency-scope-separation.js";
 import { runCurrencyScopeTest } from "./test-currency-scope.js";
 import { runDenomLostComplexTest } from "./test-denom-lost-complex.js";
 import { runDenomLostTest } from "./test-denom-lost.js";
@@ -115,6 +118,7 @@ import { runMerchantSelfProvisionActivationTest } from "./test-merchant-self-pro
 import { runMerchantSelfProvisionForgotPasswordTest } from "./test-merchant-self-provision-forgot-password.js";
 import { runMerchantSelfProvisionInactiveAccountPermissionsTest } from "./test-merchant-self-provision-inactive-account-permissions.js";
 import { runMerchantSpecPublicOrdersTest } from "./test-merchant-spec-public-orders.js";
+import { runMerchantWireTest } from "./test-merchant-wire.js";
 import { runMultiExchangeTest } from "./test-multiexchange.js";
 import { runOtpTest } from "./test-otp.js";
 import { runPayPaidTest } from "./test-pay-paid.js";
@@ -142,6 +146,7 @@ import { runRefundAutoTest } from "./test-refund-auto.js";
 import { runRefundGoneTest } from "./test-refund-gone.js";
 import { runRefundIncrementalTest } from "./test-refund-incremental.js";
 import { runRefundTest } from "./test-refund.js";
+import { runRepurchaseV1Test } from "./test-repurchase-v1.js";
 import { runRepurchaseTest } from "./test-repurchase.js";
 import { runRevocationTest } from "./test-revocation.js";
 import { runSimplePaymentTest } from "./test-simple-payment.js";
@@ -154,6 +159,7 @@ import { runTopsAmlCustomAddrSmsTest } from "./test-tops-aml-custom-addr-sms.js"
 import { runTopsAmlKyxNaturalTest } from "./test-tops-aml-kyx-natural.js";
 import { runTopsAmlLegiTest } from "./test-tops-aml-legi.js";
 import { runTopsAmlMeasuresTest } from "./test-tops-aml-measures.js";
+import { runTopsAmlPdfTest } from "./test-tops-aml-pdf.js";
 import { runTopsChallengerTwiceTest } from "./test-tops-challenger-twice.js";
 import { runTopsPeerTest } from "./test-tops-peer.js";
 import { runTermOfServiceFormatTest } from "./test-tos-format.js";
@@ -163,6 +169,7 @@ import { runWalletBackupDoublespendTest } from "./test-wallet-backup-doublespend
 import { runWalletBalanceNotificationsTest } from "./test-wallet-balance-notifications.js";
 import { runWalletBalanceZeroTest } from "./test-wallet-balance-zero.js";
 import { runWalletBalanceTest } from "./test-wallet-balance.js";
+import { runWalletBbanTest } from "./test-wallet-bban.js";
 import { runWalletBlockedDepositTest } from "./test-wallet-blocked-deposit.js";
 import { runWalletBlockedPayMerchantTest } from "./test-wallet-blocked-pay-merchant.js";
 import { runWalletBlockedPayPeerPullTest } from "./test-wallet-blocked-pay-peer-pull.js";
@@ -176,6 +183,7 @@ import { runWalletDd48Test } from "./test-wallet-dd48.js";
 import { runWalletDenomExpireTest } from "./test-wallet-denom-expire.js";
 import { runWalletDevExperimentsTest } from "./test-wallet-dev-experiments.js";
 import { runWalletDevexpFakeprotoverTest } from "./test-wallet-devexp-fakeprotover.js";
+import { runWalletExchangeFeaturesTest } from "./test-wallet-exchange-features.js";
 import { runWalletExchangeMigrationExistingTest } from "./test-wallet-exchange-migration-existing.js";
 import { runWalletExchangeMigrationTest } from "./test-wallet-exchange-migration.js";
 import { runWalletExchangeUpdateTest } from "./test-wallet-exchange-update.js";
@@ -399,6 +407,12 @@ const allTests: TestMainFunction[] = [
   runDonauMultiTest,
   runDonauIdempotencyTest,
   runDonauKeychangeTest,
+  runTopsAmlPdfTest,
+  runMerchantWireTest,
+  runWalletExchangeFeaturesTest,
+  runRepurchaseV1Test,
+  runWalletBbanTest,
+  runCurrencyScopeSeparationTest,
 ];
 
 export interface TestRunSpec {
@@ -673,7 +687,6 @@ export async function runTests(spec: TestRunSpec) {
         throw Error("exit on fail fast");
       }
     } catch (e: any) {
-      console.error(`test ${testName} timed out`);
       if (token.isCancelled) {
         result = {
           status: "fail",
@@ -683,6 +696,7 @@ export async function runTests(spec: TestRunSpec) {
         };
         currentChild.kill("SIGTERM");
       } else {
+        logger.error(`test failed: ${j2s(TalerError.fromException(e))}`);
         throw Error(e);
       }
     }
