@@ -22,7 +22,12 @@
  * Imports.
  */
 import { codecForAmountString } from "./amounts.js";
-import { Codec, buildCodecForObject } from "./codec.js";
+import {
+  Codec,
+  buildCodecForObject,
+  codecForString,
+  codecOptional,
+} from "./codec.js";
 import { AmountString } from "./types-taler-common.js";
 
 /**
@@ -35,9 +40,19 @@ export interface ReserveStatus {
    * Balance left in the reserve.
    */
   balance: AmountString;
+
+  /**
+   * Full payto URI of the bank account that
+   * (most recently) funded this reserve.
+   * Useful as a hint for deposit operations for wallets.
+   * Missing if this reserve was only filled via P2P merges.
+   * @since protocol **v23**.
+   */
+  last_origin?: string;
 }
 
 export const codecForReserveStatus = (): Codec<ReserveStatus> =>
   buildCodecForObject<ReserveStatus>()
     .property("balance", codecForAmountString())
+    .property("last_origin", codecOptional(codecForString()))
     .build("ReserveStatus");
