@@ -605,7 +605,7 @@ export class TalerExchangeHttpClient {
 
     switch (resp.status) {
       case HttpStatusCode.Ok: // means there are voluntary checks
-      case HttpStatusCode.Accepted: // means there are requried checks
+      case HttpStatusCode.Accepted: // means there are required checks
         return opKnownAlternativeHttpFailure(
           resp,
           resp.status,
@@ -1132,6 +1132,82 @@ export class TalerExchangeHttpClient {
     }
   }
 
+  async getAmlAttributesForAccountAsPdf(
+    auth: OfficerAccount,
+    account: string,
+    params: PaginationParams = {},
+  ): Promise<
+    | OperationOk<ArrayBuffer>
+    | OperationFail<
+        | HttpStatusCode.Forbidden
+        | HttpStatusCode.NotFound
+        | HttpStatusCode.Conflict
+        | HttpStatusCode.NoContent
+      >
+  > {
+    const url = new URL(`aml/${auth.id}/attributes/${account}`, this.baseUrl);
+
+    addPaginationParams(url, params);
+    const resp = await this.fetch(url, {
+      headers: {
+        Accept: "application/pdf",
+        "Taler-AML-Officer-Signature": encodeCrock(
+          signAmlQuery(auth.signingKey),
+        ),
+      },
+    });
+
+    switch (resp.status) {
+      case HttpStatusCode.Ok: {
+        return opFixedSuccess(await resp.bytes());
+      }
+      case HttpStatusCode.NoContent:
+      case HttpStatusCode.Forbidden:
+      case HttpStatusCode.NotFound:
+      case HttpStatusCode.Conflict:
+        return opKnownHttpFailure(resp.status, resp);
+      default:
+        return opUnknownHttpFailure(resp);
+    }
+  }
+
+  async getAmlAccountsAsOtherFormat(
+    auth: OfficerAccount,
+    mime: string,
+  ): Promise<
+    | OperationOk<ArrayBuffer>
+    | OperationFail<
+        | HttpStatusCode.Forbidden
+        | HttpStatusCode.NotFound
+        | HttpStatusCode.Conflict
+        | HttpStatusCode.NoContent
+      >
+  > {
+    const url = new URL(`aml/${auth.id}/accounts`, this.baseUrl);
+
+    const resp = await this.fetch(url, {
+      headers: {
+        Accept: mime,
+        "Taler-AML-Officer-Signature": encodeCrock(
+          signAmlQuery(auth.signingKey),
+        ),
+      },
+    });
+
+    switch (resp.status) {
+      case HttpStatusCode.Ok: {
+        return opFixedSuccess(await resp.bytes());
+      }
+      case HttpStatusCode.NoContent:
+      case HttpStatusCode.Forbidden:
+      case HttpStatusCode.NotFound:
+      case HttpStatusCode.Conflict:
+        return opKnownHttpFailure(resp.status, resp);
+      default:
+        return opUnknownHttpFailure(resp);
+    }
+  }
+
   /**
    * https://docs.taler.net/core/api-exchange.html#post--aml-$OFFICER_PUB-decision
    *
