@@ -15,7 +15,7 @@
  */
 
 import { setPRNG } from "./nacl-fast.js";
-import cr from "crypto";
+import cr from "node:crypto";
 
 export function initNodePrng() {
   // Initialize PRNG if environment provides CSPRNG.
