@@ -26,9 +26,9 @@ import {
   EddsaSigP,
   hash,
   stringToBytes,
-  TalerSignaturePurpose,
   timestampRoundedToBuffer,
 } from "./taler-crypto.js";
+import { TalerSignaturePurpose } from "./taler_signatures.js";
 import { TalerProtocolTimestamp } from "./time.js";
 import { AmlDecisionRequestWithoutSignature } from "./types-taler-exchange.js";
 
