@@ -511,12 +511,10 @@ transactionsCli.action(async (args) => {
     },
     async (wallet) => {
       const pending = await wallet.client.call(
-        WalletApiOperation.GetTransactions,
+        WalletApiOperation.GetTransactionsV2,
         {
           currency: args.transactions.currency,
-          search: args.transactions.search,
           includeRefreshes: args.transactions.includeRefreshes,
-          sort: "stable-ascending",
         },
       );
       console.log(JSON.stringify(pending, undefined, 2));
