@@ -39,10 +39,20 @@
  * - "age-acceptable": Subset of the material balance that can be spent
  *   with age restrictions applied.
  *
- * - "merchant-acceptable": Subset of the material balance that can be spent with a particular
+ * - "receiver-acceptable": Subset of the material balance that can be spent with a particular
  *   merchant (restricted via min age, exchange, auditor, wire_method).
+ *   Deprecated in favor of more specific "receiver-*-acceptable"" balance types.
  *
- * - "merchant-depositable": Subset of the merchant-acceptable balance that the merchant
+ * - "receiver-exchange-url-acceptable": Subset of the material balance that can be spent
+ *   with a particular merchant based on the exchange URLs it accepts.
+ *
+ * - "receiver-exchange-pub-acceptable": Subset of the material balance that can be spent
+ *   with a particular merchant based on the exchange public keys it accepts.
+ *
+ * - "receiver-auditor-url-acceptable": Subset of the material balance that can be spent
+ *   with a particular merchant based on the auditor URLs it accepts.
+ *
+ * - "receiver-depositable": Subset of the merchant-acceptable balance that the merchant
  *   can accept via their supported wire methods.
  */
 
@@ -58,6 +68,7 @@ import {
   assertUnreachable,
   BalanceFlag,
   BalancesResponse,
+  BalancesScopeRequest,
   checkDbInvariant,
   DonauSummaryItem,
   GetBalanceDetailRequest,
@@ -87,8 +98,8 @@ import {
 } from "./db.js";
 import {
   checkExchangeInScopeTx,
+  getExchangeDetailsInTx,
   getExchangeScopeInfo,
-  getExchangeWireDetailsInTx,
 } from "./exchanges.js";
 import { getDenomInfo, WalletExecutionContext } from "./wallet.js";
 
@@ -105,6 +116,9 @@ interface WalletBalance {
   flagIncomingKyc: boolean;
   flagIncomingConfirmation: boolean;
   flagOutgoingKyc: boolean;
+  disablePeerPayments: boolean;
+  disableDirectDeposits: boolean;
+  shoppingUrls: Set<string>;
 }
 
 function computeRefreshGroupAvailableAmountForExchanges(
@@ -203,6 +217,9 @@ class BalancesStore {
         flagIncomingConfirmation: false,
         flagIncomingKyc: false,
         flagOutgoingKyc: false,
+        disablePeerPayments: false,
+        disableDirectDeposits: false,
+        shoppingUrls: new Set(),
       };
     }
     return this.balanceStore[balanceKey];
@@ -212,6 +229,31 @@ class BalancesStore {
     await this.initBalance(currency, exchangeBaseUrl);
   }
 
+  async setPeerPaymentsDisabled(
+    currency: string,
+    exchangeBaseUrl: string,
+  ): Promise<void> {
+    const b = await this.initBalance(currency, exchangeBaseUrl);
+    b.disablePeerPayments = true;
+  }
+
+  async setDirectDepositsDisabled(
+    currency: string,
+    exchangeBaseUrl: string,
+  ): Promise<void> {
+    const b = await this.initBalance(currency, exchangeBaseUrl);
+    b.disableDirectDeposits = true;
+  }
+
+  async addShoppingUrl(
+    currency: string,
+    exchangeBaseUrl: string,
+    shoppingUrl: string,
+  ): Promise<void> {
+    const b = await this.initBalance(currency, exchangeBaseUrl);
+    b.shoppingUrls.add(shoppingUrl);
+  }
+
   async addAvailable(
     currency: string,
     exchangeBaseUrl: string,
@@ -299,7 +341,7 @@ class BalancesStore {
         if (scopeA !== scopeB) return scopeA - scopeB;
         return a.localeCompare(b);
       })
-      .forEach((c) => {
+      .forEach((c, i) => {
         const v = balanceStore[c];
         const flags: BalanceFlag[] = [];
         if (v.flagIncomingKyc) {
@@ -311,16 +353,33 @@ class BalancesStore {
         if (v.flagOutgoingKyc) {
           flags.push(BalanceFlag.OutgoingKyc);
         }
+        let shoppingUrls: string[];
+        if (this.wex.ws.devExperimentState.fakeShoppingUrl != null) {
+          shoppingUrls = [this.wex.ws.devExperimentState.fakeShoppingUrl];
+        } else {
+          shoppingUrls = [...v.shoppingUrls];
+        }
+        let disableDirectDeposits: boolean;
+        if (this.wex.ws.devExperimentState.flagDisableDirectDeposits) {
+          disableDirectDeposits = true;
+        } else {
+          disableDirectDeposits = v.disablePeerPayments;
+        }
+        let disablePeerPayments: boolean;
+        if (i === 0 && this.wex.ws.devExperimentState.flagDisablePeerPayments) {
+          disablePeerPayments = true; // only disable for first balance
+        } else {
+          disablePeerPayments = v.disablePeerPayments;
+        }
         balancesResponse.balances.push({
           scopeInfo: v.scopeInfo,
           available: Amounts.stringify(v.available),
           pendingIncoming: Amounts.stringify(v.pendingIncoming),
           pendingOutgoing: Amounts.stringify(v.pendingOutgoing),
-          // FIXME: This field is basically not implemented, do we even need it?
-          hasPendingTransactions: false,
-          // FIXME: This field is basically not implemented, do we even need it?
-          requiresUserInput: false,
           flags,
+          shoppingUrls,
+          disablePeerPayments,
+          disableDirectDeposits,
         });
       });
     return balancesResponse;
@@ -368,9 +427,25 @@ export async function getBalancesInsideTransaction(
       ex.entryStatus === ExchangeEntryDbRecordStatus.Used ||
       ex.tosAcceptedTimestamp != null
     ) {
-      const det = await getExchangeWireDetailsInTx(tx, ex.baseUrl);
+      const det = await getExchangeDetailsInTx(tx, ex.baseUrl);
       if (det) {
         await balanceStore.addZero(det.currency, ex.baseUrl);
+        if (ex.peerPaymentsDisabled) {
+          await balanceStore.setPeerPaymentsDisabled(det.currency, ex.baseUrl);
+        }
+        if (ex.directDepositDisabled) {
+          await balanceStore.setDirectDepositsDisabled(
+            det.currency,
+            ex.baseUrl,
+          );
+        }
+        if (det.shoppingUrl) {
+          await balanceStore.addShoppingUrl(
+            det.currency,
+            ex.baseUrl,
+            det.shoppingUrl,
+          );
+        }
       }
     }
   });
@@ -697,6 +772,27 @@ export async function getBalances(
   return wbal;
 }
 
+/**
+ * Get detailed balance information of one exchange and currency.
+ */
+export async function getBalanceOfScope(
+  wex: WalletExecutionContext,
+  req: BalancesScopeRequest,
+): Promise<BalancesResponse> {
+  logger.trace("starting to compute balance");
+
+  const wbal = await wex.db.runAllStoresReadOnlyTx({}, async (tx) => {
+    return getBalancesInsideTransaction(wex, tx);
+  });
+
+  wbal.balances.find((w) => {
+    w.scopeInfo;
+  });
+  logger.trace("finished computing wallet balance");
+
+  return wbal;
+}
+
 export interface PaymentRestrictionsForBalance {
   currency: string;
 
@@ -751,9 +847,26 @@ export interface PaymentBalanceDetails {
 
   /**
    * Balance of type "receiver-acceptable" (see balance.ts for definition).
+   *
+   * @deprecated (2025-12-05) use balanceReceiver[...]Acceptable instead.
    */
   balanceReceiverAcceptable: AmountJson;
 
+  /**
+   * Balance of type "receiver-exchange-url-acceptable" (see balance.ts for definition).
+   */
+  balanceReceiverExchangeUrlAcceptable: AmountJson;
+
+  /**
+   * Balance of type "receiver-exchange-pub-acceptable" (see balance.ts for definition).
+   */
+  balanceReceiverExchangePubAcceptable: AmountJson;
+
+  /**
+   * Balance of type "receiver-auditor-url-acceptable" (see balance.ts for definition).
+   */
+  balanceReceiverAuditorUrlAcceptable: AmountJson;
+
   /**
    * Balance of type "receiver-depositable" (see balance.ts for definition).
    */
@@ -815,6 +928,9 @@ export async function getPaymentBalanceDetailsInTx(
     balanceMaterial: Amounts.zeroOfCurrency(req.currency),
     balanceAgeAcceptable: Amounts.zeroOfCurrency(req.currency),
     balanceReceiverAcceptable: Amounts.zeroOfCurrency(req.currency),
+    balanceReceiverExchangeUrlAcceptable: Amounts.zeroOfCurrency(req.currency),
+    balanceReceiverExchangePubAcceptable: Amounts.zeroOfCurrency(req.currency),
+    balanceReceiverAuditorUrlAcceptable: Amounts.zeroOfCurrency(req.currency),
     balanceReceiverDepositable: Amounts.zeroOfCurrency(req.currency),
     maxMerchantEffectiveDepositAmount: Amounts.zeroOfCurrency(req.currency),
     balanceExchangeDepositable: Amounts.zeroOfCurrency(req.currency),
@@ -851,10 +967,7 @@ export async function getPaymentBalanceDetailsInTx(
       continue;
     }
 
-    const wireDetails = await getExchangeWireDetailsInTx(
-      tx,
-      ca.exchangeBaseUrl,
-    );
+    const wireDetails = await getExchangeDetailsInTx(tx, ca.exchangeBaseUrl);
     if (!wireDetails) {
       continue;
     }
@@ -887,27 +1000,41 @@ export async function getPaymentBalanceDetailsInTx(
 
     let ageOkay = ca.maxAge === 0 || ca.maxAge > req.minAge;
 
-    let merchantExchangeAcceptable = false;
+    let merchantExchangePubAcceptable = false;
+    let merchantExchangeUrlAcceptable = false;
+    let merchantExchangeAuditorAcceptable = false;
 
     if (!req.restrictReceiverExchanges) {
-      merchantExchangeAcceptable = true;
+      merchantExchangePubAcceptable = true;
+      merchantExchangeUrlAcceptable = true;
+      merchantExchangeAuditorAcceptable = true;
     } else {
       for (const ex of req.restrictReceiverExchanges.exchanges) {
-        if (ex.exchangeBaseUrl === ca.exchangeBaseUrl) {
-          merchantExchangeAcceptable = true;
+        if (ex.exchangePub === ca.exchangeMasterPub) {
+          merchantExchangePubAcceptable = true;
           break;
         }
       }
+
+      for (const ex of req.restrictReceiverExchanges.exchanges) {
+        if (ex.exchangeBaseUrl === ca.exchangeBaseUrl) {
+          merchantExchangeUrlAcceptable = true;
+          break;
+        }
+      }
+
       for (const acceptedAuditor of req.restrictReceiverExchanges.auditors) {
         for (const exchangeAuditor of wireDetails.auditors) {
           if (acceptedAuditor.auditorBaseUrl === exchangeAuditor.auditor_url) {
-            merchantExchangeAcceptable = true;
+            merchantExchangeAuditorAcceptable = true;
             break;
           }
         }
       }
     }
 
+    const merchantExchangeAcceptable =
+      merchantExchangeUrlAcceptable || merchantExchangeAuditorAcceptable;
     const merchantExchangeDepositable = merchantExchangeAcceptable && wireOkay;
 
     d.balanceAvailable = Amounts.add(d.balanceAvailable, coinAmount).amount;
@@ -928,6 +1055,24 @@ export async function getPaymentBalanceDetailsInTx(
             coinAmount,
           ).amount;
         }
+        if (merchantExchangeUrlAcceptable) {
+          d.balanceReceiverExchangeUrlAcceptable = Amounts.add(
+            d.balanceReceiverExchangeUrlAcceptable,
+            coinAmount,
+          ).amount;
+        }
+        if (merchantExchangePubAcceptable) {
+          d.balanceReceiverExchangePubAcceptable = Amounts.add(
+            d.balanceReceiverExchangePubAcceptable,
+            coinAmount,
+          ).amount;
+        }
+        if (merchantExchangeAuditorAcceptable) {
+          d.balanceReceiverAuditorUrlAcceptable = Amounts.add(
+            d.balanceReceiverAuditorUrlAcceptable,
+            coinAmount,
+          ).amount;
+        }
       }
     }
 
@@ -974,7 +1119,7 @@ export async function getBalanceDetail(
     async (tx) => {
       const allExchanges = await tx.exchanges.iter().toArray();
       for (const e of allExchanges) {
-        const details = await getExchangeWireDetailsInTx(tx, e.baseUrl);
+        const details = await getExchangeDetailsInTx(tx, e.baseUrl);
         if (!details || req.currency !== details.currency) {
           continue;
         }
