@@ -31,14 +31,15 @@ import {
   AgeCommitmentProof,
   AmountJson,
   AmountString,
-  CoinEnvelope,
   DenominationPubKey,
+  EddsaPrivateKeyString,
   EddsaPublicKeyString,
   EddsaSignatureString,
   ExchangeProtocolVersion,
+  HashCodeString,
   RefreshPlanchetInfo,
   TalerProtocolTimestamp,
-  UnblindedSignature,
+  UnblindedDenominationSignature,
   WalletAccountMergeFlags,
 } from "@gnu-taler/taler-util";
 
@@ -68,8 +69,23 @@ export interface DeriveRefreshSessionRequest {
 }
 
 /**
+ * Request to derive a refresh session from the refresh session
+ * public seed.
  *
+ * This version is for the improved, PQC-compatible refresh protocol.
  */
+export interface DeriveRefreshSessionRequestV2 {
+  sessionPublicSeed: string;
+  kappa: number;
+  meltCoinPub: string;
+  meltCoinPriv: string;
+  meltCoinDenomPubHash: string;
+  meltCoinMaxAge: number;
+  meltCoinAgeCommitmentProof?: AgeCommitmentProof;
+  newCoinDenoms: RefreshNewDenomInfo[];
+  feeRefresh: AmountJson;
+}
+
 export interface DerivedRefreshSession {
   /**
    * Public key that's being melted in this session.
@@ -84,7 +100,7 @@ export interface DerivedRefreshSession {
   /**
    * Planchets for each cut-and-choose instance.
    */
-  planchetsForGammas: RefreshPlanchetInfo[][];
+  planchets: RefreshPlanchetInfo[][];
 
   /**
    * The transfer keys, kappa of them.
@@ -107,22 +123,36 @@ export interface DerivedRefreshSession {
   meltValueWithFee: AmountJson;
 }
 
-export interface DeriveTipRequest {
-  secretSeed: string;
-  denomPub: DenominationPubKey;
-  planchetIndex: number;
-}
+export interface DerivedRefreshSessionV2 {
+  /**
+   * Public key that's being melted in this session.
+   */
+  meltCoinPub: string;
 
-/**
- * Tipping planchet stored in the database.
- */
-export interface DerivedTipPlanchet {
-  blindingKey: string;
-  coinEv: CoinEnvelope;
-  coinEvHash: string;
-  coinPriv: string;
-  coinPub: string;
-  ageCommitmentProof: AgeCommitmentProof | undefined;
+  /**
+   * Signature to confirm the melting.
+   */
+  confirmSig: string;
+
+  /**
+   * Planchets for each cut-and-choose instance.
+   */
+  planchets: RefreshPlanchetInfo[][];
+
+  /**
+   * kappa signatures by the old coin private key.
+   */
+  signatures: EddsaSignatureString[];
+
+  /**
+   * Hash of the session.
+   */
+  hash: string;
+
+  /**
+   * Exact value that is being melted.
+   */
+  meltValueWithFee: AmountJson;
 }
 
 export interface SignTrackTransactionRequest {
@@ -142,7 +172,7 @@ export interface CreateRecoupReqRequest {
   blindingKey: string;
   denomPub: DenominationPubKey;
   denomPubHash: string;
-  denomSig: UnblindedSignature;
+  denomSig: UnblindedDenominationSignature;
 }
 
 /**
@@ -154,7 +184,7 @@ export interface CreateRecoupRefreshReqRequest {
   blindingKey: string;
   denomPub: DenominationPubKey;
   denomPubHash: string;
-  denomSig: UnblindedSignature;
+  denomSig: UnblindedDenominationSignature;
 }
 
 export interface EncryptedContract {
@@ -244,6 +274,15 @@ export interface SignWalletKycAuthResponse {
   sig: string;
 }
 
+export interface SignContractTermsHashRequest {
+  merchantPriv: EddsaPrivateKeyString;
+  contractTermsHash: HashCodeString;
+}
+
+export interface SignContractTermsHashResponse {
+  sig: string;
+}
+
 export interface SignPurseMergeRequest {
   mergeTimestamp: TalerProtocolTimestamp;
 
