@@ -305,7 +305,7 @@ export async function handleSetDonau(
       oldRec.value.donauBaseUrl === req.donauBaseUrl &&
       oldRec.value.donauTaxId === req.taxPayerId
     ) {
-      // Be idempotent, re-use old salt.
+      // Be idempotent, reuse old salt.
       return;
     }
     await tx.config.put({
@@ -426,7 +426,7 @@ export async function generateDonauPlanchets(
       return undefined;
     }
     if (!rec.donauAmount) {
-      throw Error("db consistency error: donau amout not set");
+      throw Error("db consistency error: donau amount not set");
     }
     if (typeof rec.donauYear !== "number") {
       throw Error("db consistency error: donau year not a number");
