@@ -58,3 +58,31 @@ export function makeTempfileId(length: number): string {
   }
   return result;
 }
+
+/**
+ * Get the underlying sqlite3 DB filename
+ * from the storage path specified by the wallet-core client.
+ */
+export function getSqlite3FilenameFromStoragePath(
+  p: string | undefined,
+): string {
+  // Allow specifying a directory as the storage path.
+  // In that case, we pick the filename and use the sqlite3
+  // backend.
+  //
+  // We still allow specifying a filename for backwards
+  // compatibility and control over the exact file.
+  //
+  // Specifying a directory allows us to automatically
+  // migrate to a new DB file in the future.
+  if (!p) {
+    return ":memory:";
+  }
+  if (p.endsWith("/")) {
+    // Current sqlite3 DB filename.
+    // Should rarely if ever change.
+    return `${p}talerwalletdb-v30.sqlite3`;
+  } else {
+    return p;
+  }
+}
