@@ -23,20 +23,19 @@
  * Imports.
  */
 import type {
-  IDBFactory,
   ResultRow,
   Sqlite3Interface,
   Sqlite3Statement,
 } from "@gnu-taler/idb-bridge";
 // eslint-disable-next-line no-duplicate-imports
 import {
-  AccessStats,
   BridgeIDBFactory,
-  MemoryBackend,
   createSqliteBackend,
+  MemoryBackend,
   shimIndexedDB,
 } from "@gnu-taler/idb-bridge";
 import {
+  j2s,
   Logger,
   SetTimeoutTimerAPI,
   WalletRunConfig,
@@ -44,16 +43,16 @@ import {
 import { createPlatformHttpLib } from "@gnu-taler/taler-util/http";
 import { qjsOs, qjsStd } from "@gnu-taler/taler-util/qtart";
 import { SynchronousCryptoWorkerFactoryPlain } from "./crypto/workers/synchronousWorkerFactoryPlain.js";
-import { DefaultNodeWalletArgs, makeTempfileId } from "./host-common.js";
-import { Wallet } from "./wallet.js";
+import {
+  DefaultNodeWalletArgs,
+  getSqlite3FilenameFromStoragePath,
+  makeTempfileId,
+} from "./host-common.js";
+import { exportDb } from "./index.js";
+import { Wallet, WalletDatabaseImplementation } from "./wallet.js";
 
 const logger = new Logger("host-impl.qtart.ts");
 
-interface MakeDbResult {
-  idbFactory: BridgeIDBFactory;
-  getStats: () => AccessStats;
-}
-
 let numStmt = 0;
 
 export async function createQtartSqlite3Impl(): Promise<Sqlite3Interface> {
@@ -62,32 +61,32 @@ export async function createQtartSqlite3Impl(): Promise<Sqlite3Interface> {
     throw Error("globalThis._qtart not defined");
   }
   return {
-    open(filename: string) {
+    async open(filename: string) {
       const internalDbHandle = tart.sqlite3Open(filename);
       return {
         internalDbHandle,
-        close() {
+        async close() {
           tart.sqlite3Close(internalDbHandle);
         },
-        prepare(stmtStr): Sqlite3Statement {
+        async prepare(stmtStr): Promise<Sqlite3Statement> {
           const stmtHandle = tart.sqlite3Prepare(internalDbHandle, stmtStr);
           return {
             internalStatement: stmtHandle,
-            getAll(params): ResultRow[] {
+            async getAll(params): Promise<ResultRow[]> {
               numStmt++;
               return tart.sqlite3StmtGetAll(stmtHandle, params);
             },
-            getFirst(params): ResultRow | undefined {
+            async getFirst(params): Promise<ResultRow | undefined> {
               numStmt++;
               return tart.sqlite3StmtGetFirst(stmtHandle, params);
             },
-            run(params) {
+            async run(params) {
               numStmt++;
               return tart.sqlite3StmtRun(stmtHandle, params);
             },
           };
         },
-        exec(sqlStr): void {
+        async exec(sqlStr): Promise<void> {
           numStmt++;
           tart.sqlite3Exec(internalDbHandle, sqlStr);
         },
@@ -98,11 +97,15 @@ export async function createQtartSqlite3Impl(): Promise<Sqlite3Interface> {
 
 async function makeSqliteDb(
   args: DefaultNodeWalletArgs,
-): Promise<MakeDbResult> {
+): Promise<WalletDatabaseImplementation> {
   BridgeIDBFactory.enableTracing = false;
+  const filename = getSqlite3FilenameFromStoragePath(
+    args.persistentStoragePath,
+  );
+  logger.info(`opening sqlite3 database ${j2s(filename)}`);
   const imp = await createQtartSqlite3Impl();
   const myBackend = await createSqliteBackend(imp, {
-    filename: args.persistentStoragePath ?? ":memory:",
+    filename,
   });
   myBackend.trackStats = true;
   myBackend.enableTracing = false;
@@ -114,13 +117,51 @@ async function makeSqliteDb(
         primitiveStatements: numStmt,
       };
     },
+    async exportToFile(directory, stem, forceFormat) {
+      if (forceFormat === "json") {
+        const path = `${directory}/${stem}.json`;
+        const dbDump = await exportDb(myBridgeIdbFactory);
+        const errObj = { errno: undefined };
+        const file = qjsStd.open(path, "w+", errObj);
+        if (!file) {
+          throw Error(`could not create file (errno=${errObj.errno})`);
+        }
+        file.puts(JSON.stringify(dbDump));
+        file.close();
+        return {
+          path,
+        };
+      } else if (forceFormat === "sqlite3" || forceFormat == null) {
+        const path = `${directory}/${stem}.sqlite3`;
+        await myBackend.backupToFile(path);
+        return {
+          path,
+        };
+      } else {
+        throw Error(`forcing format ${forceFormat} not supported`);
+      }
+    },
+    async readBackupJson(path: string): Promise<any> {
+      const errObj = { errno: undefined };
+      const file = qjsStd.open(path, "r", errObj);
+      if (!path.endsWith(".json")) {
+        throw Error("DB file import only supports .json files at the moment");
+      }
+      if (!file) {
+        throw Error(`could not open file (errno=${errObj.errno})`);
+      }
+      const dumpStr = file.readAsString();
+      file.close();
+      const dump = JSON.parse(dumpStr);
+      return dump;
+    },
     idbFactory: myBridgeIdbFactory,
   };
 }
 
 async function makeFileDb(
   args: DefaultNodeWalletArgs = {},
-): Promise<MakeDbResult> {
+): Promise<WalletDatabaseImplementation> {
   BridgeIDBFactory.enableTracing = false;
   const myBackend = new MemoryBackend();
   myBackend.enableTracing = false;
@@ -156,6 +197,12 @@ async function makeFileDb(
   return {
     idbFactory: myBridgeIdbFactory,
     getStats: () => myBackend.accessStats,
+    exportToFile(directory, stem) {
+      throw Error("not supported");
+    },
+    async readBackupJson(path: string): Promise<any> {
+      throw Error("not supported");
+    },
   };
 }
 
@@ -163,11 +210,10 @@ export async function createNativeWalletHost2(
   args: DefaultNodeWalletArgs = {},
 ): Promise<{
   wallet: Wallet;
-  getDbStats: () => AccessStats;
 }> {
   BridgeIDBFactory.enableTracing = false;
 
-  let dbResp: MakeDbResult;
+  let dbResp: WalletDatabaseImplementation;
 
   if (
     args.persistentStoragePath &&
@@ -176,12 +222,10 @@ export async function createNativeWalletHost2(
     logger.info("using JSON file DB backend (slow, only use for testing)");
     dbResp = await makeFileDb(args);
   } else {
-    logger.info("using sqlite3 DB backend");
+    //    logger.info("using sqlite3 DB backend");
     dbResp = await makeSqliteDb(args);
   }
 
-  const myIdbFactory: IDBFactory = dbResp.idbFactory as any as IDBFactory;
-
   shimIndexedDB(dbResp.idbFactory);
 
   const myHttpFactory = (config: WalletRunConfig) => {
@@ -202,18 +246,12 @@ export async function createNativeWalletHost2(
 
   const timer = new SetTimeoutTimerAPI();
 
-  const w = await Wallet.create(
-    myIdbFactory,
-    myHttpFactory,
-    timer,
-    workerFactory,
-  );
+  const w = await Wallet.create(dbResp, myHttpFactory, timer, workerFactory);
 
   if (args.notifyHandler) {
     w.addNotificationListener(args.notifyHandler);
   }
   return {
     wallet: w,
-    getDbStats: dbResp.getStats,
   };
 }
