@@ -15,4 +15,4 @@
  */
 
 export * from "./index.js";
-export { SynchronousCryptoWorker } from "./crypto/workers/synchronousWorkerWeb.js";
+export { SynchronousCryptoWorkerPlain } from "./crypto/workers/synchronousWorkerPlain.js";
