@@ -55,6 +55,7 @@ import {
 } from "@gnu-taler/taler-util";
 import {
   PendingTaskType,
+  RecordHandle,
   TaskIdStr,
   TaskIdentifiers,
   TaskRunResult,
@@ -62,6 +63,7 @@ import {
   TransitionResultType,
   constructTaskIdentifier,
   genericWaitForStateVal,
+  getGenericRecordHandle,
   requireExchangeTosAcceptedOrThrow,
   runWithClientCancellation,
 } from "./common.js";
@@ -94,7 +96,6 @@ import {
 import {
   getMergeReserveInfo,
   isPurseDeposited,
-  recordCreate,
   recordDelete,
   recordTransition,
   recordTransitionStatus,
@@ -304,6 +305,25 @@ export class PeerPullCreditTransactionContext implements TransactionContext {
     };
   }
 
+  async getRecordHandle(
+    tx: WalletDbReadWriteTransaction<["peerPullCredit", "transactionsMeta"]>,
+  ): Promise<
+    [PeerPullCreditRecord | undefined, RecordHandle<PeerPullCreditRecord>]
+  > {
+    return getGenericRecordHandle<PeerPullCreditRecord>(
+      this,
+      tx as any,
+      async () => tx.peerPullCredit.get(this.pursePub),
+      async (r) => {
+        await tx.peerPullCredit.put(r);
+      },
+      async () => tx.peerPullCredit.delete(this.pursePub),
+      (r) => computePeerPullCreditTransactionState(r),
+      (r) => r.status,
+      () => this.updateTransactionMeta(tx),
+    );
+  }
+
   async deleteTransaction(): Promise<void> {
     const res = await this.wex.db.runReadWriteTx(
       {
@@ -1100,36 +1120,35 @@ export async function initiatePeerPullPayment(
   const mergeTimestamp = TalerPreciseTimestamp.now();
 
   const ctx = new PeerPullCreditTransactionContext(wex, pursePair.pub);
-  await recordCreate(
-    ctx,
-    {
-      extraStores: ["contractTerms"],
-      label: "create-transaction-peer-pull-credit",
-    },
-    async (tx) => {
-      await tx.contractTerms.put({
-        contractTermsRaw: contractTerms,
-        h: hContractTerms,
-      });
-      return {
-        amount: req.partialContractTerms.amount,
-        contractTermsHash: hContractTerms,
-        exchangeBaseUrl: exchangeBaseUrl,
-        pursePriv: pursePair.priv,
-        pursePub: pursePair.pub,
-        mergePriv: mergePair.priv,
-        mergePub: mergePair.pub,
-        status: PeerPullPaymentCreditStatus.PendingCreatePurse,
-        mergeTimestamp: timestampPreciseToDb(mergeTimestamp),
-        contractEncNonce,
-        mergeReserveRowId: mergeReserveRowId,
-        contractPriv: contractKeyPair.priv,
-        contractPub: contractKeyPair.pub,
-        withdrawalGroupId,
-        estimatedAmountEffective: wi.withdrawalAmountEffective,
-      };
-    },
-  );
+
+  await wex.db.runAllStoresReadWriteTx({}, async (tx) => {
+    await tx.contractTerms.put({
+      contractTermsRaw: contractTerms,
+      h: hContractTerms,
+    });
+    const [oldRec, h] = await ctx.getRecordHandle(tx);
+    if (oldRec) {
+      throw Error("peer-pull-credit record already exists");
+    }
+    await h.update({
+      amount: req.partialContractTerms.amount,
+      contractTermsHash: hContractTerms,
+      exchangeBaseUrl: exchangeBaseUrl,
+      pursePriv: pursePair.priv,
+      pursePub: pursePair.pub,
+      mergePriv: mergePair.priv,
+      mergePub: mergePair.pub,
+      status: PeerPullPaymentCreditStatus.PendingCreatePurse,
+      mergeTimestamp: timestampPreciseToDb(mergeTimestamp),
+      contractEncNonce,
+      mergeReserveRowId: mergeReserveRowId,
+      contractPriv: contractKeyPair.priv,
+      contractPub: contractKeyPair.pub,
+      withdrawalGroupId,
+      estimatedAmountEffective: wi.withdrawalAmountEffective,
+    });
+  });
+
   wex.taskScheduler.startShepherdTask(ctx.taskId);
 
   return {
