@@ -64,11 +64,13 @@ import {
 import { PreviousPayCoins, selectPeerCoins } from "./coinSelection.js";
 import {
   PendingTaskType,
+  RecordHandle,
   TaskIdStr,
   TaskRunResult,
   TransactionContext,
   TransitionResultType,
   constructTaskIdentifier,
+  getGenericRecordHandle,
   spendCoins,
 } from "./common.js";
 import {
@@ -85,7 +87,6 @@ import {
   getTotalPeerPaymentCost,
   isPurseDeposited,
   queryCoinInfosForSelection,
-  recordCreate,
   recordDelete,
   recordTransition,
   recordTransitionStatus,
@@ -135,6 +136,7 @@ export class PeerPullDebitTransactionContext implements TransactionContext {
     currency: Amounts.currencyOf(rec.amount),
     exchanges: [rec.exchangeBaseUrl],
   });
+
   updateTransactionMeta = (
     tx: WalletDbReadWriteTransaction<["peerPullDebit", "transactionsMeta"]>,
   ) => recordUpdateMeta(this, tx);
@@ -183,6 +185,28 @@ export class PeerPullDebitTransactionContext implements TransactionContext {
     };
   }
 
+  async getRecordHandle(
+    tx: WalletDbReadWriteTransaction<["peerPullDebit", "transactionsMeta"]>,
+  ): Promise<
+    [
+      PeerPullPaymentIncomingRecord | undefined,
+      RecordHandle<PeerPullPaymentIncomingRecord>,
+    ]
+  > {
+    return getGenericRecordHandle<PeerPullPaymentIncomingRecord>(
+      this,
+      tx as any,
+      async () => tx.peerPullDebit.get(this.peerPullDebitId),
+      async (r) => {
+        await tx.peerPullDebit.put(r);
+      },
+      async () => tx.peerPullDebit.delete(this.peerPullDebitId),
+      (r) => computePeerPullDebitTransactionState(r),
+      (r) => r.status,
+      () => this.updateTransactionMeta(tx),
+    );
+  }
+
   async deleteTransaction(): Promise<void> {
     const res = await this.wex.db.runReadWriteTx(
       { storeNames: ["peerPullDebit", "transactionsMeta"] },
@@ -829,6 +853,7 @@ export async function preparePeerPullDebit(
         contractTerms,
         scopeInfo,
         exchangeBaseUrl: peerPullDebitRecord.exchangeBaseUrl,
+        rec: peerPullDebitRecord,
       };
     },
   );
@@ -841,6 +866,7 @@ export async function preparePeerPullDebit(
       contractTerms: existing.contractTerms.contractTermsRaw,
       scopeInfo: existing.scopeInfo,
       exchangeBaseUrl: existing.exchangeBaseUrl,
+      txState: computePeerPullDebitTransactionState(existing.rec),
       transactionId: constructTransactionIdentifier({
         tag: TransactionType.PeerPullDebit,
         peerPullDebitId: existing.peerPullDebitRecord.peerPullDebitId,
@@ -948,42 +974,43 @@ export async function preparePeerPullDebit(
   const totalAmount = await getTotalPeerPaymentCost(wex, coins);
 
   const ctx = new PeerPullDebitTransactionContext(wex, peerPullDebitId);
-  await recordCreate(
-    ctx,
-    {
-      extraStores: ["contractTerms"],
-      label: "create-transaction-peer-pull-credit",
-    },
-    async (tx) => {
-      await tx.contractTerms.put({
-        h: contractTermsHash,
-        contractTermsRaw: contractTerms,
-      });
-      return {
-        peerPullDebitId,
-        contractPriv: contractPriv,
-        exchangeBaseUrl: exchangeBaseUrl,
-        pursePub: pursePub,
-        timestampCreated: timestampPreciseToDb(TalerPreciseTimestamp.now()),
-        contractTermsHash,
-        amount: contractTerms.amount,
-        status: PeerPullDebitRecordStatus.DialogProposed,
-        totalCostEstimated: Amounts.stringify(totalAmount),
-      };
-    },
-  );
-  wex.taskScheduler.startShepherdTask(ctx.taskId);
 
-  const scopeInfo = await wex.db.runAllStoresReadOnlyTx({}, (tx) => {
-    return getExchangeScopeInfo(tx, exchangeBaseUrl, currency);
+  const ret = await wex.db.runAllStoresReadWriteTx({}, async (tx) => {
+    await tx.contractTerms.put({
+      h: contractTermsHash,
+      contractTermsRaw: contractTerms,
+    });
+    const [rec, h] = await ctx.getRecordHandle(tx);
+    if (rec) {
+      throw Error("peer-pull-debit record already exists");
+    }
+    const newRec: PeerPullPaymentIncomingRecord = {
+      peerPullDebitId,
+      contractPriv: contractPriv,
+      exchangeBaseUrl: exchangeBaseUrl,
+      pursePub: pursePub,
+      timestampCreated: timestampPreciseToDb(TalerPreciseTimestamp.now()),
+      contractTermsHash,
+      amount: contractTerms.amount,
+      status: PeerPullDebitRecordStatus.DialogProposed,
+      totalCostEstimated: Amounts.stringify(totalAmount),
+    };
+    await h.update(newRec);
+    return {
+      newRec,
+      scopeInfo: await getExchangeScopeInfo(tx, exchangeBaseUrl, currency),
+    };
   });
 
+  wex.taskScheduler.startShepherdTask(ctx.taskId);
+
   return {
     amount: contractTerms.amount,
     amountEffective: Amounts.stringify(totalAmount),
     amountRaw: contractTerms.amount,
     contractTerms: contractTerms,
-    scopeInfo,
+    scopeInfo: ret.scopeInfo,
+    txState: computePeerPullDebitTransactionState(ret.newRec),
     exchangeBaseUrl,
     transactionId: ctx.transactionId,
   };
