@@ -54,6 +54,7 @@ import {
 } from "@gnu-taler/taler-util";
 import {
   PendingTaskType,
+  RecordHandle,
   TaskIdStr,
   TaskIdentifiers,
   TaskRunResult,
@@ -61,6 +62,7 @@ import {
   TransitionResultType,
   constructTaskIdentifier,
   genericWaitForStateVal,
+  getGenericRecordHandle,
   requireExchangeTosAcceptedOrThrow,
 } from "./common.js";
 import {
@@ -93,7 +95,6 @@ import {
 import {
   getMergeReserveInfo,
   isPurseMerged,
-  recordCreate,
   recordDelete,
   recordTransition,
   recordTransitionStatus,
@@ -268,6 +269,28 @@ export class PeerPushCreditTransactionContext implements TransactionContext {
     };
   }
 
+  async getRecordHandle(
+    tx: WalletDbReadWriteTransaction<["peerPushCredit", "transactionsMeta"]>,
+  ): Promise<
+    [
+      PeerPushPaymentIncomingRecord | undefined,
+      RecordHandle<PeerPushPaymentIncomingRecord>,
+    ]
+  > {
+    return getGenericRecordHandle<PeerPushPaymentIncomingRecord>(
+      this,
+      tx as any,
+      async () => tx.peerPushCredit.get(this.peerPushCreditId),
+      async (r) => {
+        await tx.peerPushCredit.put(r);
+      },
+      async () => tx.peerPushCredit.delete(this.peerPushCreditId),
+      (r) => computePeerPushCreditTransactionState(r),
+      (r) => r.status,
+      () => this.updateTransactionMeta(tx),
+    );
+  }
+
   async deleteTransaction(): Promise<void> {
     const res = await this.wex.db.runReadWriteTx(
       {
@@ -494,6 +517,7 @@ export async function preparePeerPushCredit(
         tag: TransactionType.PeerPushCredit,
         peerPushCreditId: existing.existingPushInc.peerPushCreditId,
       }),
+      txState: computePeerPushCreditTransactionState(existing.existingPushInc),
       scopeInfo,
       exchangeBaseUrl,
       ...getPeerCreditLimitInfo(
@@ -568,48 +592,41 @@ export async function preparePeerPushCredit(
     );
   }
 
-  const ctx = new PeerPushCreditTransactionContext(wex, peerPushCreditId);
-  await recordCreate(
-    ctx,
-    {
-      extraStores: ["contractTerms"],
-    },
-    async (tx) => {
-      await tx.contractTerms.put({
-        h: contractTermsHash,
-        contractTermsRaw: dec.contractTerms,
-      });
-      return {
-        peerPushCreditId,
-        contractPriv: contractPriv,
-        exchangeBaseUrl: exchangeBaseUrl,
-        mergePriv: dec.mergePriv,
-        pursePub: pursePub,
-        timestamp: timestampPreciseToDb(TalerPreciseTimestamp.now()),
-        contractTermsHash,
-        status: PeerPushCreditStatus.DialogProposed,
-        withdrawalGroupId,
-        currency: Amounts.currencyOf(purseStatus.balance),
-        estimatedAmountEffective: Amounts.stringify(
-          wi.withdrawalAmountEffective,
-        ),
-      };
-    },
-  );
-  wex.taskScheduler.startShepherdTask(ctx.taskId);
-
   const currency = Amounts.currencyOf(wi.withdrawalAmountRaw);
-  const scopeInfo = await wex.db.runReadOnlyTx(
-    {
-      storeNames: [
-        "exchanges",
-        "exchangeDetails",
-        "globalCurrencyExchanges",
-        "globalCurrencyAuditors",
-      ],
-    },
-    (tx) => getExchangeScopeInfo(tx, exchangeBaseUrl, currency),
-  );
+
+  const ctx = new PeerPushCreditTransactionContext(wex, peerPushCreditId);
+
+  const res = await wex.db.runAllStoresReadWriteTx({}, async (tx) => {
+    await tx.contractTerms.put({
+      h: contractTermsHash,
+      contractTermsRaw: dec.contractTerms,
+    });
+
+    const [rec, h] = await ctx.getRecordHandle(tx);
+    if (rec) {
+      throw Error("record already exists");
+    }
+    const newRec: PeerPushPaymentIncomingRecord = {
+      peerPushCreditId,
+      contractPriv: contractPriv,
+      exchangeBaseUrl: exchangeBaseUrl,
+      mergePriv: dec.mergePriv,
+      pursePub: pursePub,
+      timestamp: timestampPreciseToDb(TalerPreciseTimestamp.now()),
+      contractTermsHash,
+      status: PeerPushCreditStatus.DialogProposed,
+      withdrawalGroupId,
+      currency: Amounts.currencyOf(purseStatus.balance),
+      estimatedAmountEffective: Amounts.stringify(wi.withdrawalAmountEffective),
+    };
+    await h.update(newRec);
+    return {
+      scopeInfo: await getExchangeScopeInfo(tx, exchangeBaseUrl, currency),
+      newRec,
+    };
+  });
+
+  wex.taskScheduler.startShepherdTask(ctx.taskId);
 
   return {
     amount: purseStatus.balance,
@@ -618,7 +635,8 @@ export async function preparePeerPushCredit(
     contractTerms: dec.contractTerms,
     transactionId: ctx.transactionId,
     exchangeBaseUrl,
-    scopeInfo,
+    scopeInfo: res.scopeInfo,
+    txState: computePeerPushCreditTransactionState(res.newRec),
     ...getPeerCreditLimitInfo(exchange, purseStatus.balance),
   };
 }
