@@ -59,11 +59,13 @@ import {
 } from "./coinSelection.js";
 import {
   PendingTaskType,
+  RecordHandle,
   TaskIdStr,
   TaskRunResult,
   TransactionContext,
   TransitionResultType,
   constructTaskIdentifier,
+  getGenericRecordHandle,
   runWithClientCancellation,
   spendCoins,
 } from "./common.js";
@@ -79,6 +81,7 @@ import {
   timestampProtocolToDb,
 } from "./db.js";
 import {
+  fetchFreshExchange,
   getPreferredExchangeForCurrency,
   getScopeForAllExchanges,
 } from "./exchanges.js";
@@ -87,7 +90,6 @@ import {
   getTotalPeerPaymentCostInTx,
   isPurseMerged,
   queryCoinInfosForSelection,
-  recordCreate,
   recordDelete,
   recordTransition,
   recordTransitionStatus,
@@ -199,6 +201,25 @@ export class PeerPushDebitTransactionContext implements TransactionContext {
     };
   }
 
+  async getRecordHandle(
+    tx: WalletDbReadWriteTransaction<["peerPushDebit", "transactionsMeta"]>,
+  ): Promise<
+    [PeerPushDebitRecord | undefined, RecordHandle<PeerPushDebitRecord>]
+  > {
+    return getGenericRecordHandle<PeerPushDebitRecord>(
+      this,
+      tx as any,
+      async () => tx.peerPushDebit.get(this.pursePub),
+      async (r) => {
+        await tx.peerPushDebit.put(r);
+      },
+      async () => tx.peerPushDebit.delete(this.pursePub),
+      (r) => computePeerPushDebitTransactionState(r),
+      (r) => r.status,
+      () => this.updateTransactionMeta(tx),
+    );
+  }
+
   async deleteTransaction(): Promise<void> {
     const res = await this.wex.db.runReadWriteTx(
       { storeNames: ["peerPushDebit", "transactionsMeta"] },
@@ -421,6 +442,9 @@ async function internalCheckPeerPushDebit(
       assertUnreachable(coinSelRes);
   }
   logger.trace(`selected peer coins (len=${coins.length})`);
+  // We might need to do a refresh later, so it's important
+  // that we have up-to-date info about the exchange.
+  await fetchFreshExchange(wex, coinSelRes.result.exchangeBaseUrl);
   const totalAmount = await getTotalPeerPaymentCost(wex, coins);
   logger.trace("computed total peer payment cost");
   return {
@@ -975,111 +999,98 @@ export async function initiatePeerPushDebit(
   await updateWithdrawalDenomsForCurrency(wex, instructedAmount.currency);
 
   let exchangeBaseUrl;
-  await recordCreate(
-    ctx,
-    {
-      extraStores: [
-        "coinAvailability",
-        "coinHistory",
-        "coins",
-        "contractTerms",
-        "denominations",
-        "exchangeDetails",
-        "exchanges",
-        "refreshGroups",
-        "refreshSessions",
-        "globalCurrencyExchanges",
-        "globalCurrencyAuditors",
-      ],
-    },
-    async (tx) => {
-      const coinSelRes = await selectPeerCoinsInTx(wex, tx, {
-        instructedAmount,
-        // Any (single!) exchange that is in scope works.
-        restrictScope: req.restrictScope,
-        feesCoveredByCounterparty: false,
-      });
 
-      let coins: SelectedProspectiveCoin[] | undefined = undefined;
+  await wex.db.runAllStoresReadWriteTx({}, async (tx) => {
+    const coinSelRes = await selectPeerCoinsInTx(wex, tx, {
+      instructedAmount,
+      // Any (single!) exchange that is in scope works.
+      restrictScope: req.restrictScope,
+      feesCoveredByCounterparty: false,
+    });
 
-      switch (coinSelRes.type) {
-        case "failure":
-          throw TalerError.fromDetail(
-            TalerErrorCode.WALLET_PEER_PUSH_PAYMENT_INSUFFICIENT_BALANCE,
-            {
-              insufficientBalanceDetails: coinSelRes.insufficientBalanceDetails,
-            },
-          );
-        case "prospective":
-          coins = coinSelRes.result.prospectiveCoins;
-          break;
-        case "success":
-          coins = coinSelRes.result.coins;
-          break;
-        default:
-          assertUnreachable(coinSelRes);
-      }
+    let coins: SelectedProspectiveCoin[] | undefined = undefined;
 
-      logger.trace(j2s(coinSelRes));
+    switch (coinSelRes.type) {
+      case "failure":
+        throw TalerError.fromDetail(
+          TalerErrorCode.WALLET_PEER_PUSH_PAYMENT_INSUFFICIENT_BALANCE,
+          {
+            insufficientBalanceDetails: coinSelRes.insufficientBalanceDetails,
+          },
+        );
+      case "prospective":
+        coins = coinSelRes.result.prospectiveCoins;
+        break;
+      case "success":
+        coins = coinSelRes.result.coins;
+        break;
+      default:
+        assertUnreachable(coinSelRes);
+    }
 
-      const sel = coinSelRes.result;
+    logger.trace(j2s(coinSelRes));
 
-      logger.trace(
-        `peer debit instructed amount: ${Amounts.stringify(instructedAmount)}`,
-      );
-      logger.trace(
-        `peer debit contract terms amount: ${Amounts.stringify(
-          contractTerms.amount,
-        )}`,
-      );
-      logger.trace(
-        `peer debit deposit fees: ${Amounts.stringify(sel.totalDepositFees)}`,
-      );
+    const sel = coinSelRes.result;
 
-      const totalAmount = await getTotalPeerPaymentCostInTx(wex, tx, coins);
-      const ppi: PeerPushDebitRecord = {
-        amount: Amounts.stringify(instructedAmount),
-        restrictScope: req.restrictScope,
-        contractPriv: contractKeyPair.priv,
-        contractPub: contractKeyPair.pub,
-        contractTermsHash: hContractTerms,
-        exchangeBaseUrl: sel.exchangeBaseUrl,
-        mergePriv: mergePair.priv,
-        mergePub: mergePair.pub,
-        purseExpiration: timestampProtocolToDb(purseExpiration),
-        pursePriv: pursePair.priv,
-        pursePub: pursePair.pub,
-        timestampCreated: timestampPreciseToDb(TalerPreciseTimestamp.now()),
-        status: PeerPushDebitStatus.PendingCreatePurse,
-        contractEncNonce,
-        totalCost: Amounts.stringify(totalAmount),
+    logger.trace(
+      `peer debit instructed amount: ${Amounts.stringify(instructedAmount)}`,
+    );
+    logger.trace(
+      `peer debit contract terms amount: ${Amounts.stringify(
+        contractTerms.amount,
+      )}`,
+    );
+    logger.trace(
+      `peer debit deposit fees: ${Amounts.stringify(sel.totalDepositFees)}`,
+    );
+
+    const totalAmount = await getTotalPeerPaymentCostInTx(wex, tx, coins);
+    const ppi: PeerPushDebitRecord = {
+      amount: Amounts.stringify(instructedAmount),
+      restrictScope: req.restrictScope,
+      contractPriv: contractKeyPair.priv,
+      contractPub: contractKeyPair.pub,
+      contractTermsHash: hContractTerms,
+      exchangeBaseUrl: sel.exchangeBaseUrl,
+      mergePriv: mergePair.priv,
+      mergePub: mergePair.pub,
+      purseExpiration: timestampProtocolToDb(purseExpiration),
+      pursePriv: pursePair.priv,
+      pursePub: pursePair.pub,
+      timestampCreated: timestampPreciseToDb(TalerPreciseTimestamp.now()),
+      status: PeerPushDebitStatus.PendingCreatePurse,
+      contractEncNonce,
+      totalCost: Amounts.stringify(totalAmount),
+    };
+
+    if (coinSelRes.type === "success") {
+      ppi.coinSel = {
+        coinPubs: coinSelRes.result.coins.map((x) => x.coinPub),
+        contributions: coinSelRes.result.coins.map((x) => x.contribution),
       };
-
-      if (coinSelRes.type === "success") {
-        ppi.coinSel = {
-          coinPubs: coinSelRes.result.coins.map((x) => x.coinPub),
-          contributions: coinSelRes.result.coins.map((x) => x.contribution),
-        };
-        // FIXME: Instead of directly doing a spendCoin here,
-        // we might want to mark the coins as used and spend them
-        // after we've been able to create the purse.
-        await spendCoins(wex, tx, {
-          transactionId: ctx.transactionId,
-          coinPubs: coinSelRes.result.coins.map((x) => x.coinPub),
-          contributions: coinSelRes.result.coins.map((x) =>
-            Amounts.parseOrThrow(x.contribution),
-          ),
-          refreshReason: RefreshReason.PayPeerPush,
-        });
-      }
-      await tx.contractTerms.put({
-        h: hContractTerms,
-        contractTermsRaw: contractTerms,
+      // FIXME: Instead of directly doing a spendCoin here,
+      // we might want to mark the coins as used and spend them
+      // after we've been able to create the purse.
+      await spendCoins(wex, tx, {
+        transactionId: ctx.transactionId,
+        coinPubs: coinSelRes.result.coins.map((x) => x.coinPub),
+        contributions: coinSelRes.result.coins.map((x) =>
+          Amounts.parseOrThrow(x.contribution),
+        ),
+        refreshReason: RefreshReason.PayPeerPush,
       });
-      exchangeBaseUrl = coinSelRes.result.exchangeBaseUrl;
-      return ppi;
-    },
-  );
+    }
+    await tx.contractTerms.put({
+      h: hContractTerms,
+      contractTermsRaw: contractTerms,
+    });
+    exchangeBaseUrl = coinSelRes.result.exchangeBaseUrl;
+    const [oldRec, h] = await ctx.getRecordHandle(tx);
+    if (oldRec) {
+      throw Error("record for peer-push-debit already exists");
+    }
+    await h.update(ppi);
+  });
 
   wex.taskScheduler.startShepherdTask(ctx.taskId);
 
