@@ -548,6 +548,11 @@ type ValidateKeyPath<T, P> = P extends `${infer PX extends keyof T &
 
 // foo({x: [0,1,2]}, "x.0");
 
+export interface TransactionUtil {
+  notify: (w: WalletNotification) => void;
+  scheduleOnCommit(f: () => void): void;
+}
+
 export type StoreMap = { [Store: string]: StoreWithIndexes<any, any, any> };
 export type StoreNames<Stores extends StoreMap> = keyof Stores;
 export type DbReadWriteTransaction<
@@ -559,6 +564,7 @@ export type DbReadWriteTransaction<
     Stores[X]["indexMap"]
   >;
 } & {
+  _util: TransactionUtil;
   notify: (w: WalletNotification) => void;
 };
 
@@ -571,6 +577,7 @@ export type DbReadOnlyTransaction<
     Stores[X]["indexMap"]
   >;
 } & {
+  _util: TransactionUtil;
   notify: (w: WalletNotification) => void;
 };
 
@@ -728,11 +735,20 @@ function makeTxClientContext(
   const ctx: {
     [s: string]:
       | StoreReadWriteAccessor<any, any>
-      | ((notif: WalletNotification) => void);
+      | ((notif: WalletNotification) => void)
+      | TransactionUtil;
   } = {
     notify(notif: WalletNotification): void {
       internalContext.scheduleNotification(notif);
     },
+    _util: {
+      notify(notif: WalletNotification): void {
+        internalContext.scheduleNotification(notif);
+      },
+      scheduleOnCommit(f: () => void): void {
+        internalContext.scheduleAfterCommit(f);
+      },
+    },
   };
   for (const storeAlias in storePick) {
     const indexes: { [s: string]: IndexReadWriteAccessor<any> } = {};
@@ -954,6 +970,7 @@ class InternalTransactionContext {
   allowWrite: boolean;
   abortExn: TransactionAbortedError | undefined;
   notifications: WalletNotification[] = [];
+  afterCommitHandlers: (() => void)[] = [];
 
   constructor(
     private readonly triggerSpec: TriggerSpec,
@@ -970,6 +987,10 @@ class InternalTransactionContext {
     this.notifications.push(notif);
   }
 
+  scheduleAfterCommit(f: () => void) {
+    this.afterCommitHandlers.push(f);
+  }
+
   handleAfterCommit() {
     if (this.triggerSpec.afterCommit) {
       this.triggerSpec.afterCommit({
@@ -979,6 +1000,9 @@ class InternalTransactionContext {
         scope: this.storesScope,
       });
     }
+    for (const f of this.afterCommitHandlers) {
+      f();
+    }
   }
 
   throwIfInactive() {
