@@ -210,9 +210,9 @@ export class TaskSchedulerImpl implements TaskScheduler {
     }
     this.isRunning = true;
     try {
-      logger.info(`loading shepherd tasks from database`);
+      logger.trace(`loading shepherd tasks from database`);
       await this.loadTasksFromDb();
-      logger.info(`done loading shepherd tasks from database`);
+      logger.trace(`done loading shepherd tasks from database`);
     } catch (e) {
       this.isRunning = false;
       throw e;
@@ -425,7 +425,9 @@ export class TaskSchedulerImpl implements TaskScheduler {
           );
           const t = timestampAbsoluteFromDb(retryRecord.retryInfo.nextRetry);
           const delay = AbsoluteTime.remaining(t);
-          logger.trace(`Stored error for ${taskId}, waiting for ${delay.d_ms} ms`);
+          logger.trace(
+            `Stored error for ${taskId}, waiting for ${delay.d_ms} ms`,
+          );
           await this.wait(taskId, info, delay);
           break;
         }
