@@ -51,6 +51,8 @@ import {
 } from "./common.js";
 import {
   DbPreciseTimestamp,
+  OPERATION_STATUS_DIALOG_FIRST,
+  OPERATION_STATUS_DIALOG_LAST,
   OPERATION_STATUS_DONE_FIRST,
   OPERATION_STATUS_DONE_LAST,
   OPERATION_STATUS_NONFINAL_FIRST,
@@ -222,10 +224,25 @@ function checkFilterIncludes(
         mtx.status <= OPERATION_STATUS_NONFINAL_LAST
       );
       break;
+    case "nonfinal-approved":
+    case "nonfinal-dialog":
     case "nonfinal":
       included =
         mtx.status >= OPERATION_STATUS_NONFINAL_FIRST &&
         mtx.status <= OPERATION_STATUS_NONFINAL_LAST;
+      if (filter === "nonfinal-approved") {
+        included =
+          included &&
+          !(
+            mtx.status >= OPERATION_STATUS_DIALOG_FIRST &&
+            mtx.status <= OPERATION_STATUS_DIALOG_LAST
+          );
+      } else if (filter === "nonfinal-dialog") {
+        included =
+          included &&
+          mtx.status >= OPERATION_STATUS_DIALOG_FIRST &&
+          mtx.status <= OPERATION_STATUS_DIALOG_LAST;
+      }
       break;
     case undefined:
       included = true;
