@@ -56,6 +56,10 @@ import {
   CompleteBaseUrlResult,
   ConfirmPayRequest,
   ConfirmPayResult,
+  ConvertIbanAccountFieldToPaytoRequest,
+  ConvertIbanAccountFieldToPaytoResponse,
+  ConvertIbanPaytoToAccountFieldRequest,
+  ConvertIbanPaytoToAccountFieldResponse,
   CoreApiResponse,
   CreateStoredBackupResponse,
   DeleteDiscountRequest,
@@ -109,6 +113,7 @@ import {
   ObservableHttpClientLibrary,
   OpenedPromise,
   PartialWalletRunConfig,
+  Paytos,
   PrepareWithdrawExchangeRequest,
   PrepareWithdrawExchangeResponse,
   RecoverStoredBackupRequest,
@@ -171,6 +176,8 @@ import {
   codecForConfirmPeerPushPaymentRequest,
   codecForConfirmWithdrawalRequestRequest,
   codecForConvertAmountRequest,
+  codecForConvertIbanAccountFieldToPaytoRequest,
+  codecForConvertIbanPaytoToAccountFieldRequest,
   codecForCreateDepositGroupRequest,
   codecForDeleteContactRequest,
   codecForDeleteDiscountRequest,
@@ -249,12 +256,15 @@ import {
   codecForUserAttentionsRequest,
   codecForValidateIbanRequest,
   codecForWithdrawTestBalance,
+  convertCHF_BBANtoIBAN,
+  convertHUF_BBANtoIBAN,
   encodeCrock,
   getErrorDetailFromException,
   getQrCodesForPayto,
   getRandomBytes,
   j2s,
   openPromise,
+  parseIban,
   parsePaytoUri,
   parseTalerUri,
   performanceNow,
@@ -262,6 +272,7 @@ import {
   setDangerousTimetravel,
   setGlobalLogLevelFromString,
   stringifyScopeInfo,
+  succeedOrThrow,
   validateIban,
 } from "@gnu-taler/taler-util";
 import {
@@ -333,9 +344,9 @@ import {
   fetchFreshExchange,
   forgetExchangeTermsOfService,
   getExchangeDetailedInfo,
+  getExchangeDetailsInTx,
   getExchangeResources,
   getExchangeTos,
-  getExchangeWireDetailsInTx,
   handleStartExchangeWalletKyc,
   handleTestingPlanMigrateExchangeBaseUrl,
   handleTestingWaitExchangeState,
@@ -542,7 +553,7 @@ async function fillDefaults(wex: WalletExecutionContext): Promise<void> {
 /**
  * Incremented each time we want to re-materialize transactions.
  */
-const MATERIALIZED_TRANSACTIONS_VERSION = 1;
+const MATERIALIZED_TRANSACTIONS_VERSION = 2;
 
 async function migrateMaterializedTransactions(
   wex: WalletExecutionContext,
@@ -1455,7 +1466,7 @@ async function handleGetDepositWireTypes(
     async (tx) => {
       const exchanges = await tx.exchanges.getAll();
       for (const exchange of exchanges) {
-        const det = await getExchangeWireDetailsInTx(tx, exchange.baseUrl);
+        const det = await getExchangeDetailsInTx(tx, exchange.baseUrl);
         if (!det) {
           continue;
         }
@@ -1500,6 +1511,7 @@ async function handleGetDepositWireTypes(
               // Will possibly extended later by other exchanges
               // with the same wire type.
               talerBankHostnames,
+              preferredEntryType,
             });
           }
         }
@@ -1523,7 +1535,7 @@ async function handleGetDepositWireTypesForCurrency(
     async (tx) => {
       const exchanges = await tx.exchanges.getAll();
       for (const exchange of exchanges) {
-        const det = await getExchangeWireDetailsInTx(tx, exchange.baseUrl);
+        const det = await getExchangeDetailsInTx(tx, exchange.baseUrl);
         if (!det) {
           continue;
         }
@@ -1930,6 +1942,81 @@ async function handleGetVersion(
   return result;
 }
 
+export async function handleConvertIbanAccountFieldToPayto(
+  wex: WalletExecutionContext,
+  req: ConvertIbanAccountFieldToPaytoRequest,
+): Promise<ConvertIbanAccountFieldToPaytoResponse> {
+  const strippedInput = req.value.replace(/[- ]/g, "");
+  if (req.currency === "HUF") {
+    const iban = convertHUF_BBANtoIBAN(strippedInput);
+    if (iban.type === "ok") {
+      return {
+        ok: true,
+        paytoUri: `payto://iban/${iban.body}`,
+        type: "iban",
+      };
+    } else {
+      return {
+        ok: false,
+      };
+    }
+  }
+  if (wex.ws.devExperimentState.fakeChfBban && req.currency === "CHF") {
+    const iban = convertCHF_BBANtoIBAN(strippedInput);
+    if (iban.type === "ok") {
+      return {
+        ok: true,
+        paytoUri: `payto://iban/${iban.body}`,
+        type: "iban",
+      };
+    } else {
+      return {
+        ok: false,
+      };
+    }
+  }
+  const parsedIban = parseIban(strippedInput);
+  switch (parsedIban.case) {
+    case "ok":
+      return {
+        ok: true,
+        paytoUri: `payto://iban/${strippedInput}`,
+        type: "iban",
+      };
+    default:
+      return {
+        ok: false,
+      };
+  }
+}
+
+export async function handleConvertIbanPaytoToAccountField(
+  wex: WalletExecutionContext,
+  req: ConvertIbanPaytoToAccountFieldRequest,
+): Promise<ConvertIbanPaytoToAccountFieldResponse> {
+  const payto = succeedOrThrow(Paytos.fromString(req.paytoUri));
+  const iban = payto.normalizedPath;
+  if (iban.startsWith("HU")) {
+    let bban = iban.slice(4);
+    if (bban.endsWith("00000000")) {
+      bban = bban.slice(0, bban.length - 8);
+    }
+    return {
+      type: "bban",
+      value: bban,
+    };
+  } else if (wex.ws.devExperimentState.fakeChfBban && iban.startsWith("CH")) {
+    return {
+      type: "bban",
+      value: iban.slice(4),
+    };
+  }
+  return {
+    type: "iban",
+    value: iban,
+  };
+}
+
 interface HandlerWithValidator<Tag extends WalletApiOperation> {
   codec: Codec<WalletCoreRequestType<Tag>>;
   handler: (
@@ -1939,6 +2026,14 @@ interface HandlerWithValidator<Tag extends WalletApiOperation> {
 }
 
 const handlers: { [T in WalletApiOperation]: HandlerWithValidator<T> } = {
+  [WalletApiOperation.ConvertIbanAccountFieldToPayto]: {
+    codec: codecForConvertIbanAccountFieldToPaytoRequest(),
+    handler: handleConvertIbanAccountFieldToPayto,
+  },
+  [WalletApiOperation.ConvertIbanPaytoToAccountField]: {
+    codec: codecForConvertIbanPaytoToAccountFieldRequest(),
+    handler: handleConvertIbanPaytoToAccountField,
+  },
   [WalletApiOperation.TestingWaitExchangeState]: {
     codec: codecForAny(),
     handler: handleTestingWaitExchangeState,
@@ -2864,6 +2959,23 @@ export interface DevExperimentState {
     }
   >;
 
+  /** Map from base URL to faked version for /config or /keys */
+  fakeMasterPub?: Map<
+    string,
+    {
+      fakeMasterPub: string;
+    }
+  >;
+
+  fakeShoppingUrl?: string;
+
+  flagDisablePeerPayments?: boolean;
+
+  /** Set of exchanges to fake disabled direct deposits for. */
+  flagDisableDirectDeposits?: Set<string>;
+
+  fakeChfBban?: boolean;
+
   blockPayResponse?: boolean;
 
   /** Migration test for confirmPay */
