@@ -15,7 +15,7 @@
  */
 
 import { h, VNode } from "preact";
-import logo from "../svg/logo-2021.svg";
+import logo from "../svg/logo-2021.inline.svg";
 
 export function LogoHeader(): VNode {
   return (
