@@ -20,10 +20,40 @@
  */
 
 import * as tests from "@gnu-taler/web-util/testing";
-// import { ReadyView } from "./views.js";
+import { ShowTosContentView } from "./views.js";
+import { ExchangeTosStatus } from "@gnu-taler/taler-util";
 
 export default {
   title: "TermsOfService",
 };
 
-// export const Ready = tests.createExample(ReadyView, {});
+export const Ready = tests.createExample(ShowTosContentView, {
+  tosLang: {
+    list: {
+      es: "es",
+      en: "en",
+    },
+    value: "es",
+    onChange: (() => { }) as any
+  },
+  tosFormat: {
+    list: {
+      es: "es",
+      en: "en",
+    },
+    value: "es",
+    onChange: (() => { }) as any
+  },
+  terms: {
+    content: {
+      type: "plain",
+      content: "hola"
+    },
+    status: ExchangeTosStatus.Accepted,
+    version: "1"
+  },
+  status: "show-content",
+  termsAccepted: {
+    button: {},
+  }
+});
