@@ -19,7 +19,7 @@
  * @author Sebastian Javier Marchano (sebasjm)
  */
 
-import { Amounts } from "@gnu-taler/taler-util";
+import { Amounts, parsePaytoUri } from "@gnu-taler/taler-util";
 import * as tests from "@gnu-taler/web-util/testing";
 import { ReadyView } from "./views.js";
 
@@ -30,6 +30,10 @@ export default {
 export const Ready = tests.createExample(ReadyView, {
   status: "ready",
   confirm: {},
+  amount: {
+    value: Amounts.parseOrThrow("EUR:1")
+  },
+  account: parsePaytoUri("payto://iban/DE1231231231")!,
   cost: Amounts.parseOrThrow("EUR:1.2"),
   effective: Amounts.parseOrThrow("EUR:1"),
   fee: Amounts.parseOrThrow("EUR:0.2"),
