@@ -19,23 +19,29 @@
  * @author Sebastian Javier Marchano (sebasjm)
  */
 
-import { createExample } from "../../test-utils.js";
+import * as tests from "@gnu-taler/web-util/testing";
 import { ReadyView } from "./views.js";
+import { AbsoluteTime } from "@gnu-taler/taler-util";
 
 export default {
-  title: "wallet/transfer pickup",
+  title: "transfer pickup",
 };
 
-export const Ready = createExample(ReadyView, {
-  amount: {
+export const Ready = tests.createExample(ReadyView, {
+  effective: {
+    currency: "ARS",
+    value: 1,
+    fraction: 0,
+  },
+  raw: {
     currency: "ARS",
     value: 1,
     fraction: 0,
   },
   summary: "some subject",
-  expiration: {
-    t_ms: new Date().getTime() + 1000 * 60 * 60,
-  },
+  expiration: AbsoluteTime.fromMilliseconds(
+    new Date().getTime() + 1000 * 60 * 60,
+  ),
   accept: {},
   cancel: {},
 });
