@@ -21,17 +21,18 @@
  */
 
 export const termsHtml = `<html xmlns="http://www.w3.org/1999/xhtml" lang="en">
-<head>
-  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-  <title>Terms Of Service &#8212; Taler Terms of Service</title>
-</head><body>
-  <div>
-    Terms of service
-  </div>
-  <div>
-    A complete separated html with it's own design
-  </div>
-</body>
+  <head>
+    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
+    <title>Terms Of Service &#8212; Taler Terms of Service</title>
+  </head>
+  <body>
+    <div>
+      Terms of service
+    </div>
+    <div>
+      A complete separated html with it's own design
+    </div>
+  </body>
 </html>
 `;
 export const termsPlain = `
