@@ -30,7 +30,7 @@ export interface Props {
   autoFocus?: boolean;
   color?: Colors;
   disabled?: boolean;
-  error?: string;
+  error?: string | Error;
   fullWidth?: boolean;
   helperText?: VNode | string;
   id?: string;
