@@ -27,7 +27,7 @@ export interface Props {
   disabled?: boolean;
   disableUnderline?: boolean;
   endAdornment?: VNode;
-  error?: string;
+  error?: string | Error;
   fullWidth?: boolean;
   id?: string;
   margin?: "dense" | "normal" | "none";
@@ -82,9 +82,9 @@ const underlineStyle = css`
     right: 0px;
     transform: scaleX(0);
     transition: ${theme.transitions.create("transform", {
-      duration: theme.transitions.duration.shorter,
-      easing: theme.transitions.easing.easeOut,
-    })};
+  duration: theme.transitions.duration.shorter,
+  easing: theme.transitions.easing.easeOut,
+})};
     pointer-events: none;
   }
   &[data-focused]:after {
@@ -97,8 +97,8 @@ const underlineStyle = css`
   &:before {
     border-bottom: 1px solid
       ${theme.palette.mode === "light"
-        ? "rgba(0, 0, 0, 0.42)"
-        : "rgba(255, 255, 255, 0.7)"};
+    ? "rgba(0, 0, 0, 0.42)"
+    : "rgba(255, 255, 255, 0.7)"};
     left: 0px;
     bottom: 0px;
     right: 0px;
@@ -114,8 +114,8 @@ const underlineStyle = css`
     @media (hover: none) {
       border-bottom: 1px solid
         ${theme.palette.mode === "light"
-          ? "rgba(0, 0, 0, 0.42)"
-          : "rgba(255, 255, 255, 0.7)"};
+    ? "rgba(0, 0, 0, 0.42)"
+    : "rgba(255, 255, 255, 0.7)"};
     }
   }
   &[data-disabled]:before {
