@@ -21,11 +21,11 @@ import {
   WalletRunConfig,
 } from "@gnu-taler/taler-util";
 import { WalletOperations } from "@gnu-taler/taler-wallet-core";
-import {
+import { BackgroundOperations } from "../wxApi.js";
+import type {
   ExtensionOperations,
   MessageFromExtension,
-} from "../taler-wallet-interaction-loader.js";
-import { BackgroundOperations } from "../wxApi.js";
+} from "../wxBackend.js";
 
 export interface Permissions {
   /**
@@ -118,6 +118,7 @@ export interface Settings extends WebexWalletConfig {
   autoOpen: boolean;
   advancedMode: boolean;
   backup: boolean;
+  p2p_aliases: boolean;
   langSelector: boolean;
   showJsonOnError: boolean;
   extendedAccountTypes: boolean;
@@ -133,6 +134,7 @@ export const defaultSettings: Settings = {
   autoOpen: true,
   advancedMode: false,
   backup: false,
+  p2p_aliases: false,
   langSelector: false,
   showRefeshTransactions: false,
   suspendIndividualTransaction: false,
