@@ -23,6 +23,7 @@ import {
   stringifyTalerUri,
 } from "@gnu-taler/taler-util";
 import { WalletOperations } from "@gnu-taler/taler-wallet-core";
+import { encodeCrockForURI } from "@gnu-taler/web-util/browser";
 import { BackgroundOperations } from "../wxApi.js";
 import {
   BackgroundPlatformAPI,
@@ -35,7 +36,6 @@ import {
   Settings,
   defaultSettings,
 } from "./api.js";
-import { encodeCrockForURI } from "@gnu-taler/web-util/browser";
 
 const api: BackgroundPlatformAPI & ForegroundPlatformAPI = {
   isFirefox,
@@ -231,11 +231,20 @@ function openWalletURIFromPopup(uri: TalerUri): void {
         )}`,
       );
       break;
+    case TalerUriAction.AddContact:
+      url = chrome.runtime.getURL(
+        `static/wallet.html#/cta/add/contact?talerUri=${encodeCrockForURI(
+          talerUri,
+        )}`,
+      );
+      break;
     case TalerUriAction.DevExperiment:
       logger.warn(`taler://dev-experiment URIs are not allowed in headers`);
       return;
     case TalerUriAction.WithdrawalTransferResult:
-      logger.warn(`taler://withdrawal-transfer-result URIs are not allowed in headers`);
+      logger.warn(
+        `taler://withdrawal-transfer-result URIs are not allowed in headers`,
+      );
       return;
     default: {
       const error: never = uri;
@@ -598,8 +607,8 @@ async function registerIconChangeOnTalerContent(): Promise<void> {
     return;
   }
 
-  //this browser doesn't have declarativeContent
-  //we need host_permission and we will check the content for changing the icon
+  // this browser doesn't have declarativeContent
+  // we need host_permission and we will check the content for changing the icon
   chrome.tabs.onUpdated.addListener(
     async (tabId, info: chrome.tabs.TabChangeInfo) => {
       if (tabId < 0) return;
