@@ -14,7 +14,7 @@
  GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
 
-import { AmountJson, PaytoUri, ScopeInfo } from "@gnu-taler/taler-util";
+import { AmountJson, PaytoString, ScopeInfo } from "@gnu-taler/taler-util";
 import { ErrorAlertView } from "../../components/CurrentAlerts.js";
 import { Loading } from "../../components/Loading.js";
 import { ErrorAlert } from "../../context/alert.js";
@@ -34,7 +34,7 @@ import {
 } from "./views.js";
 
 export interface Props {
-  scope:ScopeInfo;
+  scope: ScopeInfo;
   onCancel: (scope: ScopeInfo) => void;
   onSuccess: (scope: ScopeInfo) => void;
 }
@@ -63,7 +63,7 @@ export namespace State {
     status: "manage-account";
     error: undefined;
     scope: ScopeInfo;
-    onAccountAdded: (p: PaytoUri) => void;
+    onAccountSelected: (paytoUri: PaytoString) => void;
     onCancel: () => void;
   }
 
@@ -92,7 +92,7 @@ export namespace State {
     error: undefined;
     currency: string;
 
-    currentAccount: PaytoUri;
+    currentAccount: string;
     totalFee: AmountJson;
 
     amount: AmountFieldHandler;
