@@ -179,8 +179,8 @@ export const SomeBalanceWithNoTransactions = tests.createExample(
         flags: [],
         pendingIncoming: "TESTKUDOS:0" as AmountString,
         pendingOutgoing: "TESTKUDOS:0" as AmountString,
-        hasPendingTransactions: false,
-        requiresUserInput: false,
+        
+        
         scopeInfo: {
           currency: "Ásd",
           type: ScopeType.Auditor,
@@ -206,8 +206,8 @@ export const OneSimpleTransaction = tests.createExample(TestedComponent, {
       available: "USD:10" as AmountString,
       pendingIncoming: "USD:0" as AmountString,
       pendingOutgoing: "USD:0" as AmountString,
-      hasPendingTransactions: false,
-      requiresUserInput: false,
+      
+      
       scopeInfo: {
         currency: "Ásd",
         type: ScopeType.Auditor,
@@ -236,8 +236,8 @@ export const TwoTransactionsAndZeroBalance = tests.createExample(
         available: "USD:0" as AmountString,
         pendingIncoming: "USD:0" as AmountString,
         pendingOutgoing: "USD:0" as AmountString,
-        hasPendingTransactions: false,
-        requiresUserInput: false,
+        
+        
         scopeInfo: {
           currency: "Ásd",
           type: ScopeType.Auditor,
@@ -272,8 +272,8 @@ export const OneTransactionPending = tests.createExample(TestedComponent, {
       available: "USD:10" as AmountString,
       pendingIncoming: "USD:0" as AmountString,
       pendingOutgoing: "USD:0" as AmountString,
-      hasPendingTransactions: false,
-      requiresUserInput: false,
+      
+      
       scopeInfo: {
         currency: "Ásd",
         type: ScopeType.Auditor,
@@ -315,8 +315,8 @@ export const SomeTransactions = tests.createExample(TestedComponent, {
       available: "USD:10" as AmountString,
       pendingIncoming: "USD:0" as AmountString,
       pendingOutgoing: "USD:0" as AmountString,
-      hasPendingTransactions: false,
-      requiresUserInput: false,
+      
+      
       scopeInfo: {
         currency: "Ásd",
         type: ScopeType.Auditor,
@@ -417,8 +417,8 @@ export const SomeTransactionsInDifferentStates = tests.createExample(
         available: "USD:10" as AmountString,
         pendingIncoming: "USD:0" as AmountString,
         pendingOutgoing: "USD:0" as AmountString,
-        hasPendingTransactions: false,
-        requiresUserInput: false,
+        
+        
         scopeInfo: {
           currency: "Ásd",
           type: ScopeType.Auditor,
@@ -456,8 +456,8 @@ export const SomeTransactionsWithTwoCurrencies = tests.createExample(
         available: "USD:0" as AmountString,
         pendingIncoming: "USD:0" as AmountString,
         pendingOutgoing: "USD:0" as AmountString,
-        hasPendingTransactions: false,
-        requiresUserInput: false,
+        
+        
         scopeInfo: {
           currency: "Ásd",
           type: ScopeType.Auditor,
@@ -470,8 +470,8 @@ export const SomeTransactionsWithTwoCurrencies = tests.createExample(
         available: "TESTKUDOS:10" as AmountString,
         pendingIncoming: "TESTKUDOS:0" as AmountString,
         pendingOutgoing: "TESTKUDOS:0" as AmountString,
-        hasPendingTransactions: false,
-        requiresUserInput: false,
+        
+        
         scopeInfo: {
           currency: "Ásd",
           type: ScopeType.Auditor,
@@ -499,8 +499,8 @@ export const FiveOfficialCurrencies = tests.createExample(TestedComponent, {
       available: "USD:1000" as AmountString,
       pendingIncoming: "USD:0" as AmountString,
       pendingOutgoing: "USD:0" as AmountString,
-      hasPendingTransactions: false,
-      requiresUserInput: false,
+      
+      
       scopeInfo: {
         currency: "Ásd",
         type: ScopeType.Auditor,
@@ -513,8 +513,8 @@ export const FiveOfficialCurrencies = tests.createExample(TestedComponent, {
       available: "EUR:881" as AmountString,
       pendingIncoming: "TESTKUDOS:0" as AmountString,
       pendingOutgoing: "TESTKUDOS:0" as AmountString,
-      hasPendingTransactions: false,
-      requiresUserInput: false,
+      
+      
       scopeInfo: {
         currency: "Ásd",
         type: ScopeType.Auditor,
@@ -527,8 +527,8 @@ export const FiveOfficialCurrencies = tests.createExample(TestedComponent, {
       available: "COL:4043000.5" as AmountString,
       pendingIncoming: "TESTKUDOS:0" as AmountString,
       pendingOutgoing: "TESTKUDOS:0" as AmountString,
-      hasPendingTransactions: false,
-      requiresUserInput: false,
+      
+      
       scopeInfo: {
         currency: "Ásd",
         type: ScopeType.Auditor,
@@ -541,8 +541,8 @@ export const FiveOfficialCurrencies = tests.createExample(TestedComponent, {
       available: "JPY:11564450.6" as AmountString,
       pendingIncoming: "TESTKUDOS:0" as AmountString,
       pendingOutgoing: "TESTKUDOS:0" as AmountString,
-      hasPendingTransactions: false,
-      requiresUserInput: false,
+      
+      
       scopeInfo: {
         currency: "Ásd",
         type: ScopeType.Auditor,
@@ -555,8 +555,8 @@ export const FiveOfficialCurrencies = tests.createExample(TestedComponent, {
       available: "GBP:736" as AmountString,
       pendingIncoming: "TESTKUDOS:0" as AmountString,
       pendingOutgoing: "TESTKUDOS:0" as AmountString,
-      hasPendingTransactions: false,
-      requiresUserInput: false,
+      
+      
       scopeInfo: {
         currency: "Ásd",
         type: ScopeType.Auditor,
@@ -585,8 +585,8 @@ export const FiveOfficialCurrenciesWithHighValue = tests.createExample(
         available: "USD:881001321230000" as AmountString,
         pendingIncoming: "USD:0" as AmountString,
         pendingOutgoing: "USD:0" as AmountString,
-        hasPendingTransactions: false,
-        requiresUserInput: false,
+        
+        
         scopeInfo: {
           currency: "Ásd",
           type: ScopeType.Auditor,
@@ -599,8 +599,8 @@ export const FiveOfficialCurrenciesWithHighValue = tests.createExample(
         available: "EUR:10" as AmountString,
         pendingIncoming: "TESTKUDOS:0" as AmountString,
         pendingOutgoing: "TESTKUDOS:0" as AmountString,
-        hasPendingTransactions: false,
-        requiresUserInput: false,
+        
+        
         scopeInfo: {
           currency: "Ásd",
           type: ScopeType.Auditor,
@@ -613,22 +613,22 @@ export const FiveOfficialCurrenciesWithHighValue = tests.createExample(
         available: "COL:443000123123000.5123123" as AmountString,
         pendingIncoming: "TESTKUDOS:0" as AmountString,
         pendingOutgoing: "TESTKUDOS:0" as AmountString,
-        hasPendingTransactions: false,
+        
         scopeInfo: {
           currency: "Ásd",
           type: ScopeType.Auditor,
            url: "http://auditor.taler.ar",
 
         },
-        requiresUserInput: false,
+        
       },
       {
         flags: [],
         available: "JPY:1564450000000.6123123" as AmountString,
         pendingIncoming: "TESTKUDOS:0" as AmountString,
         pendingOutgoing: "TESTKUDOS:0" as AmountString,
-        hasPendingTransactions: false,
-        requiresUserInput: false,
+        
+        
         scopeInfo: {
           currency: "Ásd",
           type: ScopeType.Auditor,
@@ -641,8 +641,8 @@ export const FiveOfficialCurrenciesWithHighValue = tests.createExample(
         available: "GBP:736001231231200.23123" as AmountString,
         pendingIncoming: "TESTKUDOS:0" as AmountString,
         pendingOutgoing: "TESTKUDOS:0" as AmountString,
-        hasPendingTransactions: false,
-        requiresUserInput: false,
+        
+        
         scopeInfo: {
           currency: "Ásd",
           type: ScopeType.Auditor,
@@ -675,8 +675,8 @@ export const PeerToPeer = tests.createExample(TestedComponent, {
       available: "USD:10" as AmountString,
       pendingIncoming: "USD:0" as AmountString,
       pendingOutgoing: "USD:0" as AmountString,
-      hasPendingTransactions: false,
-      requiresUserInput: false,
+      
+      
       scopeInfo: {
         currency: "Ásd",
         type: ScopeType.Auditor,
