@@ -16,6 +16,7 @@
 
 import {
   BtAddrString,
+  convertHUF_BBANtoIBAN,
   HostPortPath,
   IbanString,
   InternationalizationAPI,
@@ -28,7 +29,8 @@ import {
   PaytoUriIBAN,
   PaytoUriTalerBank,
   TranslatedString,
-  WalletBankAccountInfo
+  WalletBankAccountInfo,
+  WireTypeDetails,
 } from "@gnu-taler/taler-util";
 import { useTranslationContext } from "@gnu-taler/web-util/browser";
 import { styled } from "@linaria/react";
@@ -44,7 +46,10 @@ import { State } from "./index.js";
 
 type AccountType = "bitcoin" | "x-taler-bank" | "iban";
 type ComponentFormByAccountType = {
-  [type in AccountType]: (props: { field: TextFieldHandler }) => VNode;
+  [type in AccountType]: (props: {
+    field: TextFieldHandler;
+    details: WireTypeDetails;
+  }) => VNode;
 };
 
 type ComponentListByAccountType = {
@@ -52,6 +57,7 @@ type ComponentListByAccountType = {
     list: WalletBankAccountInfo[];
     onDelete: (a: WalletBankAccountInfo) => Promise<void>;
     onSelect: (ac: WalletBankAccountInfo) => void;
+    details: WireTypeDetails;
   }) => VNode;
 };
 
@@ -86,6 +92,7 @@ export function ReadyView({
   error,
   accountType,
   accountByType,
+  details,
   alias,
   onAccountAdded,
   deleteAccount,
@@ -141,6 +148,7 @@ export function ReadyView({
             <CustomFieldByAccountType
               type={accountType.value as AccountType}
               field={uri}
+              details={details}
             />
           </p>
         </div>
@@ -181,6 +189,7 @@ export function ReadyView({
               list={list}
               onDelete={deleteAccount}
               onSelect={selectAccount}
+              details={details}
             />
           );
         })}
@@ -467,8 +476,10 @@ function undefinedIfEmpty<T extends object>(obj: T): T | undefined {
 
 function TalerBankAddressAccount({
   field,
+  details,
 }: {
   field: TextFieldHandler;
+  details: WireTypeDetails;
 }): VNode {
   const { i18n } = useTranslationContext();
   const [host, setHost] = useState<string | undefined>(undefined);
@@ -541,12 +552,19 @@ function translateIbanError(
 // const bicRegex = /^[A-Z]{6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3})?$/;
 // const ibanRegex = /^[A-Z]{2}[0-9]{2}[a-zA-Z0-9]{1,30}$/;
 
-function IbanAddressAccount({ field }: { field: TextFieldHandler }): VNode {
+function IbanAddressAccount({
+  field,
+  details,
+}: {
+  field: TextFieldHandler;
+  details: WireTypeDetails;
+}): VNode {
   const { i18n } = useTranslationContext();
   // const [bic, setBic] = useState<string | undefined>(undefined);
   const [iban, setIban] = useState<string | undefined>(undefined);
   const [name, setName] = useState<string | undefined>(undefined);
   const bic = "";
+
   const errorsFN = (iban: string | undefined, name: string | undefined) =>
     undefinedIfEmpty({
       // bic: !bic
@@ -554,9 +572,7 @@ function IbanAddressAccount({ field }: { field: TextFieldHandler }): VNode {
       //   : !bicRegex.test(bic)
       //   ? i18n.str`Invalid bic`
       //   : undefined,
-      iban: !iban
-        ? i18n.str`Required`
-        : validateIBAN(iban, i18n),
+      iban: !iban ? i18n.str`Required` : validateIBAN(iban, i18n, details),
       name: !name ? i18n.str`Can't be empty` : undefined,
     });
   const errors = errorsFN(iban, name);
@@ -634,9 +650,11 @@ function IbanAddressAccount({ field }: { field: TextFieldHandler }): VNode {
 function CustomFieldByAccountType({
   type,
   field,
+  details,
 }: {
   type: AccountType;
   field: TextFieldHandler;
+  details: WireTypeDetails;
 }): VNode {
   // const { i18n } = useTranslationContext();
 
@@ -644,7 +662,7 @@ function CustomFieldByAccountType({
 
   return (
     <div>
-      <AccountForm field={field} />
+      <AccountForm field={field} details={details} />
     </div>
   );
 }
@@ -652,11 +670,16 @@ function CustomFieldByAccountType({
 function validateIBAN(
   iban: string,
   i18n: ReturnType<typeof useTranslationContext>["i18n"],
+  details: WireTypeDetails,
 ): TranslatedString | undefined {
   if (!iban) {
     return i18n.str`Required`;
   }
-  const result = parseIban(iban);
+
+  const result =
+    details.preferredEntryType === "bban"
+      ? convertHUF_BBANtoIBAN(iban) // FIXME: this only works for HU
+      : parseIban(iban);
   if (result.type === "ok") {
     return undefined;
   }
