@@ -26,4 +26,6 @@ export default {
   title: "qr reader",
 };
 
-export const Reading = tests.createExample(QrReaderPage, {});
+export const Reading = tests.createExample(QrReaderPage, {
+  
+});
