@@ -278,6 +278,8 @@ function translateTalerUriError(
           return i18n.str`This URI requires the experiment id`;
         case TalerUriAction.AddExchange:
           return i18n.str`This URI requires the exchange host`;
+        case TalerUriAction.AddContact:
+          return i18n.str`This URI requires the alias type, the alias and the mailbox URI separated by /`;
         case TalerUriAction.WithdrawExchange:
           return i18n.str`This URI requires the exchange host`;
         case TalerUriAction.WithdrawalTransferResult:
@@ -306,6 +308,8 @@ function translateTalerUriError(
           return i18n.str`The merchant host is invalid`;
         case TalerUriAction.AddExchange:
           return i18n.str`The exchange host is invalid`;
+        case TalerUriAction.AddContact:
+          return i18n.str`The contact is invalid`;
         case TalerUriAction.WithdrawExchange:
           switch (result.body.pos) {
             case 0:
@@ -326,6 +330,7 @@ function translateTalerUriError(
         case TalerUriAction.PayPull:
         case TalerUriAction.PayTemplate:
         case TalerUriAction.AddExchange:
+        case TalerUriAction.AddContact:
           return i18n.str`A parameter is invalid`;
       }
     }
@@ -512,6 +517,8 @@ export function QrReaderPage({ onDetected }: Props): VNode {
                         return (
                           <i18n.Translate>Notify transaction</i18n.Translate>
                         );
+                      case TalerUriAction.AddContact:
+                        return <i18n.Translate>Add contact</i18n.Translate>;
                       default: {
                         assertUnreachable(talerUri);
                       }
@@ -560,6 +567,7 @@ async function testValidUri(
   switch (uri.type) {
     case TalerUriAction.Restore:
     case TalerUriAction.DevExperiment:
+    case TalerUriAction.AddContact:
     case TalerUriAction.WithdrawalTransferResult: {
       return undefined;
     }
