@@ -22,11 +22,10 @@ import {
 } from "@gnu-taler/taler-util";
 import { Fragment, VNode, h } from "preact";
 import { Attention } from "./Attention.js";
-import { useTranslationContext } from "../index.browser.js";
-import { useCommonPreference } from "../context/common-preferences.js";
+import { useCommonPreferences, useTranslationContext } from "../index.browser.js";
 
 export function ErrorLoading({ error }: { error: TalerError }): VNode {
-  const { showDebugInfo, toggle } = useCommonPreference();
+  const [{ showDebugInfo }, ] = useCommonPreferences();
   const { i18n } = useTranslationContext();
   switch (error.errorDetail.code) {
     //////////////////
