@@ -1,11 +1,12 @@
 import { TranslatedString } from "@gnu-taler/taler-util";
 import { VNode, h } from "preact";
-import { LabelWithTooltipMaybeRequired, RenderAddon } from "./InputLine.js";
-import { RenderAllFieldsByUiConfig, UIFormField, convertUiField } from "./forms.js";
-import { Addon, FormProvider } from "./FormProvider.js";
-import { useField } from "./useField.js";
-import { useTranslationContext } from "../index.browser.js";
-import { getConverterById } from "./converter.js";
+import { Addon } from "./FormProvider.js";
+import {
+  LabelWithTooltipMaybeRequired,
+  RenderAddon,
+} from "./fields/InputLine.js";
+import { RenderAllFieldsByUiConfig } from "./forms-ui.js";
+import { UIFormField } from "./field-types.js";
 
 interface Props {
   label: TranslatedString;
@@ -35,9 +36,7 @@ export function Group({
         </p>
       )}
       <div class="grid max-w-2xl grid-cols-1 gap-x-6 gap-y-2 sm:grid-cols-6">
-        <RenderAllFieldsByUiConfig 
-          fields={fields}
-          />
+        <RenderAllFieldsByUiConfig fields={fields} />
       </div>
     </div>
   );
