@@ -85,6 +85,7 @@ export type UIFormElementConfig =
   | UIFormFieldChoiceStacked
   | UIFormFieldFile
   | UIFormFieldInteger
+  | UIFormFieldPhone
   | UIFormFieldSecret
   | UIFormFieldSelectMultiple
   | UIFormFieldDuration
@@ -200,6 +201,10 @@ type UIFormFieldInteger = {
   min?: Integer;
 } & UIFormFieldBaseConfig;
 
+type UIFormFieldPhone = {
+  type: "phone";
+} & UIFormFieldBaseConfig;
+
 type UIFormFieldSecret = {
   type: "secret";
 } & UIFormFieldBaseConfig;
@@ -472,6 +477,12 @@ const codecForUiFormVoid = (): Codec<UIFormVoid> =>
     .property("type", codecForConstString("void"))
     .build("UIFormVoid");
 
+
+const codecForUIFormFieldPhone = (): Codec<UIFormFieldPhone> =>
+  codecForUIFormFieldBaseConfigTemplate<UIFormFieldPhone>()
+    .property("type", codecForConstString("phone"))
+    .build("UIFormFieldPhone");
+
 const codecForUiFormFieldInteger = (): Codec<UIFormFieldInteger> =>
   codecForUIFormFieldBaseConfigTemplate<UIFormFieldInteger>()
     .property("type", codecForConstString("integer"))
@@ -547,6 +558,7 @@ const codecForUiFormField = (): Codec<UIFormElementConfig> =>
     .alternative("choiceStacked", codecForUiFormFieldChoiceStacked())
     .alternative("file", codecForUiFormFieldFile())
     .alternative("integer", codecForUiFormFieldInteger())
+    .alternative("phone", codecForUIFormFieldPhone())
     .alternative("secret", codecForUiFormFieldSecret())
     .alternative("selectMultiple", codecForUiFormFieldSelectMultiple())
     .alternative("duration", codecForUiFormFieldDuration())
