@@ -254,6 +254,7 @@ export function useLocalNotificationBetter(): [
           // @ts-expect-error
           r.withArgs = (...args: D) => {
             const d = converter(...args);
+            if (!d) return thiz
             const e = thiz.withArgs(...d);
             return e;
           };
@@ -380,7 +381,7 @@ export interface SafeHandlerTemplate<Args extends any[], Errors> {
    * @param e
    */
   lambda<OtherArgs extends any[]>(
-    e: (...d: OtherArgs) => Args,
+    e: (...d: OtherArgs) => Args | undefined,
     init?: OtherArgs,
   ): SafeHandlerTemplate<OtherArgs, Errors>;
   /**
